@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 2003 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 2003 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -86,30 +86,53 @@ static void ResizeBarrel(BarrelWidget w);
 static void InitializeBarrel(Widget request, Widget renew);
 static void ExposeBarrel(Widget renew, XEvent * event, Region region);
 static void HideBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void SelectBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void ReleaseBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void PracticeBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void PracticeBarrelMaybe(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void PracticeBarrel2(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void RandomizeBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void RandomizeBarrelMaybe(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void RandomizeBarrel2(BarrelWidget w, XEvent * event, char **args, int nArgs);
+static void SelectBarrel(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void MotionBarrel(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void ReleaseBarrel(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void PracticeBarrel(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void PracticeBarrelMaybe(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void PracticeBarrel2(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void RandomizeBarrel(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void RandomizeBarrelMaybe(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void RandomizeBarrel2(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
 static void GetBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void WriteBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void ClearBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
+static void WriteBarrel(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void ClearBarrel(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
 static void UndoBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void SolveBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void OrientizeBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void PairsBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void SpeedBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
+static void SolveBarrel(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void OrientizeBarrel(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void PairsBarrel(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void SpeedBarrel(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
 static void SlowBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void SoundBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void EnterBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void LeaveBarrel(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void MoveBarrelTop(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void MoveBarrelLeft(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void MoveBarrelRight(BarrelWidget w, XEvent * event, char **args, int nArgs);
-static void MoveBarrelBottom(BarrelWidget w, XEvent * event, char **args, int nArgs);
+static void SoundBarrel(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void EnterBarrel(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void LeaveBarrel(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void MoveBarrelTop(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void MoveBarrelBottom(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void MoveBarrelLeft(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
+static void MoveBarrelRight(BarrelWidget w, XEvent * event,
+	char **args, int nArgs);
 
 static char defaultTranslationsBarrel[] =
 "<KeyPress>q: Quit()\n\
@@ -140,6 +163,7 @@ static char defaultTranslationsBarrel[] =
  <KeyPress>KP_2: MoveBottom()\n\
  <KeyPress>R14: MoveBottom()\n\
  <Btn1Down>: Select()\n\
+ <Btn1Motion>: Motion()\n\
  <Btn1Up>: Release()\n\
  <KeyPress>p: Practice()\n\
  <KeyPress>r: Randomize()\n\
@@ -158,7 +182,6 @@ static char defaultTranslationsBarrel[] =
  <KeyPress>0x3E: Speed()\n\
  <KeyPress>0x3C: Slow()\n\
  <KeyPress>0x2C: Slow()\n\
- <KeyPress>2: Sound()\n\
  <KeyPress>@: Sound()\n\
  <EnterWindow>: Enter()\n\
  <LeaveWindow>: Leave()";
@@ -172,6 +195,7 @@ static XtActionsRec actionsListBarrel[] =
 	{(char *) "MoveRight", (XtActionProc) MoveBarrelRight},
 	{(char *) "MoveBottom", (XtActionProc) MoveBarrelBottom},
 	{(char *) "Select", (XtActionProc) SelectBarrel},
+	{(char *) "Motion", (XtActionProc) MotionBarrel},
 	{(char *) "Release", (XtActionProc) ReleaseBarrel},
 	{(char *) "Practice", (XtActionProc) PracticeBarrel},
 	{(char *) "PracticeMaybe", (XtActionProc) PracticeBarrelMaybe},
@@ -587,7 +611,8 @@ CheckTiles(BarrelWidget w)
 static Boolean
 PositionTile(BarrelWidget w, int x, int *r)
 {
-	*r = (x - w->barrel.delta.x / 2 - w->barrel.puzzleOffset.x) / w->barrel.offset.x;
+	*r = (x - w->barrel.delta.x / 2 - w->barrel.puzzleOffset.x) /
+		w->barrel.offset.x;
 	if (*r < 0 || *r >= w->barrel.tiles)
 		return False;
 	return True;
@@ -605,12 +630,18 @@ Row(BarrelWidget w, int pos)
 	return (pos / w->barrel.tiles);
 }
 
-static void
-Cartesian(BarrelWidget w, int pos, int * x, int * y)
+
+static int
+CartesianX(BarrelWidget w, int pos)
 {
-	*x = Column(w, pos) * w->barrel.offset.x + w->barrel.delta.x +
+	return Column(w, pos) * w->barrel.offset.x + w->barrel.delta.x +
 		w->barrel.puzzleOffset.x;
-	*y = Row(w, pos) * (w->barrel.offset.y + 1) + w->barrel.delta.y +
+}
+
+static int
+CartesianY(BarrelWidget w, int pos)
+{
+	return Row(w, pos) * (w->barrel.offset.y + 1) + w->barrel.delta.y +
 		w->barrel.puzzleOffset.y;
 }
 
@@ -640,26 +671,39 @@ CheckSolved(const BarrelWidget w)
 		return True;
 	if (w->barrel.orient) {
 		for (j = 0; j < w->barrel.faces; j++) {
-			color = (w->barrel.tileOfPosition[j * w->barrel.tiles + 1] - 1) / (w->barrel.tiles - 2);
-			inc = (w->barrel.tileOfPosition[j * w->barrel.tiles + 1] - 1) % (w->barrel.tiles - 2);
+			color = (w->barrel.tileOfPosition[j * w->barrel.tiles +
+				1] - 1) / (w->barrel.tiles - 2);
+			inc = (w->barrel.tileOfPosition[j * w->barrel.tiles +
+				1] - 1) % (w->barrel.tiles - 2);
 			for (i = 1; i < w->barrel.tiles - 2; i++) {
-				if (color != (w->barrel.tileOfPosition[j * w->barrel.tiles + i + 1] - 1) / (w->barrel.tiles - 2)) {
+				if (color != (w->barrel.tileOfPosition[j *
+						w->barrel.tiles + i + 1] - 1) /
+					       	(w->barrel.tiles - 2)) {
 					return False;
 				}
-				if (inc + i != (w->barrel.tileOfPosition[j * w->barrel.tiles + i + 1] - 1) % (w->barrel.tiles - 2)) {
+				if (inc + i != (w->barrel.tileOfPosition[j *
+						w->barrel.tiles + i + 1] - 1) %
+					       	(w->barrel.tiles - 2)) {
 					return False;
 				}
 			}
 			if (color % 2 == 0) {
-				if ((w->barrel.tiles - 2) * w->barrel.faces + 1 + color / 2 != w->barrel.tileOfPosition[j * w->barrel.tiles + w->barrel.tiles - 1])
+				if ((w->barrel.tiles - 2) * w->barrel.faces +
+						1 + color / 2 !=
+						w->barrel.tileOfPosition[j *
+						w->barrel.tiles +
+						w->barrel.tiles - 1])
 					return False;
 			}
 		}
 	} else {
 		for (j = 0; j < w->barrel.faces; j++) {
-			color = (w->barrel.tileOfPosition[j * w->barrel.tiles + 1] - 1) / (w->barrel.tiles - 2);
+			color = (w->barrel.tileOfPosition[j * w->barrel.tiles +
+				1] - 1) / (w->barrel.tiles - 2);
 			for (i = 0; i < w->barrel.tiles - 3; i++) {
-				if (color != (w->barrel.tileOfPosition[j * w->barrel.tiles + i + 2] - 1) / (w->barrel.tiles - 2)) {
+				if (color != (w->barrel.tileOfPosition[j *
+						w->barrel.tiles + i + 2] - 1) /
+					       	(w->barrel.tiles - 2)) {
 					return False;
 				}
 			}
@@ -669,7 +713,7 @@ CheckSolved(const BarrelWidget w)
 }
 
 static int
-tilePicture(BarrelWidget w, int tile)
+TilePicture(BarrelWidget w, int tile)
 {
 	int face, inc = 0;
 
@@ -705,7 +749,7 @@ PrintBarrel(BarrelWidget w)
 		for (tile = 0; tile < w->barrel.tiles; tile++) {
 			   (void) printf("%d %d, ",
 	   w->barrel.tileOfPosition[face * w->barrel.tiles + tile],
-   tilePicture(w, w->barrel.tileOfPosition[face * w->barrel.tiles + tile]));
+   TilePicture(w, w->barrel.tileOfPosition[face * w->barrel.tiles + tile]));
 			if (!((tile + 1) % w->barrel.tiles))
 				(void) printf("\n");
 		}
@@ -793,9 +837,8 @@ DrawBall(BarrelWidget w, Pixmap dr, GC gc, int pos, int offsetX, int offsetY)
 	int dx, dy, diameter;
 
 	diameter = MIN(w->barrel.offset.x, w->barrel.offset.y) * 3 / 4 - 3;
-	Cartesian(w, pos, &dx, &dy);
-	dx += w->barrel.tileSize.x / 2 - offsetX;
-	dy += w->barrel.tileSize.y / 2 - offsetY;
+	dx = CartesianX(w, pos) + w->barrel.tileSize.x / 2 - offsetX;
+	dy = CartesianY(w, pos) + w->barrel.tileSize.y / 2 - offsetY;
 	FILLCIRCLE(w, dr, gc, diameter, dx, dy);
 }
 
@@ -814,14 +857,14 @@ DrawTile(BarrelWidget w, int pos, Boolean blank, Boolean erase,
 		int pressedOffset, int offsetX, int offsetY)
 {
 	int dx, dy, sx, sy;
-	int tile = tilePicture(w, (w->barrel.tileOfPosition[pos] +
+	int tile = TilePicture(w, (w->barrel.tileOfPosition[pos] +
 		w->barrel.tileFaces - 1) % w->barrel.tileFaces);
 	Pixmap dr = 0;
 
-	Cartesian(w, pos, &dx, &dy);
-	dx += offsetX + pressedOffset;
-	dy += offsetY + pressedOffset;
-	Cartesian(w, tile, &sx, &sy);
+	dx = CartesianX(w, pos) + offsetX + pressedOffset;
+	dy = CartesianY(w, pos) + offsetY + pressedOffset;
+	sx = CartesianX(w, tile);
+	sy = CartesianY(w, tile);
 	if (blank) {
 		FILLRECTANGLE(w, dr,
 			(erase) ? w->barrel.inverseGC : w->barrel.tileGC,
@@ -878,9 +921,8 @@ DrawBufferedTile(BarrelWidget w, int pos, int pressedOffset)
 #endif
 	}
 	dr = &(w->barrel.bufferTiles[pressedOffset]);
-	Cartesian(w, pos, &dx, &dy);
-	dx += pressedOffset;
-	dy += pressedOffset;
+	dx = CartesianX(w, pos) + pressedOffset;
+	dy = CartesianY(w, pos) + pressedOffset;
 	if (pressedOffset != 0) {
 		drawShadow(w, *dr, w->barrel.tileDarkerGC,
 			dx - pressedOffset, dy - pressedOffset,
@@ -970,7 +1012,8 @@ static void
 AnimateSlide(BarrelWidget w, int numTiles, int dir, int fast)
 {
 	int inc, aTile, plunger;
-	int fillBeginPos[NUMPLUNGERS], fillBeginI = 0, gapI = 0, moveI = 0;
+	int fillBeginPos[NUMPLUNGERS];
+	int fillBeginI = 0, gapI = 0, moveI = 0;
 	int dx, dy, pos, posNext;
 	int ix = 0, iy = 0;
 	Pixmap dr = 0;
@@ -978,7 +1021,8 @@ AnimateSlide(BarrelWidget w, int numTiles, int dir, int fast)
 	for (plunger = 0; plunger < NUMPLUNGERS; plunger++) {
 	  fillBeginPos[plunger] = TileNFromSpace(w, plunger, numTiles, dir);
 	}
-	Cartesian(w, fillBeginPos[0], &fillBeginI, &dy);
+	fillBeginI = CartesianX(w, fillBeginPos[0]);
+	dy = CartesianY(w, fillBeginPos[0]);
 	gapI = w->barrel.tileSize.x * fast / w->barrel.numSlices;
 	moveI = w->barrel.tileSize.x + w->barrel.delta.x;
 	if (gapI == 0)
@@ -993,7 +1037,8 @@ AnimateSlide(BarrelWidget w, int numTiles, int dir, int fast)
 	    for (aTile = 0; aTile < numTiles; aTile++) {
 	      posNext = TileNFromSpace(w, plunger, aTile + 1, dir);
 	      /* Calculate deltas */
-	      Cartesian(w, posNext, &dx, &dy);
+	      dx = CartesianX(w, posNext);
+	      dy = CartesianY(w, posNext);
 	      ix = ((dir == RIGHT) ? inc : -inc);
 	      iy = 0;
 	      DrawTile(w, posNext, False, False, FALSE, ix, iy);
@@ -1001,34 +1046,34 @@ AnimateSlide(BarrelWidget w, int numTiles, int dir, int fast)
 	      ix += dx;
 	      iy += dy;
 	      if (aTile < numTiles - 1) {
-	        switch (dir) {
-	          case RIGHT:
-	            FILLRECTANGLE(w, dr,
-	              w->barrel.inverseGC,
-	              ix - gapI, iy, gapI, w->barrel.tileSize.y);
-	            break;
-	          case LEFT:
-	            FILLRECTANGLE(w, dr,
-	              w->barrel.inverseGC,
-	              ix + w->barrel.tileSize.x, iy,
-	              gapI, w->barrel.tileSize.y);
-		    break;
-	        }
+		switch (dir) {
+		case RIGHT:
+		  FILLRECTANGLE(w, dr,
+		    w->barrel.inverseGC,
+		    ix - gapI, iy, gapI, w->barrel.tileSize.y);
+		  break;
+		case LEFT:
+		  FILLRECTANGLE(w, dr,
+		    w->barrel.inverseGC,
+		    ix + w->barrel.tileSize.x, iy,
+		    gapI, w->barrel.tileSize.y);
+		  break;
+		}
 	      } else {
-	        switch (dir) {
-	          case RIGHT:
-	            FILLRECTANGLE(w, dr,
-	              w->barrel.inverseGC,
-	              fillBeginI, iy,
-	              ix - fillBeginI, w->barrel.tileSize.y);
-	            break;
-	          case LEFT:
-	            FILLRECTANGLE(w, dr,
-	              w->barrel.inverseGC,
-	              ix + w->barrel.tileSize.x, iy,
-	              fillBeginI - ix, w->barrel.tileSize.y);
-		    break;
-	        }
+		switch (dir) {
+		case RIGHT:
+		  FILLRECTANGLE(w, dr,
+		    w->barrel.inverseGC,
+		    fillBeginI, iy,
+		    ix - fillBeginI, w->barrel.tileSize.y);
+		  break;
+		case LEFT:
+		  FILLRECTANGLE(w, dr,
+		    w->barrel.inverseGC,
+		    ix + w->barrel.tileSize.x, iy,
+		    fillBeginI - ix, w->barrel.tileSize.y);
+		  break;
+		}
 	      }
 	    }
 	    useTimer(w, w->barrel.delay / fast);
@@ -1051,7 +1096,7 @@ AnimateSlide(BarrelWidget w, int numTiles, int dir, int fast)
 static void
 DrawAllTilesForColumns(BarrelWidget w, int start, int finish)
 {
-	int         i, j, k;
+	int i, j, k;
 
 	for (i = start; i <= finish; i++) {
 		for (j = 0; j < w->barrel.faces; j++) {
@@ -1089,7 +1134,7 @@ AnimateRotate(BarrelWidget w, int start, int finish, int direction, int fast)
 		w->barrel.puzzleSize.y);
 	SelectObject(memDC, hBit);
 	BitBlt(memDC, 0, 0,
-		size * moveI + 1,
+		size * moveI,
 		w->barrel.puzzleSize.y,
 		w->core.hDC,
 		start * moveI + w->barrel.puzzleOffset.x + 1,
@@ -1099,7 +1144,7 @@ AnimateRotate(BarrelWidget w, int start, int finish, int direction, int fast)
 	(void) XGetWindowAttributes(XtDisplay(w), XtWindow(w), &xgwa);
 
 	if ((bufferBox = XCreatePixmap(XtDisplay(w), XtWindow(w),
-			size * moveI + 1,
+			size * moveI,
 			w->barrel.puzzleSize.y,
 			xgwa.depth)) == None) {
 		XtError("Not enough memory, exiting.");
@@ -1108,7 +1153,7 @@ AnimateRotate(BarrelWidget w, int start, int finish, int direction, int fast)
 		w->barrel.frameGC,
 		start * moveI + w->barrel.puzzleOffset.x + 1,
 		w->barrel.puzzleOffset.y,
-		size * moveI + 1,
+		size * moveI,
 		w->barrel.puzzleSize.y,
 		0, 0);
 	XSetGraphicsExposures(XtDisplay(w), w->barrel.frameGC, False);
@@ -1126,7 +1171,7 @@ AnimateRotate(BarrelWidget w, int start, int finish, int direction, int fast)
 		BitBlt(w->core.hDC,
 			start * moveI + w->barrel.puzzleOffset.x + 1,
 			w->barrel.puzzleOffset.y + 1,
-			size * moveI + 1,
+			size * moveI,
 			w->barrel.puzzleSize.y - i,
 			memDC,
 			0, i,
@@ -1135,7 +1180,7 @@ AnimateRotate(BarrelWidget w, int start, int finish, int direction, int fast)
 			start * moveI + w->barrel.puzzleOffset.x + 1,
 			w->barrel.puzzleSize.y - i + w->barrel.puzzleOffset.y -
 			w->barrel.delta.y + 1,
-			size * moveI + 1,
+			size * moveI,
 			i - w->barrel.delta.y,
 			memDC,
 			0, 0,
@@ -1145,14 +1190,14 @@ AnimateRotate(BarrelWidget w, int start, int finish, int direction, int fast)
 		XCopyArea(XtDisplay(w), bufferBox, XtWindow(w),
 			w->barrel.frameGC,
 			0, i,
-			size * moveI + 1,
+			size * moveI,
 			w->barrel.puzzleSize.y - i,
 			start * moveI + w->barrel.puzzleOffset.x + 1,
 			w->barrel.puzzleOffset.y + 1);
 		XCopyArea(XtDisplay(w), bufferBox, XtWindow(w),
 			w->barrel.frameGC,
 			0, 0,
-			size * moveI + 1,
+			size * moveI,
 			i - w->barrel.delta.y,
 			start * moveI + w->barrel.puzzleOffset.x + 1,
 			w->barrel.puzzleSize.y - i + w->barrel.puzzleOffset.y -
@@ -1168,55 +1213,6 @@ AnimateRotate(BarrelWidget w, int start, int finish, int direction, int fast)
 #endif
 }
 
-static void
-ResetTiles(BarrelWidget w)
-{
-	int i, inc;
-
-	w->barrel.tileFaces = w->barrel.tiles * w->barrel.faces;
-	if (w->barrel.tileOfPosition)
-		free(w->barrel.tileOfPosition);
-	if (!(w->barrel.tileOfPosition = (int *)
-			malloc(sizeof (int) * w->barrel.tileFaces))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-	if (startPosition)
-		free(startPosition);
-	if (!(startPosition = (int *)
-			malloc(sizeof (int) * w->barrel.tileFaces))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-
-	inc = 0;
-	for (i = 0; i < w->barrel.tileFaces; i++) {
-		if (i % w->barrel.tiles != 0 &&
-				i % w->barrel.tiles != w->barrel.tiles - 1) {
-			inc++;
-			w->barrel.tileOfPosition[i] = inc;
-		} else {
-			w->barrel.tileOfPosition[i] = 0;
-		}
-	}
-	for (i = 0; i < NUMPLUNGERS; i++) {
-		w->barrel.spacePosition[i] = 2 * i * w->barrel.tiles;
-		w->barrel.tileOfPosition[2 * i * w->barrel.tiles] =
-			-NUMPLUNGERS + i;
-		inc++;
-		w->barrel.tileOfPosition[(2 * i + 1) * w->barrel.tiles - 1] =
-			inc;
-	}
-	inc++;
-	for (i = 0; i < w->barrel.faces - NUMPLUNGERS; i++) {
-		w->barrel.tileOfPosition[(2 * i + 1) * w->barrel.tiles] =
-			inc++;
-		w->barrel.tileOfPosition[(2 * i + 2) * w->barrel.tiles - 1] =
-			inc++;
-	}
-	FlushMoves(w);
-	w->barrel.currentRef = -w->barrel.tileFaces;
-	w->barrel.started = False;
-}
-
 static void
 EraseFrame(const BarrelWidget w, Pixmap dr)
 {
@@ -1351,7 +1347,7 @@ RotateTiles(BarrelWidget w, int start, int finish, int direction, int fast)
 
 		FILLRECTANGLE(w, dr, w->barrel.inverseGC,
 			start * moveI + w->barrel.puzzleOffset.x + 1, 0,
-			(finish - start + 1) * moveI + 1, w->core.height);
+			(finish - start + 1) * moveI, w->core.height);
 		DrawFrame(w, dr, w->barrel.focus);
 		DrawAllTilesForColumns(w, start, finish);
 	}
@@ -1363,40 +1359,6 @@ RotateTiles(BarrelWidget w, int start, int finish, int direction, int fast)
 #endif
 }
 
-static void
-SelectSlideTiles(BarrelWidget w, int pos)
-{
-	if (pos < 0) {
-		if (w->barrel.delay > 0) {
-			AnimateSlide(w, -pos, RIGHT, NORMAL);
-#ifdef USE_SOUND
-			if (w->barrel.sound) {
-				playSound((char *) BUMPSOUND);
-			}
-#endif
-		} else {
-			MoveTiles(w, w->barrel.spacePosition[0] % w->barrel.tiles - w->barrel.tiles + 1,
-				NORMAL);
-		}
-		SetBarrel(w, BARREL_MOVED);
-		PutMove(RIGHT, 0, 0);
-	} else if (pos > 0) {
-		if (w->barrel.delay > 0) {
-			AnimateSlide(w, pos, LEFT, NORMAL);
-#ifdef USE_SOUND
-			if (w->barrel.sound) {
-				playSound((char *) BUMPSOUND);
-			}
-#endif
-		} else {
-			MoveTiles(w, w->barrel.spacePosition[0] % w->barrel.tiles + w->barrel.tiles - 1,
-				NORMAL);
-		}
-		SetBarrel(w, BARREL_MOVED);
-		PutMove(LEFT, w->barrel.tiles - 1, 0);
-	}
-}
-
 static Boolean
 MoveTilesDir(BarrelWidget w, int direction, int tile, Boolean all, int fast)
 {
@@ -1442,6 +1404,13 @@ MoveTilesDir(BarrelWidget w, int direction, int tile, Boolean all, int fast)
 	return False;
 }
 
+static void
+MoveShift(BarrelWidget w, int direction, int fast)
+{
+	(void) MoveTilesDir(w, direction, 0, True, fast);
+	SetBarrel(w, BARREL_CONTROL);
+}
+
 #if 0
 static void
 ControlBarrel(BarrelWidget w, int direction)
@@ -1481,11 +1450,83 @@ ControlBarrel(BarrelWidget w, int direction)
 }
 #endif
 
-static void
-MoveShift(BarrelWidget w, int direction, int fast)
+Boolean
+MoveBarrel(BarrelWidget w, const int direction, const int tile,
+		const int shift, const Boolean motion, const int fast)
 {
-	(void) MoveTilesDir(w, direction, 0, True, fast);
-	SetBarrel(w, BARREL_CONTROL);
+	if (shift != 0 && (direction == TOP || direction == BOTTOM)) {
+		MoveShift(w, direction, fast);
+		if (!motion) {
+			PutMove(direction, tile, 1);
+		}
+		return True;
+	} else if (MoveTilesDir(w, direction, tile, False, fast)) {
+		if (!motion) {
+			SetBarrel(w, BARREL_MOVED);
+			PutMove(direction, tile, 0);
+		}
+		return True;
+	}
+	return False;
+}
+
+static void
+DiffMove(BarrelWidget w, int diff, int j, int shift)
+{
+	int k;
+
+	if (diff > w->barrel.faces / 2 ||
+	    (diff == (w->barrel.faces + 1) / 2 && j > w->barrel.currentFace))
+		for (k = 0; k < w->barrel.faces - diff; k++)
+			(void) MoveBarrel(w, BOTTOM, w->barrel.currentTile,
+				shift, True, NORMAL);
+	else
+		for (k = 0; k < diff; k++)
+			(void) MoveBarrel(w, TOP, w->barrel.currentTile,
+				shift, True, NORMAL);
+}
+
+static void
+MoveRecord(BarrelWidget w, const int direction, const int tile, const int shift)
+{
+	if (shift != 0 && (direction == TOP || direction == BOTTOM)) {
+		PutMove(direction, tile, 1);
+	} else {
+		SetBarrel(w, BARREL_MOVED);
+		PutMove(direction, tile, 0);
+	}
+}
+
+static void
+DiffRecord(BarrelWidget w, int diff, int j, int shift)
+{
+	int k;
+
+	if (diff > w->barrel.faces / 2 ||
+	    (diff == (w->barrel.faces + 1) / 2 && j > w->barrel.currentFace))
+		for (k = 0; k < w->barrel.faces - diff; k++)
+			(void) MoveRecord(w, BOTTOM,
+				w->barrel.currentTile, shift);
+	else
+		for (k = 0; k < diff; k++)
+			(void) MoveRecord(w, TOP,
+				w->barrel.currentTile, shift);
+}
+
+void
+MoveBarrelDelay(BarrelWidget w, const int direction, const int tile,
+		const Boolean all)
+{
+	if (direction == RIGHT) {
+		PutMove(direction, 0, False);
+	} else if (direction == LEFT) {
+		PutMove(direction, w->barrel.tiles - 1, False);
+	} else {
+		SetBarrel(w, BARREL_MOVED);
+		PutMove(direction, tile, all);
+	}
+	(void) MoveTilesDir(w, direction, tile, all, NORMAL);
+	Sleep((unsigned int) w->barrel.delay);
 }
 
 static void
@@ -1495,7 +1536,7 @@ SlideBarrel(BarrelWidget w, int direction)
 		MoveNoTiles(w);
 		return;
 	}
-	if (!MoveBarrel(w, direction, 0, FALSE, NORMAL)) {
+	if (!MoveBarrel(w, direction, 0, FALSE, False, NORMAL)) {
 		SetBarrel(w, BARREL_BLOCKED);
 		return;
 	}
@@ -1512,7 +1553,7 @@ RotateBarrel(BarrelWidget w, int direction, int tile)
 		MoveNoTiles(w);
 		return;
 	}
-	(void) MoveBarrel(w, direction, tile, FALSE, NORMAL);
+	(void) MoveBarrel(w, direction, tile, FALSE, False, NORMAL);
 	if (CheckSolved(w)) {
 		SetBarrel(w, BARREL_SOLVED);
 	}
@@ -1527,7 +1568,7 @@ MoveBarrelInput(BarrelWidget w, int x, int direction, int shift)
 {
 	int r;
 
-	if (shift && (direction == TOP || direction == BOTTOM)) {
+	if (shift != 0 && (direction == TOP || direction == BOTTOM)) {
 		MoveShift(w, direction, NORMAL);
 		PutMove(direction, 0, 1);
 	} else if (CheckSolved(w) && !w->barrel.practice) {
@@ -1552,53 +1593,107 @@ MoveBarrelInput(BarrelWidget w, int x, int direction, int shift)
 	}
 }
 
-void
-MoveBarrelDelay(BarrelWidget w, const int direction, const int tile,
-		const Boolean all)
-{
-	if (direction == RIGHT) {
-		PutMove(direction, 0, False);
-	} else if (direction == LEFT) {
-		PutMove(direction, w->barrel.tiles - 1, False);
-	} else {
-		SetBarrel(w, BARREL_MOVED);
-		PutMove(direction, tile, all);
-	}
-	(void) MoveTilesDir(w, direction, tile, all, NORMAL);
-	Sleep((unsigned int) w->barrel.delay);
-}
-
-Boolean
-MoveBarrel(BarrelWidget w, const int direction, const int tile,
-		const int shift, const int fast)
-{
-	if (shift && (direction == TOP || direction == BOTTOM)) {
-		MoveShift(w, direction, fast);
-		PutMove(direction, tile, 1);
-		return True;
-	} else if (MoveTilesDir(w, direction, tile, False, fast)) {
-		SetBarrel(w, BARREL_MOVED);
-		PutMove(direction, tile, 0);
-		return True;
-	}
-	return False;
-}
-
 static int
 SelectTiles(BarrelWidget w, int x, int y, int *i, int *j)
 {
+	int temp;
+
 	*i = (x - w->barrel.delta.x / 2 - w->barrel.puzzleOffset.x) /
 		w->barrel.offset.x;
-	*j = ((y - w->barrel.delta.y / 2 - w->barrel.puzzleOffset.y) %
-	      (w->barrel.faces * w->barrel.offset.y + w->barrel.delta.y - 1)) /
-		w->barrel.offset.y;
+	temp = w->barrel.faces * w->barrel.offset.y + w->barrel.delta.y - 1;
+	*j = ((y - w->barrel.delta.y / 2 - w->barrel.puzzleOffset.y + temp) %
+	      temp) / w->barrel.offset.y;
 	if (*i >= 0 && *j >= 0 &&
-	    *i < w->barrel.tiles && *j < w->barrel.faces)
+	    *i < w->barrel.tiles && *j < w->barrel.faces) {
 		return (*i + w->barrel.tiles * *j -
 			w->barrel.spacePosition[0] % w->barrel.tileFaces);
+	}
 	return -w->barrel.tileFaces;
 }
 
+static void
+SelectSlideTiles(BarrelWidget w, int pos)
+{
+	if (pos < 0) {
+		if (w->barrel.delay > 0) {
+			AnimateSlide(w, -pos, RIGHT, NORMAL);
+#ifdef USE_SOUND
+			if (w->barrel.sound) {
+				playSound((char *) BUMPSOUND);
+			}
+#endif
+		} else {
+			MoveTiles(w, w->barrel.spacePosition[0] % w->barrel.tiles - w->barrel.tiles + 1,
+				NORMAL);
+		}
+		SetBarrel(w, BARREL_MOVED);
+		PutMove(RIGHT, 0, 0);
+	} else if (pos > 0) {
+		if (w->barrel.delay > 0) {
+			AnimateSlide(w, pos, LEFT, NORMAL);
+#ifdef USE_SOUND
+			if (w->barrel.sound) {
+				playSound((char *) BUMPSOUND);
+			}
+#endif
+		} else {
+			MoveTiles(w, w->barrel.spacePosition[0] % w->barrel.tiles + w->barrel.tiles - 1,
+				NORMAL);
+		}
+		SetBarrel(w, BARREL_MOVED);
+		PutMove(LEFT, w->barrel.tiles - 1, 0);
+	}
+}
+
+static void
+ResetTiles(BarrelWidget w)
+{
+	int i, inc;
+
+	w->barrel.tileFaces = w->barrel.tiles * w->barrel.faces;
+	if (w->barrel.tileOfPosition)
+		free(w->barrel.tileOfPosition);
+	if (!(w->barrel.tileOfPosition = (int *)
+			malloc(sizeof (int) * w->barrel.tileFaces))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
+	if (startPosition)
+		free(startPosition);
+	if (!(startPosition = (int *)
+			malloc(sizeof (int) * w->barrel.tileFaces))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
+
+	inc = 0;
+	for (i = 0; i < w->barrel.tileFaces; i++) {
+		if (i % w->barrel.tiles != 0 &&
+				i % w->barrel.tiles != w->barrel.tiles - 1) {
+			inc++;
+			w->barrel.tileOfPosition[i] = inc;
+		} else {
+			w->barrel.tileOfPosition[i] = 0;
+		}
+	}
+	for (i = 0; i < NUMPLUNGERS; i++) {
+		w->barrel.spacePosition[i] = 2 * i * w->barrel.tiles;
+		w->barrel.tileOfPosition[2 * i * w->barrel.tiles] =
+			-NUMPLUNGERS + i;
+		inc++;
+		w->barrel.tileOfPosition[(2 * i + 1) * w->barrel.tiles - 1] =
+			inc;
+	}
+	inc++;
+	for (i = 0; i < w->barrel.faces - NUMPLUNGERS; i++) {
+		w->barrel.tileOfPosition[(2 * i + 1) * w->barrel.tiles] =
+			inc++;
+		w->barrel.tileOfPosition[(2 * i + 2) * w->barrel.tiles - 1] =
+			inc++;
+	}
+	FlushMoves(w);
+	w->barrel.currentRef = -w->barrel.tileFaces;
+	w->barrel.started = False;
+}
+
 static void
 GetTiles(BarrelWidget w)
 {
@@ -1802,7 +1897,7 @@ UndoTiles(BarrelWidget w)
 
 		GetMove(&direction, &tile, &shift);
 		direction = (direction + COORD / 2) % COORD;
-		if (shift && (direction == TOP || direction == BOTTOM)) {
+		if (shift != 0 && (direction == TOP || direction == BOTTOM)) {
 			MoveShift(w, direction, DOUBLE);
 		} else if (MoveTilesDir(w, direction, tile, False, DOUBLE)) {
 			SetBarrel(w, BARREL_UNDO);
@@ -1854,9 +1949,13 @@ RandomizeTiles(BarrelWidget w)
 			}
 			if ((randomDirection + COORD / 2) % COORD != lastDirection) {
 				if ((randomDirection & 1) == 1) {
-					(void) MoveBarrel(w, randomDirection, w->barrel.tiles - 1, FALSE, INSTANT);
+					(void) MoveBarrel(w, randomDirection,
+						w->barrel.tiles - 1, FALSE,
+						False, INSTANT);
 				} else {
-					(void) MoveBarrel(w, randomDirection, NRAND(w->barrel.tiles - 2) + 1, FALSE, INSTANT);
+					(void) MoveBarrel(w, randomDirection,
+						NRAND(w->barrel.tiles - 2) + 1,
+						FALSE, False, INSTANT);
 				}
 #ifdef DEBUG
 				sleep(1);
@@ -2211,7 +2310,7 @@ SetAllColors(BarrelWidget w)
 	for (face = 0; face < MAXCOLORS; face++)
 		GetColor(w, face);
 	if (w->barrel.fontInfo) {
-                XSetFont(XtDisplay(w), w->barrel.tileGC,
+		XSetFont(XtDisplay(w), w->barrel.tileGC,
 			w->barrel.fontInfo->fid);
 	}
 }
@@ -2489,8 +2588,8 @@ ResizeBarrel(BarrelWidget w)
 	w->barrel.delta.y = 1;
 	w->barrel.offset.x = MAX(((int) w->core.width - 2) /
 		w->barrel.tiles, 0);
-	w->barrel.offset.y = MAX(((int) w->core.height /
-		w->barrel.faces - 2), 0);
+	w->barrel.offset.y = MAX((int) w->core.height /
+		w->barrel.faces - 2, 0);
 	w->barrel.faceSize.x = w->barrel.offset.x * w->barrel.tiles +
 		w->barrel.delta.x + 2;
 	w->barrel.faceSize.y = w->barrel.offset.y + w->barrel.delta.y + 2;
@@ -2616,12 +2715,93 @@ SelectBarrel(BarrelWidget w
 	int shift = (int) (event->xkey.state & (ShiftMask | LockMask));
 #endif
 
+	w->barrel.motion = False;
+	w->barrel.motionDiff = 0;
+	w->barrel.shiftDiff = 0;
 	pos = SelectTiles(w, x, y, &i, &j);
 	if (-w->barrel.tileFaces != pos) {
 		w->barrel.currentTile = i;
 		w->barrel.currentFace = j;
 		w->barrel.currentRef = pos;
-		if (shift || w->barrel.practice || !CheckSolved(w)) {
+		if (shift != 0 || w->barrel.practice || !CheckSolved(w)) {
+			pos = w->barrel.currentTile + w->barrel.currentFace * w->barrel.tiles;
+			DrawTile(w, pos, (w->barrel.tileOfPosition[i + j * w->barrel.tiles] < 0),
+				 False, TRUE, 0, 0);
+		}
+	} else
+		w->barrel.currentRef = -w->barrel.tileFaces;
+}
+
+#ifndef WINVER
+static
+#endif
+void
+MotionBarrel(BarrelWidget w
+#ifdef WINVER
+, const int x, const int y, const int shift
+#else
+, XEvent * event, char **args, int nArgs
+#endif
+)
+{
+	int i, j, pos, diff;
+#ifndef WINVER
+	int x = event->xbutton.x, y = event->xbutton.y;
+	int shift = (int) (event->xkey.state & (ShiftMask | LockMask));
+#endif
+
+	if (w->barrel.currentRef == -w->barrel.tileFaces)
+		return;
+	if (shift == 0 && !w->barrel.practice && CheckSolved(w)) {
+		MoveNoTiles(w);
+		w->barrel.currentRef = -w->barrel.tileFaces;
+		return;
+	}
+	pos = SelectTiles(w, x, y, &i, &j);
+	if (w->barrel.currentTile != i) {
+		int k =  w->barrel.currentTile +
+			w->barrel.currentFace * w->barrel.tiles;
+
+		DrawTile(w, k, True, True, TRUE, 0, 0);
+		DrawTile(w, k, (w->barrel.tileOfPosition[k] <= 0),
+			(w->barrel.tileOfPosition[k] <= 0), FALSE, 0, 0);
+		DiffRecord(w, w->barrel.motionDiff, j, FALSE);
+		DiffRecord(w, w->barrel.shiftDiff, j, TRUE);
+		if (shift != 0 && CheckSolved(w)) {
+			SetBarrel(w, BARREL_SOLVED);
+		}
+		w->barrel.currentTile = i;
+		w->barrel.currentFace = j;
+		w->barrel.currentRef = pos;
+		w->barrel.motionDiff = 0;
+		w->barrel.shiftDiff = 0;
+	}
+	if (-w->barrel.tileFaces != pos) {
+		if (j != w->barrel.currentFace) {
+			if (shift != 0 && (w->barrel.currentTile == 0 ||
+					w->barrel.currentTile == w->barrel.tiles - 1)) {
+				w->barrel.currentRef = -w->barrel.tileFaces;
+				return;
+			}
+			diff = (w->barrel.currentFace - j +
+				w->barrel.faces) % w->barrel.faces;
+			DiffMove(w, diff, j, shift);
+			if (shift != 0 && CheckSolved(w)) {
+				SetBarrel(w, BARREL_SOLVED);
+			}
+			w->barrel.motion = True;
+			if (shift == 0)
+				w->barrel.motionDiff = (diff +
+					w->barrel.motionDiff) %
+					w->barrel.faces;
+			else
+				w->barrel.shiftDiff = (diff +
+					w->barrel.shiftDiff) % w->barrel.faces;
+		}
+		w->barrel.currentTile = i;
+		w->barrel.currentFace = j;
+		w->barrel.currentRef = pos;
+		if (shift != 0 || w->barrel.practice || !CheckSolved(w)) {
 			pos = w->barrel.currentTile + w->barrel.currentFace * w->barrel.tiles;
 			DrawTile(w, pos, (w->barrel.tileOfPosition[i + j * w->barrel.tiles] < 0),
 				 False, TRUE, 0, 0);
@@ -2655,14 +2835,14 @@ ReleaseBarrel(BarrelWidget w
 	if (w->barrel.tileOfPosition[pos] > 0) {
 		DrawTile(w, pos, False, False, FALSE, 0, 0);
 	}
-	if (!shift && !w->barrel.practice && CheckSolved(w)) {
+	if (shift == 0 && !w->barrel.practice && CheckSolved(w)) {
 		MoveNoTiles(w);
 		w->barrel.currentRef = -w->barrel.tileFaces;
 		return;
 	}
 	pos = SelectTiles(w, x, y, &i, &j);
 	if (-w->barrel.tileFaces != pos) {
-		if (j == w->barrel.currentFace) {
+		if (j == w->barrel.currentFace && !w->barrel.motion) {
 			if ((w->barrel.spacePosition[0] % w->barrel.tiles) == 0)
 				diff = w->barrel.tiles - 1;
 			else
@@ -2672,20 +2852,24 @@ ReleaseBarrel(BarrelWidget w
 				SetBarrel(w, BARREL_SOLVED);
 			}
 		} else {
-			if (!shift && (w->barrel.currentTile == 0 ||
+			if (shift == 0 && (w->barrel.currentTile == 0 ||
 					w->barrel.currentTile == w->barrel.tiles - 1)) {
 				w->barrel.currentRef = -w->barrel.tileFaces;
 				return;
 			}
 			diff = (w->barrel.currentFace - j + w->barrel.faces) %
 				w->barrel.faces;
-			if (diff > w->barrel.faces / 2)
-				for (i = 0; i < w->barrel.faces - diff; i++)
-					(void) MoveBarrel(w, BOTTOM, w->barrel.currentTile, shift, NORMAL);
+			DiffMove(w, diff, j, shift);
+			if (shift == 0)
+				w->barrel.motionDiff = (diff +
+					w->barrel.motionDiff) %
+					w->barrel.faces;
 			else
-				for (i = 0; i < diff; i++)
-					(void) MoveBarrel(w, TOP, w->barrel.currentTile, shift, NORMAL);
-			if (!shift && CheckSolved(w)) {
+				w->barrel.shiftDiff = (diff +
+					w->barrel.shiftDiff) % w->barrel.faces;
+			DiffRecord(w, w->barrel.motionDiff, j, FALSE);
+			DiffRecord(w, w->barrel.shiftDiff, j, TRUE);
+			if (shift == 0 && CheckSolved(w)) {
 				SetBarrel(w, BARREL_SOLVED);
 			}
 		}
@@ -2947,6 +3131,13 @@ MoveBarrelTop(BarrelWidget w, XEvent * event, char **args, int nArgs)
 		(int) (event->xkey.state & (ShiftMask | LockMask)));
 }
 
+static void
+MoveBarrelBottom(BarrelWidget w, XEvent * event, char **args, int nArgs)
+{
+	MoveBarrelInput(w, event->xbutton.x, BOTTOM,
+		(int) (event->xkey.state & (ShiftMask | LockMask)));
+}
+
 static void
 MoveBarrelLeft(BarrelWidget w, XEvent * event, char **args, int nArgs)
 {
@@ -2960,11 +3151,4 @@ MoveBarrelRight(BarrelWidget w, XEvent * event, char **args, int nArgs)
 	MoveBarrelInput(w, event->xbutton.x, RIGHT,
 		(int) (event->xkey.state & (ShiftMask | LockMask)));
 }
-
-static void
-MoveBarrelBottom(BarrelWidget w, XEvent * event, char **args, int nArgs)
-{
-	MoveBarrelInput(w, event->xbutton.x, BOTTOM,
-		(int) (event->xkey.state & (ShiftMask | LockMask)));
-}
 #endif
