@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 2003 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 2003 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -93,7 +93,7 @@ static HWND Wnd;
 
 #ifdef HAVE_MOTIF
 static const char aboutHelp[] = {
-	"Version 7.1.1\n"
+	"Version 7.1.3\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
@@ -116,7 +116,7 @@ static const char descriptionHelp[] = {
 	"seen as the Cylinder Puzzle of Japanese origin.  The puzzle\n"
 	"contains 23 beads of 6 different colors.  4 each of 5 "
 	"different colors arranged in 5 rows and 3 black beads making\n"
-	"3 rows one unit longer.  A system of plugers slide all "
+	"3 rows one unit longer.  A system of plungers slide all "
 	"three of the long rows left and right.  Two of the plungers\n"
 	"sit together and the other (the middle plunger) is "
 	"separate from the other two.  There are 2 separate wheels or\n"
@@ -156,7 +156,7 @@ static const char featuresHelp[] = {
 	"\n"
 	"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
 	"\n"
-	"Press \"@\" or \"2\" keys to toggle the sound.\n"
+	"Press \"@\" key to toggle the sound.\n"
 	"\n"
 	"Press \"Esc\" key to hide program.\n"
 	"\n"
@@ -839,6 +839,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 {
 	HBRUSH brush = (HBRUSH) NULL;
 	PAINTSTRUCT paint;
+	static Boolean mousePressed = False;
 
 	Wnd = widget.core.hWnd = hWnd;
 	if (GetFocus()) {
@@ -880,19 +881,61 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case WM_LBUTTONDOWN:
+			mousePressed = True;
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
 			SelectBarrel(&widget, LOWORD(lParam), HIWORD(lParam),
 				((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)));
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
+		case WM_MOUSEMOVE:
+			if (!(wParam & MK_LBUTTON)) {
+				if (mousePressed) {
+					mousePressed = False;
+					widget.core.hDC = GetDC(hWnd);
+					(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
+					ReleaseBarrel(&widget, LOWORD(lParam), HIWORD(lParam),
+				((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)));
+					(void) ReleaseDC(hWnd, widget.core.hDC);
+				}
+				break;
+			}
+			widget.core.hDC = GetDC(hWnd);
+			(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
+			MotionBarrel(&widget, LOWORD(lParam), HIWORD(lParam),
+				((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)));
+			(void) ReleaseDC(hWnd, widget.core.hDC);
+			break;
 		case WM_LBUTTONUP:
+			mousePressed = False;
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
 			ReleaseBarrel(&widget, LOWORD(lParam), HIWORD(lParam),
 				((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)));
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
+#if (_WIN32_WINNT >= 0x0400) || (_WIN32_WINDOWS > 0x0400)
+		case WM_MOUSEWHEEL:
+			widget.core.hDC = GetDC(hWnd);
+			(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
+			{
+				int zDelta = ((short) HIWORD(wParam));
+				POINT cursor, origin;
+
+				origin.x = 0, origin.y = 0;
+				ClientToScreen(hWnd, &origin);
+				(void) GetCursorPos(&cursor);
+				if (zDelta > (WHEEL_DELTA >> 1)) {
+					MoveBarrelInput(&widget, cursor.x - origin.x, TOP,
+				((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)));
+				} else if (zDelta < -(WHEEL_DELTA >> 1)) {
+					MoveBarrelInput(&widget, cursor.x - origin.x, BOTTOM,
+				((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)));
+				}
+			}
+			(void) ReleaseDC(hWnd, widget.core.hDC);
+			break;
+#endif
 		case WM_COMMAND:
 			switch LOWORD((wParam)) {
 				case IDM_GET:
@@ -1008,7 +1051,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 
 int WINAPI
 WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
-	int numCmdShow)
+		int numCmdShow)
 {
 	HWND hWnd;
 	MSG msg;
