@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -147,7 +147,6 @@ static char defaultTranslationsCubes[] =
  <KeyPress>0x3E: Speed()\n\
  <KeyPress>0x3C: Slow()\n\
  <KeyPress>0x2C: Slow()\n\
- <KeyPress>2: Sound()\n\
  <KeyPress>@: Sound()\n\
  <EnterWindow>: Enter()\n\
  <LeaveWindow>: Leave()";
@@ -588,18 +587,30 @@ Stack(CubesWidget w, int pos)
 	return (pos / w->cubes.sizeRect);
 }
 
-static void
-Cartesian(CubesWidget w, int pos, int * x, int * y)
+static int
+CartesianX(CubesWidget w, int pos)
 {
-	*x = Column(w, pos) * w->cubes.offset.x + w->cubes.delta.x +
+	int x;
+
+	x = Column(w, pos) * w->cubes.offset.x + w->cubes.delta.x +
 		w->cubes.puzzleOffset.x;
-	*y = Row(w, pos) * w->cubes.offset.y + w->cubes.delta.y +
+	if (!w->cubes.vertical) {
+		x += Stack(w, pos) * (w->cubes.sizeX * w->cubes.offset.x + 1);
+	}
+	return x;
+}
+
+static int
+CartesianY(CubesWidget w, int pos)
+{
+	int y;
+
+	y = Row(w, pos) * w->cubes.offset.y + w->cubes.delta.y +
 		w->cubes.puzzleOffset.y;
 	if (w->cubes.vertical) {
-		*y += Stack(w, pos) * (w->cubes.sizeY * w->cubes.offset.y + 1);
-	} else {
-		*x += Stack(w, pos) * (w->cubes.sizeX * w->cubes.offset.x + 1);
+		y += Stack(w, pos) * (w->cubes.sizeY * w->cubes.offset.y + 1);
 	}
+	return y;
 }
 
 static int
@@ -737,10 +748,10 @@ DrawBlock(CubesWidget w, int pos, Boolean blank, Boolean erase,
 		w->cubes.sizeBlock;
 	Pixmap dr = 0;
 
-	Cartesian(w, pos, &dx, &dy);
-	dx += offsetX + pressedOffset;
-	dy += offsetY + pressedOffset;
-	Cartesian(w, block, &sx, &sy);
+	dx = CartesianX(w, pos) + offsetX + pressedOffset;
+	dy = CartesianY(w, pos) + offsetY + pressedOffset;
+	sx = CartesianX(w, block);
+	sy = CartesianY(w, block);
 	if (blank) {
 		FILLRECTANGLE(w, dr,
 			(erase) ? w->cubes.inverseGC : w->cubes.blockGC,
@@ -780,10 +791,10 @@ DrawBlockPiece(CubesWidget w, int pos, Boolean blank, Boolean erase,
 		w->cubes.sizeBlock;
 	Pixmap dr = 0;
 
-	Cartesian(w, pos, &dx, &dy);
-	dx += offsetX + pressedOffset;
-	dy += offsetY + pressedOffset;
-	Cartesian(w, block, &sx, &sy);
+	dx = CartesianX(w, pos) + offsetX + pressedOffset;
+	dy = CartesianY(w, pos) + offsetY + pressedOffset;
+	sx = CartesianX(w, block);
+	sy = CartesianY(w, block);
 	if (blank) {
 		FILLRECTANGLE(w, dr,
 			(erase) ? w->cubes.inverseGC : w->cubes.blockGC,
@@ -815,7 +826,6 @@ DrawBlockPiece(CubesWidget w, int pos, Boolean blank, Boolean erase,
 
 static void
 DrawBufferedBlock(CubesWidget w, int pos, int pressedOffset)
-
 {
 	Pixmap *dr;
 	GC blockGC, borderGC;
@@ -826,9 +836,8 @@ DrawBufferedBlock(CubesWidget w, int pos, int pressedOffset)
 	dr = &(w->cubes.bufferBlocks[pressedOffset]);
 	blockGC = w->cubes.blockGC;
 	borderGC = w->cubes.borderGC;
-	Cartesian(w, pos, &dx, &dy);
-	dx += pressedOffset;
-	dy += pressedOffset;
+	dx = CartesianX(w, pos) + pressedOffset;
+	dy = CartesianY(w, pos) + pressedOffset;
 	if (pressedOffset != 0) {
 		drawShadow(w, *dr, w->cubes.blockDarkerGC,
 			dx - pressedOffset, dy - pressedOffset,
@@ -850,16 +859,6 @@ DrawBufferedBlock(CubesWidget w, int pos, int pressedOffset)
 		buf, i);
 }
 
-static void
-DrawAllBufferedBlocks(const CubesWidget w)
-{
-	int k, l;
-
-	for (k = 0; k < w->cubes.sizeBlock; k++)
-		for (l = 0; l < 2; l++)
-			DrawBufferedBlock(w, k, l);
-}
-
 void
 DrawAllBlocks(const CubesWidget w)
 {
@@ -870,6 +869,16 @@ DrawAllBlocks(const CubesWidget w)
 			(w->cubes.blockOfPosition[k] <= 0), FALSE, 0, 0);
 }
 
+static void
+DrawAllBufferedBlocks(const CubesWidget w)
+{
+	int k, l;
+
+	for (k = 0; k < w->cubes.sizeBlock; k++)
+		for (l = 0; l < 2; l++)
+			DrawBufferedBlock(w, k, l);
+}
+
 static void
 DrawBlockFrame(CubesWidget w, int xR, int yR, int wR, int hR, int incAt)
 {
@@ -904,11 +913,11 @@ AnimateSlide(CubesWidget w, int numBlocks, int dir, int fast, Boolean logMoves)
 
 	fillBeginPos = BlockNFromSpace(w, numBlocks, dir);
 	if ((dir == RIGHT) || (dir == LEFT)) {
-	        Cartesian(w, fillBeginPos, &fillBeginI, &dy);
+		fillBeginI = CartesianX(w, fillBeginPos);
 		gapI = w->cubes.blockSize.x * fast / w->cubes.numSlices;
 		moveI = w->cubes.blockSize.x + w->cubes.delta.x;
 	} else if ((dir == TOP) || (dir == BOTTOM)) {
-	        Cartesian(w, fillBeginPos, &dx, &fillBeginI);
+		fillBeginI = CartesianY(w, fillBeginPos);
 		gapI = w->cubes.blockSize.y * fast / w->cubes.numSlices;
 		moveI = w->cubes.blockSize.y + w->cubes.delta.y;
 	}
@@ -927,7 +936,8 @@ AnimateSlide(CubesWidget w, int numBlocks, int dir, int fast, Boolean logMoves)
 	      PutMove(dir);
 	    }
 	    /* Calculate deltas */
-	    Cartesian(w, posNext, &dx, &dy);
+	    dx = CartesianX(w, posNext);
+	    dy = CartesianY(w, posNext);
 	    if ((dir == RIGHT) || (dir == LEFT)) {
 	      ix = ((dir == RIGHT) ? inc : -inc);
 	      iy = 0;
@@ -941,55 +951,57 @@ AnimateSlide(CubesWidget w, int numBlocks, int dir, int fast, Boolean logMoves)
 	    iy += dy;
 	    if (aBlock < numBlocks - 1) {
 	      switch (dir) {
-		case TOP:
-		  FILLRECTANGLE(w, dr,
-		    w->cubes.inverseGC,
-		    ix, iy + w->cubes.blockSize.y,
-		    w->cubes.blockSize.x, gapI);
-		  break;
-		case RIGHT:
-		  FILLRECTANGLE(w, dr,
-		    w->cubes.inverseGC,
-		    ix - gapI, iy, gapI, w->cubes.blockSize.y);
-		  break;
-		case BOTTOM:
-		  FILLRECTANGLE(w, dr,
-		    w->cubes.inverseGC,
-		    ix, iy - gapI, w->cubes.blockSize.x, gapI);
-		  break;
-		case LEFT:
-		  FILLRECTANGLE(w, dr,
-		    w->cubes.inverseGC,
-		    ix + w->cubes.blockSize.x, iy,
-		    gapI, w->cubes.blockSize.y);
-		  break;
+	      case TOP:
+		FILLRECTANGLE(w, dr,
+		  w->cubes.inverseGC,
+		  ix, iy + w->cubes.blockSize.y,
+		  w->cubes.blockSize.x, gapI);
+		break;
+	      case RIGHT:
+		FILLRECTANGLE(w, dr,
+		  w->cubes.inverseGC,
+		  ix - gapI,
+		  iy, gapI, w->cubes.blockSize.y);
+		break;
+	      case BOTTOM:
+		FILLRECTANGLE(w, dr,
+		  w->cubes.inverseGC,
+		  ix, iy - gapI,
+		  w->cubes.blockSize.x, gapI);
+		break;
+	      case LEFT:
+		FILLRECTANGLE(w, dr,
+		  w->cubes.inverseGC,
+		  ix + w->cubes.blockSize.x, iy,
+		  gapI, w->cubes.blockSize.y);
+		break;
 	      }
 	    } else {
 	      switch (dir) {
-		case TOP:
-		  FILLRECTANGLE(w, dr,
-		    w->cubes.inverseGC,
-		    ix, iy + w->cubes.blockSize.y,
-		    w->cubes.blockSize.x, fillBeginI - iy);
-		  break;
-		case RIGHT:
-		  FILLRECTANGLE(w, dr,
-		    w->cubes.inverseGC,
-		    fillBeginI, iy,
-		    ix - fillBeginI, w->cubes.blockSize.y);
-		  break;
-		case BOTTOM:
-		  FILLRECTANGLE(w, dr,
-		    w->cubes.inverseGC,
-		    ix, fillBeginI,
-		    w->cubes.blockSize.x, iy - fillBeginI);
-		  break;
-		case LEFT:
-		  FILLRECTANGLE(w, dr,
-		    w->cubes.inverseGC,
-		    ix + w->cubes.blockSize.x, iy,
-		    fillBeginI - ix, w->cubes.blockSize.y);
-		 break;
+	      case TOP:
+		FILLRECTANGLE(w, dr,
+		  w->cubes.inverseGC,
+		  ix, iy + w->cubes.blockSize.y,
+		  w->cubes.blockSize.x, fillBeginI - iy);
+		break;
+	      case RIGHT:
+		FILLRECTANGLE(w, dr,
+		  w->cubes.inverseGC,
+		  fillBeginI, iy,
+		  ix - fillBeginI, w->cubes.blockSize.y);
+		break;
+	      case BOTTOM:
+		FILLRECTANGLE(w, dr,
+		  w->cubes.inverseGC,
+		  ix, fillBeginI,
+		  w->cubes.blockSize.x, iy - fillBeginI);
+		break;
+	      case LEFT:
+		FILLRECTANGLE(w, dr,
+		  w->cubes.inverseGC,
+		  ix + w->cubes.blockSize.x, iy,
+		  fillBeginI - ix, w->cubes.blockSize.y);
+		break;
 	      }
 	    }
 	  }
@@ -997,10 +1009,10 @@ AnimateSlide(CubesWidget w, int numBlocks, int dir, int fast, Boolean logMoves)
 	}
 	pos = w->cubes.spacePosition;
 	for (aBlock = 0; aBlock < numBlocks; aBlock++) {
-	    posNext = BlockNFromSpace(w, aBlock + 1, dir);
-	    w->cubes.blockOfPosition[pos] =
-	      w->cubes.blockOfPosition[posNext];
-	    pos = posNext;
+	  posNext = BlockNFromSpace(w, aBlock + 1, dir);
+	  w->cubes.blockOfPosition[pos] =
+	    w->cubes.blockOfPosition[posNext];
+	  pos = posNext;
 	}
 	w->cubes.spacePosition = fillBeginPos;
 	w->cubes.blockOfPosition[fillBeginPos] = 0;
@@ -1010,13 +1022,15 @@ static void
 AnimateMove(CubesWidget w, int fromPos, int fast)
 {
 	int pos = w->cubes.spacePosition;
-	int dx, dy, fromdx, fromdy;
+	int dx, dy, fx, fy;
 	int xToCenter, yToCenter;
 	int incTo, incAt, inc;
 	Pixmap dr = 0;
 
-	Cartesian(w, pos, &dx, &dy);
-	Cartesian(w, fromPos, &fromdx, &fromdy);
+	dx = CartesianX(w, pos);
+	dy = CartesianY(w, pos);
+	fx = CartesianX(w, fromPos);
+	fy = CartesianY(w, fromPos);
 	xToCenter = w->cubes.blockSize.x / 2;
 	yToCenter = w->cubes.blockSize.y / 2;
 	incTo = MIN(w->cubes.blockSize.x, w->cubes.blockSize.y) / 2;
@@ -1024,21 +1038,21 @@ AnimateMove(CubesWidget w, int fromPos, int fast)
 
 	FILLRECTANGLE(w, dr,
 		w->cubes.inverseGC,
-		fromdx, fromdy, incAt, w->cubes.blockSize.y);
+		fx, fy, incAt, w->cubes.blockSize.y);
 	FILLRECTANGLE(w, dr,
 		w->cubes.inverseGC,
-		fromdx, fromdy, w->cubes.blockSize.x, incAt);
+		fx, fy, w->cubes.blockSize.x, incAt);
 	FILLRECTANGLE(w, dr,
 		w->cubes.inverseGC,
-		fromdx + w->cubes.blockSize.x - incAt, fromdy,
+		fx + w->cubes.blockSize.x - incAt, fy,
 		incAt, w->cubes.blockSize.y);
 	FILLRECTANGLE(w, dr,
 		w->cubes.inverseGC,
-		fromdx, fromdy + w->cubes.blockSize.y - incAt,
+		fx, fy + w->cubes.blockSize.y - incAt,
 		w->cubes.blockSize.x, incAt);
 	initTimer(w);
 	for (inc = incAt; inc < incTo; inc += incAt) {
-		int xR = fromdx + inc, yR = fromdy + inc;
+		int xR = fx + inc, yR = fy + inc;
 		int wR = w->cubes.blockSize.x - 2 * inc;
 		int hR = w->cubes.blockSize.y - 2 * inc;
 
@@ -1123,36 +1137,6 @@ AnimateMove(CubesWidget w, int fromPos, int fast)
 	w->cubes.spacePosition = fromPos;
 }
 
-static void
-ResetBlocks(CubesWidget w)
-{
-	int i;
-
-	w->cubes.sizeRect = w->cubes.sizeX * w->cubes.sizeY;
-	w->cubes.sizeBlock = w->cubes.sizeRect * w->cubes.sizeZ;
-	if (w->cubes.blockOfPosition)
-		free((void *) w->cubes.blockOfPosition);
-	if (!(w->cubes.blockOfPosition = (int *)
-			malloc(sizeof (int) * w->cubes.sizeBlock))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-
-	if (startPosition)
-		free((void *) startPosition);
-	if (!(startPosition = (int *)
-			malloc(sizeof (int) * w->cubes.sizeBlock))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-
-	w->cubes.spacePosition = w->cubes.sizeBlock - 1;
-	w->cubes.blockOfPosition[w->cubes.sizeBlock - 1] = 0;
-	for (i = 1; i < w->cubes.sizeBlock; i++)
-		w->cubes.blockOfPosition[i - 1] = i;
-	FlushMoves(w);
-	w->cubes.currentPosition = -1;
-	w->cubes.started = False;
-}
-
 static void
 EraseFrame(const CubesWidget w, Pixmap dr)
 {
@@ -1596,100 +1580,33 @@ SelectBlocks(CubesWidget w)
 }
 
 static void
-RandomizeBlocks(CubesWidget w)
+ResetBlocks(CubesWidget w)
 {
-	if (w->cubes.currentPosition >= 0)
-		return;
-	w->cubes.cheat = False;
-	/* First interchange blocks an even number of times */
-	/* Must be at least 3x2 or 2x2x2 */
-	if ((w->cubes.sizeX > 2 && (w->cubes.sizeY > 1 || w->cubes.sizeZ > 1)) ||
-			(w->cubes.sizeY > 2 && (w->cubes.sizeX > 1 || w->cubes.sizeZ > 1)) ||
-			(w->cubes.sizeZ > 2 && (w->cubes.sizeX > 1 || w->cubes.sizeY > 1)) ||
-			(w->cubes.sizeX == 2 && w->cubes.sizeY == 2 && w->cubes.sizeZ == 2)) {
-		int pos, count = 0;
+	int i;
 
-		for (pos = 0; pos < w->cubes.sizeBlock; pos++) {
-			int randomPos = pos;
+	w->cubes.sizeRect = w->cubes.sizeX * w->cubes.sizeY;
+	w->cubes.sizeBlock = w->cubes.sizeRect * w->cubes.sizeZ;
+	if (w->cubes.blockOfPosition)
+		free((void *) w->cubes.blockOfPosition);
+	if (!(w->cubes.blockOfPosition = (int *)
+			malloc(sizeof (int) * w->cubes.sizeBlock))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
 
-			while (randomPos == pos) {
-				randomPos = NRAND(w->cubes.sizeBlock);
-			}
-			count += ExchangeBlocks(w, pos, randomPos);
-		}
-		if ((count & 1) &&
-				!ExchangeBlocks(w, 0, 1) &&
-				!ExchangeBlocks(w, w->cubes.sizeBlock - 2,
-				w->cubes.sizeBlock - 1)) {
-			DISPLAY_WARNING("RandomizeBlocks: should not get here");
-		}
-		DrawAllBlocks(w);
-#ifndef WINVER
-		XFlush(XtDisplay(w));
-#endif
+	if (startPosition)
+		free((void *) startPosition);
+	if (!(startPosition = (int *)
+			malloc(sizeof (int) * w->cubes.sizeBlock))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
 	}
-	/* randomly position space */
-	/* Idea for this came from "puzzle" by Don Bennett, HP Labs */
-	{
-		int n, s, e;
 
-		s = Column(w, w->cubes.spacePosition);
-		e = NRAND(w->cubes.sizeX);
-		for (n = 0; n < e - s; n++)
-			(void) MoveCubesDir(w, LEFT, INSTANT);
-		for (n = 0; n < s - e; n++)
-			(void) MoveCubesDir(w, RIGHT, INSTANT);
-		s = Row(w, w->cubes.spacePosition);
-		e = NRAND(w->cubes.sizeY);
-		for (n = 0; n < e - s; n++)
-			(void) MoveCubesDir(w, TOP, INSTANT);
-		for (n = 0; n < s - e; n++)
-			(void) MoveCubesDir(w, BOTTOM, INSTANT);
-		s = Stack(w, w->cubes.spacePosition);
-		e = NRAND(w->cubes.sizeZ);
-		for (n = 0; n < e - s; n++)
-			(void) MoveCubesDir(w, OUTWARDS, INSTANT);
-		for (n = 0; n < s - e; n++)
-			(void) MoveCubesDir(w, INWARDS, INSTANT);
-		FlushMoves(w);
-		SetCubes(w, CUBES_RANDOMIZE);
-	}
-#if 0
-	/* Now move the space around randomly */
-	if (w->cubes.sizeX > 1 || w->cubes.sizeY > 1 || w->cubes.sizeZ > 1) {
-		int big = w->cubes.sizeBlock + NRAND(2);
-		int lastDirection = -1;
-		int randomDirection;
-
-		SetCubes(w, CUBES_RESET);
-#ifdef DEBUG
-		big = 3;
-#endif
-		if (big > 1000)
-			big = 1000;
-		while (big--) {
-			randomDirection = NRAND(COORD);
-#ifdef DEBUG
-			Sleep(1);
-#endif
-			if ((randomDirection < 4 && (randomDirection + 2) % 4 != lastDirection) ||
-			    (randomDirection >= 4 && randomDirection + ((randomDirection % 2) ? -1 : 1) != lastDirection) ||
-			    (w->cubes.sizeX == 1 && w->cubes.sizeY == 1) ||
-			    (w->cubes.sizeY == 1 && w->cubes.sizeZ == 1) ||
-			    (w->cubes.sizeZ == 1 && w->cubes.sizeX == 1)) {
-				if (MoveCubesDir(w, randomDirection, INSTANT))
-					lastDirection = randomDirection;
-				else
-					big++;
-			}
-		}
-		FlushMoves(w);
-		SetCubes(w, CUBES_RANDOMIZE);
-	}
-#endif
-	if (CheckSolved(w)) {
-		SetCubes(w, CUBES_SOLVED);
-	}
+	w->cubes.spacePosition = w->cubes.sizeBlock - 1;
+	w->cubes.blockOfPosition[w->cubes.sizeBlock - 1] = 0;
+	for (i = 1; i < w->cubes.sizeBlock; i++)
+		w->cubes.blockOfPosition[i - 1] = i;
+	FlushMoves(w);
+	w->cubes.currentPosition = -1;
+	w->cubes.started = False;
 }
 
 static void
@@ -1906,6 +1823,103 @@ UndoBlocks(CubesWidget w)
 	}
 }
 
+static void
+RandomizeBlocks(CubesWidget w)
+{
+	if (w->cubes.currentPosition >= 0)
+		return;
+	w->cubes.cheat = False;
+	/* First interchange blocks an even number of times */
+	/* Must be at least 3x2 or 2x2x2 */
+	if ((w->cubes.sizeX > 2 && (w->cubes.sizeY > 1 || w->cubes.sizeZ > 1)) ||
+			(w->cubes.sizeY > 2 && (w->cubes.sizeX > 1 || w->cubes.sizeZ > 1)) ||
+			(w->cubes.sizeZ > 2 && (w->cubes.sizeX > 1 || w->cubes.sizeY > 1)) ||
+			(w->cubes.sizeX == 2 && w->cubes.sizeY == 2 && w->cubes.sizeZ == 2)) {
+		int pos, count = 0;
+
+		for (pos = 0; pos < w->cubes.sizeBlock; pos++) {
+			int randomPos = pos;
+
+			while (randomPos == pos) {
+				randomPos = NRAND(w->cubes.sizeBlock);
+			}
+			count += ExchangeBlocks(w, pos, randomPos);
+		}
+		if ((count & 1) &&
+				!ExchangeBlocks(w, 0, 1) &&
+				!ExchangeBlocks(w, w->cubes.sizeBlock - 2,
+				w->cubes.sizeBlock - 1)) {
+			DISPLAY_WARNING("RandomizeBlocks: should not get here");
+		}
+		DrawAllBlocks(w);
+#ifndef WINVER
+		XFlush(XtDisplay(w));
+#endif
+	}
+	/* randomly position space */
+	/* Idea for this came from "puzzle" by Don Bennett, HP Labs */
+	{
+		int n, s, e;
+
+		s = Column(w, w->cubes.spacePosition);
+		e = NRAND(w->cubes.sizeX);
+		for (n = 0; n < e - s; n++)
+			(void) MoveCubesDir(w, LEFT, INSTANT);
+		for (n = 0; n < s - e; n++)
+			(void) MoveCubesDir(w, RIGHT, INSTANT);
+		s = Row(w, w->cubes.spacePosition);
+		e = NRAND(w->cubes.sizeY);
+		for (n = 0; n < e - s; n++)
+			(void) MoveCubesDir(w, TOP, INSTANT);
+		for (n = 0; n < s - e; n++)
+			(void) MoveCubesDir(w, BOTTOM, INSTANT);
+		s = Stack(w, w->cubes.spacePosition);
+		e = NRAND(w->cubes.sizeZ);
+		for (n = 0; n < e - s; n++)
+			(void) MoveCubesDir(w, OUTWARDS, INSTANT);
+		for (n = 0; n < s - e; n++)
+			(void) MoveCubesDir(w, INWARDS, INSTANT);
+		FlushMoves(w);
+		SetCubes(w, CUBES_RANDOMIZE);
+	}
+#if 0
+	/* Now move the space around randomly */
+	if (w->cubes.sizeX > 1 || w->cubes.sizeY > 1 || w->cubes.sizeZ > 1) {
+		int big = w->cubes.sizeBlock + NRAND(2);
+		int lastDirection = -1;
+		int randomDirection;
+
+		SetCubes(w, CUBES_RESET);
+#ifdef DEBUG
+		big = 3;
+#endif
+		if (big > 1000)
+			big = 1000;
+		while (big--) {
+			randomDirection = NRAND(COORD);
+#ifdef DEBUG
+			Sleep(1);
+#endif
+			if ((randomDirection < 4 && (randomDirection + 2) % 4 != lastDirection) ||
+			    (randomDirection >= 4 && randomDirection + ((randomDirection % 2) ? -1 : 1) != lastDirection) ||
+			    (w->cubes.sizeX == 1 && w->cubes.sizeY == 1) ||
+			    (w->cubes.sizeY == 1 && w->cubes.sizeZ == 1) ||
+			    (w->cubes.sizeZ == 1 && w->cubes.sizeX == 1)) {
+				if (MoveCubesDir(w, randomDirection, INSTANT))
+					lastDirection = randomDirection;
+				else
+					big++;
+			}
+		}
+		FlushMoves(w);
+		SetCubes(w, CUBES_RANDOMIZE);
+	}
+#endif
+	if (CheckSolved(w)) {
+		SetCubes(w, CUBES_SOLVED);
+	}
+}
+
 static void
 SolveBlocks(CubesWidget w)
 {
@@ -2291,9 +2305,9 @@ DestroyCubes(Widget old)
 	CubesWidget w = (CubesWidget) old;
 
 	XtReleaseGC(old, w->cubes.blockGC);
+	XtReleaseGC(old, w->cubes.borderGC);
 	XtReleaseGC(old, w->cubes.blockBrighterGC);
 	XtReleaseGC(old, w->cubes.blockDarkerGC);
-	XtReleaseGC(old, w->cubes.borderGC);
 	XtReleaseGC(old, w->cubes.frameGC);
 	XtReleaseGC(old, w->cubes.inverseGC);
 	XtRemoveCallbacks(old, XtNselectCallback, w->cubes.select);
@@ -2484,9 +2498,9 @@ Widget request, Widget renew
 	w->cubes.oldColormap = None;
 	w->cubes.fontInfo = NULL;
 	w->cubes.blockGC = NULL;
+	w->cubes.borderGC = NULL;
 	w->cubes.blockBrighterGC = NULL;
 	w->cubes.blockDarkerGC = NULL;
-	w->cubes.borderGC = NULL;
 	w->cubes.frameGC = NULL;
 	w->cubes.inverseGC = NULL;
 #endif
