@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -158,7 +158,6 @@ static char defaultTranslationsHexagons[] =
  <KeyPress>0x3E: Speed()\n\
  <KeyPress>0x3C: Slow()\n\
  <KeyPress>0x2C: Slow()\n\
- <KeyPress>2: Sound()\n\
  <KeyPress>@: Sound()\n\
  <EnterWindow>: Enter()\n\
  <LeaveWindow>: Leave()";
@@ -643,15 +642,18 @@ TlBr(HexagonsWidget w, const int pos, const int posRow)
 		(2 * w->hexagons.sizeY + w->hexagons.sizeX - posRow - 2) / 2);
 }
 
-static void
-Cartesian(HexagonsWidget w, int pos, int * x, int * y)
+static int
+CartesianX(HexagonsWidget w, int pos, int row)
 {
-	int k = Row(w, pos);
-
-	*x = w->hexagons.tileSize.x / 4 - 1 + (2 * TrBl(w, pos, k) +
-		w->hexagons.sizeY - k) * w->hexagons.offset.x / 2 - 2 +
+	return w->hexagons.tileSize.x / 4 - 1 + (2 * TrBl(w, pos, row) +
+		w->hexagons.sizeY - row) * w->hexagons.offset.x / 2 - 2 +
 		w->hexagons.puzzleOffset.x;
-	*y = k * (3 * w->hexagons.tileSize.y / 2 + w->hexagons.delta.y) +
+}
+
+static int
+CartesianY(HexagonsWidget w, int row)
+{
+	return row * (3 * w->hexagons.tileSize.y / 2 + w->hexagons.delta.y) +
 		w->hexagons.delta.y + w->hexagons.puzzleOffset.y;
 }
 
@@ -688,19 +690,19 @@ CheckSolved(const HexagonsWidget w)
 	int i;
 
 	for (i = 1; i < w->hexagons.sizeSize -
-			((w->hexagons.corners) ? 1 : 0); i++)
+			((w->hexagons.corners) ? CORNERS : NOCORN); i++)
 		if (w->hexagons.tileOfPosition[i - 1] != i)
 			return FALSE;
 	return TRUE;
 }
 
 static Boolean
-bresenhamLine(int x0, int y0, int x1, int y1,
+bresenhamLine(int startX, int startY, int endX, int endY,
 		int * pixX, int * pixY, int * pixNo)
 {
 	int pix = 0;
-	int ex = x1 - x0;
-	int ey = y1 - y0;
+	int ex = endX - startX;
+	int ey = endY - startY;
 	int dx, dy, error;
 
 	(*pixNo)++;
@@ -720,8 +722,8 @@ bresenhamLine(int x0, int y0, int x1, int y1,
 	} else {
 		dy = 0;
 	}
-	*pixX = x0;
-	*pixY = y0;
+	*pixX = startX;
+	*pixY = startY;
 	if (ex > ey) {
 		error = 2 * ey - ex;
 		while (pix != *pixNo) {
@@ -732,12 +734,12 @@ bresenhamLine(int x0, int y0, int x1, int y1,
 			error += 2 * ey;
 			*pixX += dx;
 			pix++;
-			if (*pixX == x1)
+			if (*pixX == endX)
 				return True;
 		}
 		return False;
 	} else {
-		error = 2 * ex -ey;
+		error = 2 * ex - ey;
 		while (pix != *pixNo) {
 			if (error >= 0) {
 				error -= 2 * ey;
@@ -746,7 +748,7 @@ bresenhamLine(int x0, int y0, int x1, int y1,
 			error += 2 * ex;
 			*pixY += dy;
 			pix++;
-			if (*pixY == y1)
+			if (*pixY == endY)
 				return True; 
 		}
 		return False;
@@ -832,7 +834,6 @@ POLYGON(HexagonsWidget w, Pixmap dr, GC color, GC lineColor,
 	if (dr)
 		(void) SelectObject(w->hexagons.memDC,
 			w->hexagons.hOldBitmap);
-
 	if (!origin) {
 		free(temp);
 	}
@@ -1015,7 +1016,7 @@ DrawTile(HexagonsWidget w, int pos, Boolean blank, Boolean erase,
 {
 	Pixmap *dr;
 	Pixmap adr = 0;
-	int dx, dy;
+	int dx, dy, row;
 	int corners = (w->hexagons.corners) ? 1 : 0;
 	GC tileGC, borderGC;
 
@@ -1028,9 +1029,10 @@ DrawTile(HexagonsWidget w, int pos, Boolean blank, Boolean erase,
 		tileGC = w->hexagons.tileGC;
 		borderGC = w->hexagons.borderGC;
 	}
-	Cartesian(w, pos, &dx, &dy);
-	dx += offsetX + pressedOffset;
-	dy += offsetY + pressedOffset;
+	
+	row = Row(w, pos);
+	dx = CartesianX(w, pos, row) + offsetX + pressedOffset;
+	dy = CartesianY(w, row) + offsetY + pressedOffset;
 	if (corners) {
 		hexagonList[corners][0].x = dx;
 		hexagonList[corners][0].y = dy;
@@ -1091,6 +1093,200 @@ DrawAllTiles(const HexagonsWidget w)
 			(w->hexagons.tileOfPosition[k] <= 0), False, 0, 0);
 }
 
+static int
+FindSpaceType(HexagonsWidget w, int pos1, int pos2, int row1, int row2)
+{
+	if (row1 == row2 && (pos1 == pos2 + 1 || pos1 == pos2 - 1))
+		return (ROW);
+	else if (row1 == row2 - 1) {
+		swap(&row1, &row2);
+		swap(&pos1, &pos2);
+	}
+	if (row1 == row2 + 1) {
+		if (row1 <= w->hexagons.sizeY - 1) {
+			if (pos2 == pos1 - w->hexagons.sizeX - row1)
+				return (TLBR);
+			else if (pos2 == pos1 - w->hexagons.sizeX - row1 + 1)
+				return (TRBL);
+		} else {	/* row1 > w->hexagons.sizeY - 1 */
+			if (pos2 == pos1 - 2 * w->hexagons.sizeY -
+					w->hexagons.sizeX + row1 + 1)
+				return (TLBR);
+			else if (pos2 == pos1 - 2 * w->hexagons.sizeY -
+					w->hexagons.sizeX + row1 + 2)
+				return (TRBL);
+		}
+	}
+	return (-1);
+}
+
+static void
+FindMovableTile(HexagonsWidget w, int pos, int posRow, int spaceType, int side,
+	int *tilePos, int *tileRow)
+{
+	switch (spaceType) {
+		case TRBL:
+			if (side == HIGH) {
+				*tileRow = posRow;
+				*tilePos = pos + 1;
+			} else {	/* side == LOW */
+				*tileRow = posRow - 1;
+				*tilePos = (posRow <= w->hexagons.sizeY - 1) ?
+					pos - w->hexagons.sizeX - posRow :
+					pos - 2 * w->hexagons.sizeY -
+					w->hexagons.sizeX + posRow + 1;
+			}
+			break;
+		case TLBR:
+			if (side == HIGH) {
+				*tileRow = posRow;
+				*tilePos = pos - 1;
+			} else {	/* side == LOW */
+				*tileRow = posRow - 1;
+				*tilePos = (posRow <= w->hexagons.sizeY - 1) ?
+					pos - w->hexagons.sizeX - posRow + 1 :
+					pos - 2 * w->hexagons.sizeY -
+					w->hexagons.sizeX + posRow + 2;
+			}
+			break;
+		case ROW:
+			if (side == HIGH) {
+				*tileRow = posRow + 1;
+				*tilePos = (posRow < w->hexagons.sizeY - 1) ?
+					pos + w->hexagons.sizeX + posRow :
+					pos + 2 * w->hexagons.sizeY +
+					w->hexagons.sizeX - posRow - 3;
+			} else {	/* side == LOW */
+				*tileRow = posRow - 1;
+				*tilePos = (posRow <= w->hexagons.sizeY - 1) ?
+					pos - w->hexagons.sizeX - posRow :
+					pos - 2 * w->hexagons.sizeY -
+					w->hexagons.sizeX + posRow + 1;
+			}
+			break;
+		default:
+			{
+				char *buf;
+
+				intCat(&buf,
+					"FindMovableTile: spaceType \n",
+					spaceType);
+				DISPLAY_WARNING(buf);
+				free(buf);
+			}
+	}
+}
+
+static int
+NextToWall(HexagonsWidget w, int pos, int posRow, int spaceType)
+{
+	switch (spaceType) {
+		case TRBL:
+			if (posRow < w->hexagons.sizeY &&
+					pos ==w->hexagons.sizeX * posRow +
+					posRow * (posRow - 1) / 2)
+				return (HIGH);
+			else if (posRow >= w->hexagons.sizeY &&
+					pos == w->hexagons.sizeY *
+					(2 * posRow - w->hexagons.sizeY + 3) -
+					w->hexagons.sizeX * posRow - 2 -
+					posRow + 4 * w->hexagons.sizeX *
+					(w->hexagons.sizeX - 1) / 2 -
+					(2 * w->hexagons.sizeX - posRow - 2) *
+					(2 * w->hexagons.sizeX - posRow - 1) / 2)
+				return (LOW);
+			else
+				return (-1);
+		case TLBR:
+			if (posRow < w->hexagons.sizeY && pos ==
+					w->hexagons.sizeX * (posRow + 1) +
+					posRow * (posRow + 1) / 2 - 1)
+				return (HIGH);
+			else if (posRow >= w->hexagons.sizeY &&
+					pos == w->hexagons.sizeY *
+					(2 * posRow - w->hexagons.sizeY + 1) -
+					 w->hexagons.sizeX * (posRow + 1) + 1 +
+					 4 * w->hexagons.sizeX *
+					(w->hexagons.sizeX - 1) / 2 -
+					(2 * w->hexagons.sizeX - posRow - 2) *
+					(2 * w->hexagons.sizeX - posRow - 1) / 2)
+				return (LOW);
+			else
+				return (-1);
+		case ROW:
+			if (posRow == 0)
+				return (HIGH);
+			else if (posRow == 2 * (w->hexagons.sizeY - 1))
+				return (LOW);
+			else
+				return (-1);
+	}
+	return (-2);		/*Unknown space formation. */
+}
+
+static int
+MovableCornerTiles(HexagonsWidget w, int direction,
+		int *position, int *posRow, int *space)
+{
+	int spaceType, highest, side = -1;
+
+	highest = (w->hexagons.spacePosition[HIGH] >
+		w->hexagons.spacePosition[LOW]) ? HIGH : LOW;
+	spaceType = FindSpaceType(w,
+		w->hexagons.spacePosition[HIGH], w->hexagons.spacePosition[LOW],
+		w->hexagons.spaceRow[HIGH], w->hexagons.spaceRow[LOW]);
+	switch (spaceType) {
+		case TRBL:
+			if (direction == TR || direction == BL)
+				return FALSE;
+			side = NextToWall(w, w->hexagons.spacePosition[highest],
+				w->hexagons.spaceRow[highest], spaceType);
+			if (side != -1) {
+				if ((side == HIGH && direction == RIGHT) ||
+				    (side == HIGH && direction == BR) ||
+				    (side == LOW && direction == LEFT) ||
+				    (side == LOW && direction == TL))
+					return FALSE;
+			} else
+				side = (direction == TL || direction == LEFT);
+			*space = (direction == BR || direction == LEFT);
+			break;
+		case TLBR:
+			if (direction == TL || direction == BR)
+				return FALSE;
+			side = NextToWall(w, w->hexagons.spacePosition[highest],
+				w->hexagons.spaceRow[highest], spaceType);
+			if (side != -1) {
+				if ((side == LOW && direction == TR) ||
+				    (side == LOW && direction == RIGHT) ||
+				    (side == HIGH && direction == BL) ||
+				    (side == HIGH && direction == LEFT))
+					return FALSE;
+			} else
+				side = (direction == TR || direction == RIGHT);
+			*space = (direction == RIGHT || direction == BL);
+			break;
+		case ROW:
+			if (direction == LEFT || direction == RIGHT)
+				return FALSE;
+			side = NextToWall(w, w->hexagons.spacePosition[highest],
+				   w->hexagons.spaceRow[highest], spaceType);
+			if (side != -1) {
+				if ((side == LOW && direction == TR) ||
+				    (side == HIGH && direction == BR) ||
+				    (side == HIGH && direction == BL) ||
+				    (side == LOW && direction == TL))
+					return FALSE;
+			} else
+				side = (direction == TR || direction == TL);
+			*space = (direction == TR || direction == BR);
+			break;
+	}
+	FindMovableTile(w, w->hexagons.spacePosition[highest],
+	  w->hexagons.spaceRow[highest], spaceType, side, position, posRow);
+	return TRUE;
+}
+
 static int
 MovableNoCornTile(HexagonsWidget w)
 {
@@ -1112,67 +1308,80 @@ MovableNoCornTile(HexagonsWidget w)
 
 #ifdef ANIMATE
 static int
-CountTiles(HexagonsWidget w, int *dir, int *rowType)
+CountTiles(HexagonsWidget w, int rowType)
 {
-	int count = 0;
-	char *buf;
+	switch (rowType) {
+	case TLBR:
+		return ABS(w->hexagons.spaceRow[ROW] -
+		 	w->hexagons.currentRow[ROW]);
+	case TRBL:
+		return ABS(w->hexagons.spaceRow[ROW] -
+			w->hexagons.currentRow[ROW]);
+	case ROW:
+		return ABS(w->hexagons.spaceRow[TRBL] -
+			w->hexagons.currentRow[TRBL]);
+	default:
+		{
+			char * buf;
 
-	*rowType = MovableNoCornTile(w);
-	if (*rowType < 0) {
-		intCat(&buf, "CountTiles: rowType ", *rowType);
-		DISPLAY_WARNING(buf);
-		free(buf);
-		return 0;
+			intCat(&buf, "CountTiles: rowType ", rowType);
+			DISPLAY_WARNING(buf);
+			free(buf);
+		}
 	}
-	switch (*rowType) {
-		case TLBR:
-			count = ABS(w->hexagons.spaceRow[ROW] -
-			 	w->hexagons.currentRow[ROW]);
-			*dir = (*dir == HIGH) ? BR : TL;
-			break;
-		case TRBL:
-			count = ABS(w->hexagons.spaceRow[ROW] -
-				w->hexagons.currentRow[ROW]);
-			*dir = (*dir == HIGH) ? BL: TR;
-			break;
-		case ROW:
-			count = ABS(w->hexagons.spaceRow[TRBL] -
-				w->hexagons.currentRow[TRBL]);
-			*dir = (*dir == HIGH) ? RIGHT: LEFT;
-			break;
-		default:
-			{
-				intCat(&buf, "CountTiles: rowType ",
-					*rowType);
-				DISPLAY_WARNING(buf);
-				free(buf);
-			}
+	return 0;
+}
+
+static int
+DirTiles(HexagonsWidget w, int dir, int rowType)
+{
+	switch (rowType) {
+	case TLBR:
+		return (dir == HIGH) ? BR : TL;
+	case TRBL:
+		return (dir == HIGH) ? BL : TR;
+	case ROW:
+		return (dir == HIGH) ? RIGHT : LEFT;
+	default:
+		{
+			char *buf;
+
+			intCat(&buf, "DirTiles: rowType ", rowType);
+			DISPLAY_WARNING(buf);
+			free(buf);
+		}
 	}
-	return count;
+	return dir;
 }
 
 static void
 AnimateSlide(HexagonsWidget w, int dir, int fast, Boolean logMoves)
 {
 	int aTile, numTiles, direction = dir, rowType;
-	int fillBeginPos, fillBeginRow;
+	int fillBeginPos;
 	int pos, posNext;
 
-	numTiles = CountTiles(w, &direction, &rowType);
+	rowType = MovableNoCornTile(w);
+	if (rowType < 0) {
+		char *buf;
+
+		intCat(&buf, "AnimateTiles: rowType ", rowType);
+		DISPLAY_WARNING(buf);
+		free(buf);
+		numTiles = 0;
+	} else {
+		numTiles = CountTiles(w, rowType);
+		direction = DirTiles(w, dir, rowType);
+	}
 	if (numTiles < 0)
 		numTiles = -numTiles;
 	fillBeginPos = TileNFromSpace(w, numTiles, rowType, dir);
-	fillBeginRow = Row(w, fillBeginPos);
 	{
 		int pixNo = 0;
-		int pixX = 0;
-		int pixY = 0;
-		int fromdx = 0;
-		int fromdy = 0;
-		int todx = 0;
-		int tody = 0;
-		int dx, dy;
-		int firstRow;
+		int pixX = 0, pixY = 0;
+		int fromdx = 0, fromdy = 0;
+		int todx = 0, tody = 0;
+		int dx, dy, row;
 		int *rowPos;
 		int i, k;
 		Boolean slideDone = False;
@@ -1182,14 +1391,17 @@ AnimateSlide(HexagonsWidget w, int dir, int fast, Boolean logMoves)
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 		rowPos[1] = TileNFromSpace(w, 1, rowType, dir);
-		firstRow = Row(w, rowPos[1]);
 		rowPos[0] = w->hexagons.spacePosition[HIGH];
 		for (i = 1; i < numTiles; i++) {
 			rowPos[i + 1] = TileNFromSpace(w,
 				i + 1, rowType, dir);
 		}
-		Cartesian(w, rowPos[1], &fromdx, &fromdy);
-		Cartesian(w, rowPos[0], &todx, &tody);
+		row = Row(w, rowPos[1]);
+		fromdx = CartesianX(w, rowPos[1], row);
+		fromdy = CartesianY(w, row);
+		row = Row(w, rowPos[0]);
+		todx = CartesianX(w, rowPos[0], row);
+		tody = CartesianY(w, row);
 		dx = todx - fromdx;
 		dy = tody - fromdy;
 		i = 0;
@@ -1408,14 +1620,20 @@ MoveNoTiles(HexagonsWidget w)
 static void
 MoveCornerTiles(HexagonsWidget w, int from, int posRow, int space, int fast)
 {
-	int fromTile, nextPos;
+	int fromTile, nextPos, row;
 	int dx, dy, s0x, s0y, s1x, s1y, cx, cy;
 
 	fromTile = w->hexagons.tileOfPosition[from];
 	nextPos = w->hexagons.spacePosition[space];
-	Cartesian(w, from, &dx, &dy);
-	Cartesian(w, w->hexagons.spacePosition[space], &s0x, &s0y);
-	Cartesian(w, w->hexagons.spacePosition[!space], &s1x, &s1y);
+	row = Row(w, from);
+	dx = CartesianX(w, from, row);
+	dy = CartesianY(w, row);
+	row = Row(w, w->hexagons.spacePosition[space]);
+	s0x = CartesianX(w, w->hexagons.spacePosition[space], row);
+	s0y = CartesianY(w, row);
+	row = Row(w, w->hexagons.spacePosition[!space]);
+	s1x = CartesianX(w, w->hexagons.spacePosition[!space], row);
+	s1y = CartesianY(w, row);
 	cx = (s0x + s1x - 2 * dx) / 3;
 	cy = (s0y + s1y - 2 * dy) / 3;
 	if (fast == INSTANT) {
@@ -1533,137 +1751,6 @@ MoveNoCornTiles(HexagonsWidget w, int from, int posRow, int fast)
 #endif
 }
 
-static int
-FindSpaceType(HexagonsWidget w, int pos1, int pos2, int row1, int row2)
-{
-	if (row1 == row2 && (pos1 == pos2 + 1 || pos1 == pos2 - 1))
-		return (ROW);
-	else if (row1 == row2 - 1) {
-		swap(&row1, &row2);
-		swap(&pos1, &pos2);
-	}
-	if (row1 == row2 + 1) {
-		if (row1 <= w->hexagons.sizeY - 1) {
-			if (pos2 == pos1 - w->hexagons.sizeX - row1)
-				return (TLBR);
-			else if (pos2 == pos1 - w->hexagons.sizeX - row1 + 1)
-				return (TRBL);
-		} else {	/* row1 > w->hexagons.sizeY - 1 */
-			if (pos2 == pos1 - 2 * w->hexagons.sizeY -
-					w->hexagons.sizeX + row1 + 1)
-				return (TLBR);
-			else if (pos2 == pos1 - 2 * w->hexagons.sizeY -
-					w->hexagons.sizeX + row1 + 2)
-				return (TRBL);
-		}
-	}
-	return (-1);
-}
-
-static void
-FindMovableTile(HexagonsWidget w, int pos, int posRow, int spaceType, int side,
-	int *tilePos, int *tileRow)
-{
-	switch (spaceType) {
-		case TRBL:
-			if (side == HIGH) {
-				*tileRow = posRow;
-				*tilePos = pos + 1;
-			} else {	/* side == LOW */
-				*tileRow = posRow - 1;
-				*tilePos = (posRow <= w->hexagons.sizeY - 1) ?
-					pos - w->hexagons.sizeX - posRow :
-					pos - 2 * w->hexagons.sizeY -
-					w->hexagons.sizeX + posRow + 1;
-			}
-			break;
-		case TLBR:
-			if (side == HIGH) {
-				*tileRow = posRow;
-				*tilePos = pos - 1;
-			} else {	/* side == LOW */
-				*tileRow = posRow - 1;
-				*tilePos = (posRow <= w->hexagons.sizeY - 1) ?
-					pos - w->hexagons.sizeX - posRow + 1 :
-					pos - 2 * w->hexagons.sizeY -
-					w->hexagons.sizeX + posRow + 2;
-			}
-			break;
-		case ROW:
-			if (side == HIGH) {
-				*tileRow = posRow + 1;
-				*tilePos = (posRow < w->hexagons.sizeY - 1) ?
-					pos + w->hexagons.sizeX + posRow :
-					pos + 2 * w->hexagons.sizeY +
-					w->hexagons.sizeX - posRow - 3;
-			} else {	/* side == LOW */
-				*tileRow = posRow - 1;
-				*tilePos = (posRow <= w->hexagons.sizeY - 1) ?
-					pos - w->hexagons.sizeX - posRow :
-					pos - 2 * w->hexagons.sizeY -
-					w->hexagons.sizeX + posRow + 1;
-			}
-			break;
-		default:
-			{
-				char *buf;
-
-				intCat(&buf,
-					"FindMovableTile: spaceType \n",
-					spaceType);
-				DISPLAY_WARNING(buf);
-				free(buf);
-			}
-	}
-}
-
-static int
-NextToWall(HexagonsWidget w, int pos, int posRow, int spaceType)
-{
-	switch (spaceType) {
-		case TRBL:
-			if (posRow < w->hexagons.sizeY &&
-					pos ==w->hexagons.sizeX * posRow +
-					posRow * (posRow - 1) / 2)
-				return (HIGH);
-			else if (posRow >= w->hexagons.sizeY &&
-					pos == w->hexagons.sizeY *
-					(2 * posRow - w->hexagons.sizeY + 3) -
-					w->hexagons.sizeX * posRow - 2 -
-					posRow + 4 * w->hexagons.sizeX *
-					(w->hexagons.sizeX - 1) / 2 -
-					(2 * w->hexagons.sizeX - posRow - 2) *
-					(2 * w->hexagons.sizeX - posRow - 1) / 2)
-				return (LOW);
-			else
-				return (-1);
-		case TLBR:
-			if (posRow < w->hexagons.sizeY && pos ==
-					w->hexagons.sizeX * (posRow + 1) +
-					posRow * (posRow + 1) / 2 - 1)
-				return (HIGH);
-			else if (posRow >= w->hexagons.sizeY &&
-					pos == w->hexagons.sizeY *
-					(2 * posRow - w->hexagons.sizeY + 1) -
-					 w->hexagons.sizeX * (posRow + 1) + 1 +
-					 4 * w->hexagons.sizeX *
-					(w->hexagons.sizeX - 1) / 2 -
-					(2 * w->hexagons.sizeX - posRow - 2) *
-					(2 * w->hexagons.sizeX - posRow - 1) / 2)
-				return (LOW);
-			else
-				return (-1);
-		case ROW:
-			if (posRow == 0)
-				return (HIGH);
-			else if (posRow == 2 * (w->hexagons.sizeY - 1))
-				return (LOW);
-			else
-				return (-1);
-	}
-	return (-2);		/*Unknown space formation. */
-}
-
 static int
 FindTileTriangle(HexagonsWidget w, int pI, int pJ, int pK,
 		int rI, int rJ, int rK)
@@ -1760,69 +1847,6 @@ WithinFrame(HexagonsWidget w, int x, int y, int dx, int dy)
 }
 #endif
 
-static int
-MovableCornerTiles(HexagonsWidget w, int direction,
-		int *position, int *posRow, int *space)
-{
-	int spaceType, highest, side = -1;
-
-	highest = (w->hexagons.spacePosition[HIGH] >
-		w->hexagons.spacePosition[LOW]) ? HIGH : LOW;
-	spaceType = FindSpaceType(w,
-		w->hexagons.spacePosition[HIGH], w->hexagons.spacePosition[LOW],
-		w->hexagons.spaceRow[HIGH], w->hexagons.spaceRow[LOW]);
-	switch (spaceType) {
-		case TRBL:
-			if (direction == TR || direction == BL)
-				return FALSE;
-			side = NextToWall(w, w->hexagons.spacePosition[highest],
-				w->hexagons.spaceRow[highest], spaceType);
-			if (side != -1) {
-				if ((side == HIGH && direction == RIGHT) ||
-				    (side == HIGH && direction == BR) ||
-				    (side == LOW && direction == LEFT) ||
-				    (side == LOW && direction == TL))
-					return FALSE;
-			} else
-				side = (direction == TL || direction == LEFT);
-			*space = (direction == BR || direction == LEFT);
-			break;
-		case TLBR:
-			if (direction == TL || direction == BR)
-				return FALSE;
-			side = NextToWall(w, w->hexagons.spacePosition[highest],
-				w->hexagons.spaceRow[highest], spaceType);
-			if (side != -1) {
-				if ((side == LOW && direction == TR) ||
-				    (side == LOW && direction == RIGHT) ||
-				    (side == HIGH && direction == BL) ||
-				    (side == HIGH && direction == LEFT))
-					return FALSE;
-			} else
-				side = (direction == TR || direction == RIGHT);
-			*space = (direction == RIGHT || direction == BL);
-			break;
-		case ROW:
-			if (direction == LEFT || direction == RIGHT)
-				return FALSE;
-			side = NextToWall(w, w->hexagons.spacePosition[highest],
-				   w->hexagons.spaceRow[highest], spaceType);
-			if (side != -1) {
-				if ((side == LOW && direction == TR) ||
-				    (side == HIGH && direction == BR) ||
-				    (side == HIGH && direction == BL) ||
-				    (side == LOW && direction == TL))
-					return FALSE;
-			} else
-				side = (direction == TR || direction == TL);
-			*space = (direction == TR || direction == BR);
-			break;
-	}
-	FindMovableTile(w, w->hexagons.spacePosition[highest],
-	  w->hexagons.spaceRow[highest], spaceType, side, position, posRow);
-	return TRUE;
-}
-
 static int
 MoveCornerTilesDir(HexagonsWidget w, int direction, int fast)
 {
@@ -2018,23 +2042,24 @@ DiscreteNoCornMoves(HexagonsWidget w, int dir, int fast)
 			orient, fast);
 		SetHexagons(w, HEXAGONS_MOVED);
 		switch (rowType) {
-			case TLBR:
-				PutMove(BR);
-				break;
-			case TRBL:
-				PutMove(BL);
-				break;
-			case ROW:
-				PutMove(RIGHT);
-				break;
-			default:
-				{
-					intCat(&buf,
-						"SelectNoCornTiles: rowType ",
-							rowType);
-					DISPLAY_WARNING(buf);
-					free(buf);
-				}
+		case TLBR:
+			PutMove(BR);
+			return;
+		case TRBL:
+			PutMove(BL);
+			return;
+		case ROW:
+			PutMove(RIGHT);
+			return;
+		default:
+			{
+				intCat(&buf,
+					"DiscreteNoCornTiles: rowType ",
+						rowType);
+				DISPLAY_WARNING(buf);
+				free(buf);
+				return;
+			}
 		}
 	} else { /* w->hexagons.currentPosition > w->hexagons.spacePosition[HIGH] */
 		orient = (rowType == ROW) ? w->hexagons.spaceRow[ROW] :
@@ -2043,23 +2068,24 @@ DiscreteNoCornMoves(HexagonsWidget w, int dir, int fast)
 			orient, fast);
 		SetHexagons(w, HEXAGONS_MOVED);
 		switch (rowType) {
-			case TLBR:
-				PutMove(TL);
-				break;
-			case TRBL:
-				PutMove(TR);
-				break;
-			case ROW:
-				PutMove(LEFT);
-				break;
-			default:
-				{
-					intCat(&buf,
-						"SelectNoCornTiles: rowType ",
-						rowType);
-					DISPLAY_WARNING(buf);
-				 	free(buf);
-				}
+		case TLBR:
+			PutMove(TL);
+			return;
+		case TRBL:
+			PutMove(TR);
+			return;
+		case ROW:
+			PutMove(LEFT);
+			return;
+		default:
+			{
+				intCat(&buf,
+					"DiscreteNoCornTiles: rowType ",
+					rowType);
+				DISPLAY_WARNING(buf);
+			 	free(buf);
+				return;
+			}
 		}
 	}
 }
@@ -2155,17 +2181,6 @@ SelectCornerTiles(HexagonsWidget w, int space)
 static void
 SelectNoCornTiles(HexagonsWidget w)
 {
-	int rowType;
-	char *buf;
-
-	rowType = MovableNoCornTile(w);
-	if (rowType < 0) {
-		intCat(&buf, "SelectNoCornTiles: rowType ",
-			rowType);
-		DISPLAY_WARNING(buf);
-		free(buf);
-		return;
-	}
 	if (w->hexagons.currentPosition < w->hexagons.spacePosition[HIGH]) {
 #ifdef ANIMATE
 		if (w->hexagons.delay > 0) {
@@ -2183,7 +2198,7 @@ SelectNoCornTiles(HexagonsWidget w)
 				DiscreteNoCornMoves(w, HIGH, NORMAL);
 			}
 		}
-	} else {		/*w->hexagons.currentPosition > w->hexagons.spacePosition[HIGH] */
+	} else { /* w->hexagons.currentPosition > w->hexagons.spacePosition[HIGH] */
 #ifdef ANIMATE
 		if (w->hexagons.delay > 0) {
 			AnimateSlide(w, LOW, NORMAL, True);
@@ -2754,37 +2769,41 @@ SetValuesHexagons(Widget current, Widget request, Widget renew)
 		redraw = TRUE;
 	}
 	if (w->hexagons.menu != -1) {
-		switch (w->hexagons.menu) {
+		int menu = w->hexagons.menu;
+
+		w->hexagons.menu = -1;
+		switch (menu) {
 		case 0:
-			w->hexagons.menu = -1;
 			GetTiles(w);
 			break;
 		case 1:
-			w->hexagons.menu = -1;
 			WriteTiles(w);
 			break;
 		case 3:
-			w->hexagons.menu = -1;
 			ClearTiles(w);
 			break;
 		case 4:
-			w->hexagons.menu = -1;
 			UndoTiles(w);
 			break;
 		case 5:
-			w->hexagons.menu = -1;
 			RandomizeTiles(w);
 			break;
 		case 6:
-			w->hexagons.menu = -1;
 			SolveTiles(w);
 			break;
 		case 7:
-			w->hexagons.menu = -1;
 			ModeTiles(w);
 			break;
+		case 8:
+			SpeedTiles(w);
+			break;
+		case 9:
+			SlowTiles(w);
+			break;
+		case 10:
+			SoundTiles(w);
+			break;
 		default:
-			w->hexagons.menu = -1;
 			break;
 		}
 	}
@@ -2837,9 +2856,9 @@ DestroyHexagons(Widget old)
 	HexagonsWidget w = (HexagonsWidget) old;
 
 	XtReleaseGC(old, w->hexagons.tileGC);
+	XtReleaseGC(old, w->hexagons.borderGC);
 	XtReleaseGC(old, w->hexagons.tileBrighterGC);
 	XtReleaseGC(old, w->hexagons.tileDarkerGC);
-	XtReleaseGC(old, w->hexagons.borderGC);
 	XtReleaseGC(old, w->hexagons.frameGC);
 	XtReleaseGC(old, w->hexagons.inverseGC);
 	XtRemoveCallbacks(old, XtNselectCallback, w->hexagons.select);
@@ -3048,9 +3067,9 @@ XSynchronize(XtDisplay(w), True);
 	w->hexagons.oldColormap = None;
 	w->hexagons.fontInfo = NULL;
 	w->hexagons.tileGC = NULL;
+	w->hexagons.borderGC = NULL;
 	w->hexagons.tileBrighterGC = NULL;
 	w->hexagons.tileDarkerGC = NULL;
-	w->hexagons.borderGC = NULL;
 	w->hexagons.frameGC = NULL;
 	w->hexagons.inverseGC = NULL;
 #endif
