@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -98,7 +98,7 @@ static HWND Wnd;
 
 #ifdef HAVE_MOTIF
 static const char aboutHelp[] = {
-	"Version 7.1.1\n"
+	"Version 7.1.3\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
@@ -158,7 +158,7 @@ static const char featuresHelp[] = {
 	"\n"
 	"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
 	"\n"
-	"Press \"@\" or \"2\" keys to toggle the sound.\n"
+	"Press \"@\" key to toggle the sound.\n"
 	"\n"
 	"Press \"Esc\" key to hide program.\n"
 	"\n"
@@ -835,6 +835,36 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			ReleaseHexagons(&widget, LOWORD(lParam), HIWORD(lParam));
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
+#if (_WIN32_WINNT >= 0x0400) || (_WIN32_WINDOWS > 0x0400)
+		case WM_MOUSEWHEEL:
+			widget.core.hDC = GetDC(hWnd);
+			(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
+			{
+				int zDelta = ((short) HIWORD(wParam));
+				POINT cursor, origin;
+
+				origin.x = 0, origin.y = 0;
+				ClientToScreen(hWnd, &origin);
+				(void) GetCursorPos(&cursor);
+				if (zDelta > (WHEEL_DELTA >> 1)) {
+					MoveHexagons(&widget, TOP,
+				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
+					if (GetKeyState(VK_CONTROL) >> 1) {
+						SizeHexagons(&widget);
+						(void) InvalidateRect(hWnd, NULL, TRUE);
+					}
+				} else if (zDelta < -(WHEEL_DELTA >> 1)) {
+					MoveHexagons(&widget, BOTTOM,
+				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
+					if (GetKeyState(VK_CONTROL) >> 1) {
+						SizeHexagons(&widget);
+						(void) InvalidateRect(hWnd, NULL, TRUE);
+					}
+				}
+			}
+			(void) ReleaseDC(hWnd, widget.core.hDC);
+			break;
+#endif
 		case WM_COMMAND:
 			switch (LOWORD(wParam)) {
 				case IDM_GET:
