@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -500,7 +500,7 @@ stringCat(char ** string, const char * var1, const char * var2)
 }
 
 static void
-CheckWedges(MballWidget w)
+CheckPieces(MballWidget w)
 {
 	char *buf1 = NULL, *buf2 = NULL;
 
@@ -576,11 +576,11 @@ CheckSolved(MballWidget w)
 					return False;
 				if (test.direction) {
 					if ((w->mball.wedges - w->mball.mballLoc[wedge][ring].wedge +
-					     test.wedge) % w->mball.wedges != wedge)
+							test.wedge) % w->mball.wedges != wedge)
 						return False;
 				} else {
 					if ((w->mball.wedges + w->mball.mballLoc[wedge][ring].wedge -
-					     test.wedge) % w->mball.wedges != wedge)
+							test.wedge) % w->mball.wedges != wedge)
 						return False;
 				}
 			}
@@ -837,13 +837,13 @@ DrawSector(const MballWidget w,
 	if (ring + 1 > w->mball.rings / 2) {
 		if (w->mball.vertical) {
 			DrawSect(w, pieceGC, borderGC,
-				 w->mball.rings - 1 - ring,
-				 (3 * w->mball.wedges / 2 - 1 - wedge) % w->mball.wedges,
-				 startx, lengthy + 3, lengthx - startx, lengthy - starty);
+				w->mball.rings - 1 - ring,
+				(3 * w->mball.wedges / 2 - 1 - wedge) % w->mball.wedges,
+				startx, lengthy + 3, lengthx - startx, lengthy - starty);
 		} else {
 			DrawSect(w, pieceGC, borderGC,
-				 w->mball.rings - 1 - ring, w->mball.wedges - 1 - wedge,
-				 lengthx + 3, starty, lengthx - startx, lengthy - starty);
+				w->mball.rings - 1 - ring, w->mball.wedges - 1 - wedge,
+				lengthx + 3, starty, lengthx - startx, lengthy - starty);
 		}
 	}
 	if (w->mball.mono) {
@@ -924,7 +924,7 @@ DrawSector(const MballWidget w,
 		char buf[2];
 
 		if (ring < (w->mball.rings + 1) / 2 &&
-		    !w->mball.mballLoc[wedge][ring].direction) {
+				!w->mball.mballLoc[wedge][ring].direction) {
 			LetterPosition(w, wedge, ring, lengthx - startx, lengthy - starty,
 				&letterX, &letterY);
 			letterX += startx + 5 + w->mball.letterOffset.x;
@@ -942,7 +942,7 @@ DrawSector(const MballWidget w,
 			DRAWTEXT(w, borderGC, letterX, letterY, buf, i);
 		}
 		if (ring + 1 > w->mball.rings / 2 &&
-		    w->mball.mballLoc[wedge][ring].direction) {
+				w->mball.mballLoc[wedge][ring].direction) {
 			if (w->mball.vertical) {
 				LetterPosition(w,
 					(3 * w->mball.wedges / 2 - 1 - wedge) % w->mball.wedges,
@@ -995,7 +995,7 @@ XFillSector(Display * display, Drawable drawable, GC gc, int xo, int yo,
 	d = MAX(r1 + r2 + 2, 2);
 	XSetLineAttributes(display, gc, w, LineSolid, CapNotLast, JoinRound);
 	XDrawArc(display, drawable, gc, xo - d / 2, yo - d / 2, d, d,
-		 angle1, angle2);
+		angle1, angle2);
 	XSetLineAttributes(display, gc, 1, LineSolid, CapNotLast, JoinRound);
 }
 
@@ -1019,23 +1019,23 @@ XDrawSector(Display * display, Drawable drawable, GC gc,
 		r1 = -3;
 	d = MAX(2 * (r1 + 3), 1);
 	XDrawArc(display, drawable, gc, xo - d / 2, yo - d / 2, d, d,
-		 angle1, angle2);
+		angle1, angle2);
 	d = MAX(2 * (r2 - 1), 3);
 	XDrawArc(display, drawable, gc, xo - d / 2, yo - d / 2, d, d,
-		 angle1, angle2);
+		angle1, angle2);
 #if 0
 	ang = RADIANS((double) angle1 / MULT);
 	x = cos(ang);
 	y = sin(ang);
 	XDrawLine(display, drawable, gc,
-	   (int) ((double) r1 * x) + xo, (int) ((double) r1 * y) + yo,
-	   (int) ((double) r2 * x) + xo, (int) ((double) r2 * y) + yo);
+		(int) ((double) r1 * x) + xo, (int) ((double) r1 * y) + yo,
+		(int) ((double) r2 * x) + xo, (int) ((double) r2 * y) + yo);
 	ang = RADIANS((double) angle2 / MULT);
 	x = cos(ang);
 	y = sin(ang);
 	XDrawLine(display, drawable, gc,
-	   (int) ((double) r1 * x) + xo, (int) ((double) r1 * y) + yo,
-	   (int) ((double) r2 * x) + xo, (int) ((double) r2 * y) + yo);
+		(int) ((double) r1 * x) + xo, (int) ((double) r1 * y) + yo,
+		(int) ((double) r2 * x) + xo, (int) ((double) r2 * y) + yo);
 #endif
 }
 
@@ -1058,7 +1058,7 @@ XFillSector(Display *display, Drawable drawable, GC gc,
 		r1 = -3;
 	for (d = 2 * (r1 + 3); d < 2 * (r2 - 1); d++)
 		XDrawArc(display, drawable, gc, xo - d / 2, yo - d / 2, d, d,
-			 angle1, angle2);
+			angle1, angle2);
 }
 #endif
 
@@ -1077,53 +1077,53 @@ DrawSect(const MballWidget w, GC wedgeGC, GC borderGC,
 			  startx + lengthx / 2 + dx, starty + lengthy / 2 + dy,
 			  r * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
 			  r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
-				    (r + 1) * 2 * lengthx / (w->mball.rings + 1) - 2 * w->mball.dr,
-				    (r + 1) * 2 * lengthy / (w->mball.rings + 1) - 2 * w->mball.dr,
-				 CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
-				    -FULLCIRCLE / w->mball.wedges);
+			  (r + 1) * 2 * lengthx / (w->mball.rings + 1) - 2 * w->mball.dr,
+			  (r + 1) * 2 * lengthy / (w->mball.rings + 1) - 2 * w->mball.dr,
+			  CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
+			  -FULLCIRCLE / w->mball.wedges);
 			XDrawSector(XtDisplay(w), XtWindow(w), borderGC,
-			startx + lengthx / 2 + dx, starty + lengthy / 2 + dy,
+			  startx + lengthx / 2 + dx, starty + lengthy / 2 + dy,
 			  r * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
 			  r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
-				    (r + 1) * 2 * lengthx / (w->mball.rings + 1) - 2 * w->mball.dr,
-				    (r + 1) * 2 * lengthy / (w->mball.rings + 1) - 2 * w->mball.dr,
-				 CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
-				    -FULLCIRCLE / w->mball.wedges);
+			  (r + 1) * 2 * lengthx / (w->mball.rings + 1) - 2 * w->mball.dr,
+			  (r + 1) * 2 * lengthy / (w->mball.rings + 1) - 2 * w->mball.dr,
+			  CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
+			  -FULLCIRCLE / w->mball.wedges);
 		} else {
 			XFillSector(XtDisplay(w), XtWindow(w), wedgeGC,
-			startx + lengthx / 2 + dx, starty + lengthy / 2 + dy,
+			  startx + lengthx / 2 + dx, starty + lengthy / 2 + dy,
 			  r * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
 			  r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
-				    (r + 1) * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
-				    (r + 1) * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
-				 CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
-				    -FULLCIRCLE / w->mball.wedges);
+			  (r + 1) * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
+			  (r + 1) * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
+			  CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
+			  -FULLCIRCLE / w->mball.wedges);
 			XDrawSector(XtDisplay(w), XtWindow(w), borderGC,
-			startx + lengthx / 2 + dx, starty + lengthy / 2 + dy,
+			  startx + lengthx / 2 + dx, starty + lengthy / 2 + dy,
 			  r * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
 			  r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
-				    (r + 1) * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
-				    (r + 1) * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
-				 CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
-				    -FULLCIRCLE / w->mball.wedges);
+			  (r + 1) * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
+			  (r + 1) * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
+			  CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
+			  -FULLCIRCLE / w->mball.wedges);
 		}
 	} else {
 		XFillSector(XtDisplay(w), XtWindow(w), wedgeGC,
 			startx + lengthx / 2 + dx, starty + lengthy / 2 + dy,
-			  r * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
-			  r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
-		    (r + 1) * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
-		    (r + 1) * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
-			    CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
-			    -FULLCIRCLE / w->mball.wedges);
+			r * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
+			r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
+			(r + 1) * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
+			(r + 1) * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
+			CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
+			-FULLCIRCLE / w->mball.wedges);
 		XDrawSector(XtDisplay(w), XtWindow(w), borderGC,
 			startx + lengthx / 2 + dx, starty + lengthy / 2 + dy,
-			  r * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
-			  r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
-		    (r + 1) * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
-		    (r + 1) * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
-			    CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
-			    -FULLCIRCLE / w->mball.wedges);
+			r * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
+			r * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
+			(r + 1) * 2 * lengthx / w->mball.rings - 2 * w->mball.dr,
+			(r + 1) * 2 * lengthy / w->mball.rings - 2 * w->mball.dr,
+			CIRCLE_4 - FULLCIRCLE * wedge / w->mball.wedges,
+			-FULLCIRCLE / w->mball.wedges);
 	}
 }
 
@@ -1153,18 +1153,18 @@ DrawSector(const MballWidget w, const int wedge, const int ring,
 	 * the ring can straddle both hemispheres */
 	if (ring < (w->mball.rings + 1) / 2)
 		DrawSect(w, wedgeGC, borderGC, ring, wedge,
-			 startx, starty, lengthx - startx, lengthy - starty);
+			startx, starty, lengthx - startx, lengthy - starty);
 	if (ring + 1 > w->mball.rings / 2) {
 		if (w->mball.vertical)
 			DrawSect(w, wedgeGC, borderGC,
-				 w->mball.rings - 1 - ring,
-				 (3 * w->mball.wedges / 2 - 1 - wedge) % w->mball.wedges,
-				 startx, lengthy + 3, lengthx - startx, lengthy - starty);
+				w->mball.rings - 1 - ring,
+				(3 * w->mball.wedges / 2 - 1 - wedge) % w->mball.wedges,
+				startx, lengthy + 3, lengthx - startx, lengthy - starty);
 		else
 			DrawSect(w, wedgeGC, borderGC,
-				 w->mball.rings - 1 - ring,
-				 w->mball.wedges - 1 - wedge,
-				 lengthx + 3, starty, lengthx - startx, lengthy - starty);
+				w->mball.rings - 1 - ring,
+				w->mball.wedges - 1 - wedge,
+				lengthx + 3, starty, lengthx - startx, lengthy - starty);
 	}
 	if (w->mball.mono) {
 		int letterX, letterY;
@@ -1249,7 +1249,7 @@ DrawSector(const MballWidget w, const int wedge, const int ring,
 		char buf[65];
 
 		if (ring < (w->mball.rings + 1) / 2 &&
-		    !w->mball.mballLoc[wedge][ring].direction) {
+				!w->mball.mballLoc[wedge][ring].direction) {
 			LetterPosition(w, wedge, ring, lengthx - startx, lengthy - starty,
 				&letterX, &letterY);
 			letterX += startx + w->mball.letterOffset.x;
@@ -1267,7 +1267,7 @@ DrawSector(const MballWidget w, const int wedge, const int ring,
 			DRAWTEXT(w, borderGC, letterX, letterY, buf, i);
 		}
 		if (ring + 1 > w->mball.rings / 2 &&
-		    w->mball.mballLoc[wedge][ring].direction) {
+				w->mball.mballLoc[wedge][ring].direction) {
 			if (w->mball.vertical) {
 				LetterPosition(w,
 					(3 * w->mball.wedges / 2 - 1 - wedge) % w->mball.wedges,
@@ -1320,37 +1320,38 @@ DrawAllWedges(MballWidget w)
 }
 
 static void
-DrawRadar(const MballWidget w, GC gc, const int startx, const int starty,
+DrawRadar(const MballWidget w, GC gc, int thick,
+		const int startx, const int starty,
 		const int lengthx, const int lengthy)
 {
 	int r, i, stx, sty, lenx, leny;
 	double angle, increment;
 
-	DRAWARC(w, gc, 1, startx, starty,
-		 lengthx, lengthy, 0, FULLCIRCLE);
+	DRAWARC(w, gc, thick, startx, starty,
+		lengthx, lengthy, 0, FULLCIRCLE);
 	if (w->mball.rings % 2) {
 		stx = startx - lengthx / (2 * w->mball.rings);
 		sty = starty - lengthy / (2 * w->mball.rings);
 		for (r = 1; r < w->mball.rings / 2 + 1; r++) {
-			DRAWARC(w, gc, 1,
-				 stx + (w->mball.rings / 2 + 1 - r) * lengthx /
-				 w->mball.rings,
-				 sty + (w->mball.rings / 2 + 1 - r) * lengthy /
-				 w->mball.rings,
-				 r * 2 * lengthx / w->mball.rings,
-				 r * 2 * lengthy / w->mball.rings,
-				 0, FULLCIRCLE);
+			DRAWARC(w, gc, thick,
+				stx + (w->mball.rings / 2 + 1 - r) * lengthx /
+				w->mball.rings,
+				sty + (w->mball.rings / 2 + 1 - r) * lengthy /
+				w->mball.rings,
+				r * 2 * lengthx / w->mball.rings,
+				r * 2 * lengthy / w->mball.rings,
+				0, FULLCIRCLE);
 		}
 	} else {
 		for (r = 1; r < w->mball.rings / 2; r++) {
-			DRAWARC(w, gc, 1,
-				 startx + (w->mball.rings / 2 - r) * lengthx /
-				 w->mball.rings,
-				 starty + (w->mball.rings / 2 - r) * lengthy /
-				 w->mball.rings,
-				 r * 2 * lengthx / w->mball.rings,
-				 r * 2 * lengthy / w->mball.rings,
-				 0, FULLCIRCLE);
+			DRAWARC(w, gc, thick,
+				startx + (w->mball.rings / 2 - r) * lengthx /
+				w->mball.rings,
+				starty + (w->mball.rings / 2 - r) * lengthy /
+				w->mball.rings,
+				r * 2 * lengthx / w->mball.rings,
+				r * 2 * lengthy / w->mball.rings,
+				0, FULLCIRCLE);
 		}
 	}
 	increment = RADIANS(NUM_DEGREES) / (double) w->mball.wedges;
@@ -1389,26 +1390,26 @@ DrawFrame(MballWidget w, Boolean focus)
 	starty = 1 + w->mball.puzzleOffset.y;
 	lengthx = w->mball.viewLength - w->mball.delta + w->mball.puzzleOffset.x;
 	lengthy = w->mball.viewLength - w->mball.delta + w->mball.puzzleOffset.y;
-	DrawRadar(w, gc, startx, starty, lengthx - startx, lengthy - starty);
+	DrawRadar(w, gc, 0, startx, starty, lengthx - startx, lengthy - starty);
 	if (w->mball.vertical) {
 		DRAWLINE(w, w->mball.frameGC, 0, lengthy + 1,
 			(int) w->core.width, lengthy + 1);
-		DrawRadar(w, gc, startx, lengthy + 3, lengthx - startx, lengthy - starty);
+		DrawRadar(w, gc, 0, startx, lengthy + 3, lengthx - startx, lengthy - starty);
 	} else {
 		DRAWLINE(w, w->mball.frameGC, lengthx + 1, 0,
 			lengthx + 1, (int) w->core.height);
-		DrawRadar(w, gc, lengthx + 3, starty, lengthx - startx, lengthy - starty);
+		DrawRadar(w, gc, 0, lengthx + 3, starty, lengthx - startx, lengthy - starty);
 	}
 }
 
 static void
-MoveNoWedges(MballWidget w)
+MoveNoPieces(MballWidget w)
 {
 	SetMball(w, MBALL_ILLEGAL);
 }
 
 static void
-SwapWedges(MballWidget w, int wedge1, int wedge2)
+SwapPieces(MballWidget w, int wedge1, int wedge2)
 {
 	MballLoc temp;
 	int ring;
@@ -1441,7 +1442,7 @@ SwapWedges(MballWidget w, int wedge1, int wedge2)
 }
 
 static void
-MoveWedges(MballWidget w, int wedge, int ring, int direction)
+MovePieces(MballWidget w, int wedge, int ring, int direction)
 {
 	int i;
 
@@ -1474,7 +1475,7 @@ MoveWedges(MballWidget w, int wedge, int ring, int direction)
 			wedge1 = (i + sphereDir + offset) % w->mball.wedges;
 			wedge2 = (w->mball.wedges / 2 - 1 - i + sphereDir + offset) %
 				w->mball.wedges;
-			SwapWedges(w, wedge1, wedge2);
+			SwapPieces(w, wedge1, wedge2);
 		}
 	}
 }
@@ -1486,12 +1487,12 @@ MoveControlCb(MballWidget w, int wedge, int direction)
 
 	if (direction > COORD)
 		for (ring = 0; ring < w->mball.rings; ring++) {
-			MoveWedges(w, wedge, ring, direction);
+			MovePieces(w, wedge, ring, direction);
 			SetMball(w, MBALL_CONTROL);
 	} else {
-		MoveWedges(w, 0, 0, direction);
+		MovePieces(w, 0, 0, direction);
 		SetMball(w, MBALL_CONTROL);
-		MoveWedges(w, w->mball.wedges / 2, 0, direction);
+		MovePieces(w, w->mball.wedges / 2, 0, direction);
 		SetMball(w, MBALL_CONTROL);
 	}
 }
@@ -1503,14 +1504,14 @@ MoveMball(MballWidget w, const int wedge, const int ring, const int direction,
 	if (control)
 		MoveControlCb(w, wedge, direction);
 	else {
-		MoveWedges(w, wedge, ring, direction);
+		MovePieces(w, wedge, ring, direction);
 		SetMball(w, MBALL_MOVED);
 	}
 	PutMove(wedge, ring, direction, control);
 }
 
 static Boolean
-SelectWedges(MballWidget w, int x, int y, int *wedge, int *ring, int *view)
+PositionToSector(MballWidget w, int x, int y, int *wedge, int *ring, int *view)
 {
 	double angle, radius;
 
@@ -1549,11 +1550,11 @@ SelectWedges(MballWidget w, int x, int y, int *wedge, int *ring, int *view)
 }
 
 static Boolean
-PositionWedges(MballWidget w, int x, int y, int *wedge, int *ring, int *direction)
+PositionSector(MballWidget w, int x, int y, int *wedge, int *ring, int *direction)
 {
 	int view, inside;
 
-	inside = SelectWedges(w, x, y, wedge, ring, &view);
+	inside = PositionToSector(w, x, y, wedge, ring, &view);
 	if ((*direction == CW || *direction == CCW) && !inside)
 		return False;
 	if (view == DOWN) {
@@ -1565,8 +1566,8 @@ PositionWedges(MballWidget w, int x, int y, int *wedge, int *ring, int *directio
 			*direction = (COORD - *direction) % COORD;
 	}
 	if (*direction != CW && *direction != CCW &&
-	    mapDirToWedge[(w->mball.wedges - MINWEDGES) / 2][*direction] ==
-	      CUTS) {
+		mapDirToWedge[(w->mball.wedges - MINWEDGES) / 2][*direction] ==
+			CUTS) {
 		return False;
 	}
 	return True;
@@ -1581,10 +1582,10 @@ MoveMballInput(MballWidget w, int x, int y, int direction, int control)
 	int wedge, ring;
 
 	if (CheckSolved(w) && !w->mball.practice && !control) {
-		MoveNoWedges(w);
+		MoveNoPieces(w);
 		return;
 	}
-	if (!PositionWedges(w, x, y, &wedge, &ring, &direction))
+	if (!PositionSector(w, x, y, &wedge, &ring, &direction))
 		return;
 	control = (control) ? 1 : 0;
 	MoveMball(w, wedge, ring, direction, control);
@@ -1594,7 +1595,7 @@ MoveMballInput(MballWidget w, int x, int y, int direction, int control)
 }
 
 static void
-ResetWedges(MballWidget w)
+ResetPieces(MballWidget w)
 {
 	int wedge, ring;
 
@@ -1602,13 +1603,13 @@ ResetWedges(MballWidget w)
 		if (w->mball.mballLoc[wedge])
 			(void) free((void *) w->mball.mballLoc[wedge]);
 		if (!(w->mball.mballLoc[wedge] = (MballLoc *)
-		      malloc(sizeof (MballLoc) * w->mball.rings))) {
+				malloc(sizeof (MballLoc) * w->mball.rings))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 		if (startLoc[wedge])
 			(void) free((void *) startLoc[wedge]);
 		if (!(startLoc[wedge] = (MballLoc *)
-		      malloc(sizeof (MballLoc) * w->mball.rings))) {
+				malloc(sizeof (MballLoc) * w->mball.rings))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
@@ -1730,7 +1731,7 @@ GetWedges(MballWidget w)
 		SetMball(w, MBALL_PRACTICE);
 	}
 #ifdef WINVER
-	ResetWedges(w);
+	ResetPieces(w);
 #endif
 	while ((c = getc(fp)) != EOF && c != SYMBOL);
 	(void) fscanf(fp, "%d", &moves);
@@ -1808,7 +1809,7 @@ ClearWedges(MballWidget w)
 {
 	if (w->mball.currentWedge >= 0)
 		return;
-	ResetWedges(w);
+	ResetPieces(w);
 	DrawAllWedges(w);
 	SetMball(w, MBALL_RESET);
 }
@@ -1824,7 +1825,7 @@ UndoWedges(MballWidget w)
 		if (control)
 			MoveControlCb(w, wedge, direction);
 		else {
-			MoveWedges(w, wedge, ring, direction);
+			MovePieces(w, wedge, ring, direction);
 			SetMball(w, MBALL_UNDO);
 		}
 	}
@@ -1859,8 +1860,8 @@ RandomizeWedges(MballWidget w)
 		do
 			randomDirection = NRAND(2 * COORD);
 		while (randomDirection < COORD &&
-		       mapDirToWedge[(w->mball.wedges - MINWEDGES) / 2][randomDirection] ==
-		       CUTS);
+			mapDirToWedge[(w->mball.wedges - MINWEDGES) / 2][randomDirection] ==
+				CUTS);
 		if (randomDirection >= COORD) {
 			if (randomDirection - COORD < CUTS)
 				randomDirection = CW;
@@ -1995,7 +1996,7 @@ GetColor(MballWidget w, int wedge)
 	if (!w->mball.mono) {
 		if (XAllocNamedColor(XtDisplay(w),
 				DefaultColormapOfScreen(XtScreen(w)),
-			    w->mball.wedgeName[wedge], &colorCell, &rgb)) {
+				w->mball.wedgeName[wedge], &colorCell, &rgb)) {
 			values.foreground = w->mball.wedgeColor[wedge] = colorCell.pixel;
 			if (w->mball.wedgeGC[wedge])
 				XtReleaseGC((Widget) w, w->mball.wedgeGC[wedge]);
@@ -2095,7 +2096,7 @@ SetValuesMball(Widget current, Widget request, Widget renew)
 	Boolean redraw = False, setColors = False;
 	int wedge;
 
-	CheckWedges(w);
+	CheckPieces(w);
 	for (wedge = 0; wedge < MAXWEDGES; wedge++) {
 		if (strcmp(w->mball.wedgeName[wedge], c->mball.wedgeName[wedge])) {
 			setColors = True;
@@ -2118,7 +2119,7 @@ SetValuesMball(Widget current, Widget request, Widget renew)
 	if (w->mball.orient != c->mball.orient ||
 			w->mball.base != c->mball.base ||
 			w->mball.practice != c->mball.practice) {
-		ResetWedges(w);
+		ResetPieces(w);
 		redraw = True;
 	}
 	if (w->mball.wedges != c->mball.wedges ||
@@ -2245,7 +2246,7 @@ static
 void
 SizeMball(MballWidget w)
 {
-	ResetWedges(w);
+	ResetPieces(w);
 	ResizeMball(w);
 }
 
@@ -2271,7 +2272,7 @@ Widget request, Widget renew
 		w->mball.mono);
 	w->mball.fontInfo = NULL;
 	for (wedge = 0; wedge < MAXWEDGES; wedge++)
-		 w->mball.wedgeGC[wedge] = NULL;
+		w->mball.wedgeGC[wedge] = NULL;
 	w->mball.borderGC = NULL;
 	w->mball.frameGC = NULL;
 	w->mball.inverseGC = NULL;
@@ -2280,7 +2281,7 @@ Widget request, Widget renew
 	loadFont(w);
 	for (wedge = 0; wedge < MAXWEDGES; wedge++)
 		w->mball.mballLoc[wedge] = NULL;
-	CheckWedges(w);
+	CheckPieces(w);
 	InitMoves();
 	w->mball.cheat = False;
 	SizeMball(w);
@@ -2348,8 +2349,8 @@ SelectMball(MballWidget w
 	int control = (int) (event->xkey.state & ControlMask);
 #endif
 
-	if (SelectWedges(w, x, y,
-		 &(w->mball.currentWedge), &(w->mball.currentRing), &view)) {
+	if (PositionToSector(w, x, y, &(w->mball.currentWedge),
+				&(w->mball.currentRing), &view)) {
 		if (control || w->mball.practice || !CheckSolved(w))
 			DrawSector(w, w->mball.currentWedge, w->mball.currentRing,
 				TRUE);
@@ -2379,8 +2380,8 @@ ReleaseMball(MballWidget w
 		return;
 	DrawSector(w, w->mball.currentWedge, w->mball.currentRing, FALSE);
 	if (!control && !w->mball.practice && CheckSolved(w))
-		MoveNoWedges(w);
-	else if (SelectWedges(w, x, y, &wedge, &ring, &view)) {
+		MoveNoPieces(w);
+	else if (PositionToSector(w, x, y, &wedge, &ring, &view)) {
 		opp = (w->mball.currentWedge + w->mball.wedges / 2) %
 			w->mball.wedges;
 		if (ring == w->mball.currentRing) {
@@ -2410,14 +2411,14 @@ ReleaseMball(MballWidget w
 			SetMball(w, MBALL_AMBIGUOUS);
 		} else if (opp == (wedge + 1) % w->mball.wedges)
 			MoveMball(w, wedge, ring,
-			    mapWedgeToDir[(w->mball.wedges - MINWEDGES) / 2]
-				  [w->mball.currentWedge], control);
+				mapWedgeToDir[(w->mball.wedges - MINWEDGES) / 2]
+				[w->mball.currentWedge], control);
 		else if (wedge == (opp + 1) % w->mball.wedges)
 			MoveMball(w, wedge, ring,
-				  mapWedgeToDir[(w->mball.wedges - MINWEDGES) /
-				  2][wedge], control);
+				mapWedgeToDir[(w->mball.wedges - MINWEDGES) /
+				2][wedge], control);
 		else
-			MoveNoWedges(w);
+			MoveNoPieces(w);
 	}
 	w->mball.currentWedge = -1;
 }
