@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -96,7 +96,7 @@ static HWND Wnd;
 
 #ifdef HAVE_MOTIF
 static const char aboutHelp[] = {
-	"Version 7.1\n"
+	"Version 7.1.3\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
@@ -106,7 +106,7 @@ static const char optionsHelp[] = {
 	"[-geometry [{width}][x{height}][{+-}{xoff}[{+-}{yoff}]]] "
 	"[-display [{host}]:[{vs}]] [-[no]mono] [-[no]{reverse|rv}]\n"
 	"[-{foreground|fg} {color}] [-{background|bg} {color}] "
-	"[-{border|bd} {color}] [-wedge{0|1|2|3|4|5|6|7} {color}]\n"
+	"[-{border|bd} {color}] [-wedge{0|1|2|3|4|5|6|7|8|9|10|11} {color}]\n"
 	"[-wedges {int}] [-ring {int}] [-[no]orient] [-[no]practice] "
 	"[-base {int}] [-{font|fn} {fontname}] [-username {string}]\n"
 };
@@ -121,9 +121,9 @@ static const char descriptionHelp[] = {
 	"and a variety of picture Masterballs.  For some reason,\n"
 	"they say the Geomaster is easier than the Duomaster.  The "
 	"picture Masterballs are the hardest since all the pieces\n"
-	"have a set solved postion.  On the Duo and Geo Masterballs "
+	"have a set solved position.  On the Duo and Geo Masterballs "
 	"pieces could be swapped or in a different order and still\n"
-	"be in a solved postion.  Zurick University's Mathematics "
+	"be in a solved position.  Zurick University's Mathematics "
 	"faculty has calculated that Masterball's 32 segments can\n"
 	"be arranged in 355,682,548,566,633,480,192,000,000 different "
 	"possible combinations.  Masterball was invented by Dr.\n"
@@ -847,6 +847,32 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
+#if (_WIN32_WINNT >= 0x0400) || (_WIN32_WINDOWS > 0x0400)
+		case WM_MOUSEWHEEL:
+			widget.core.hDC = GetDC(hWnd);
+			(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
+			{
+				int zDelta = ((short) HIWORD(wParam));
+				POINT cursor, origin;
+
+				origin.x = 0, origin.y = 0;
+				ClientToScreen(hWnd, &origin);
+				(void) GetCursorPos(&cursor);
+				if (zDelta > (WHEEL_DELTA >> 1)) {
+					MoveMballInput(&widget,
+						cursor.x - origin.x, cursor.y - origin.y,
+						TOP,
+				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
+				} else if (zDelta < -(WHEEL_DELTA >> 1)) {
+					MoveMballInput(&widget,
+						cursor.x - origin.x, cursor.y - origin.y,
+						BOTTOM,
+				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
+				}
+			}
+			(void) ReleaseDC(hWnd, widget.core.hDC);
+			break;
+#endif
 		case WM_COMMAND:
 			switch (LOWORD(wParam)) {
 				case IDM_GET:
@@ -1061,7 +1087,7 @@ Usage(char * programName)
 	(void) fprintf(stderr,
 		"\t[-{foreground|fg} {color}] [-{background|bg} {color}]\n");
 	(void) fprintf(stderr,
-		"\t[-{border|bd} {color}] [-wedge{0|1|2|3|4|5|6|7} {color}]\n");
+		"\t[-{border|bd} {color}] [-wedge{0|1|2|3|4|5|6|7|8|9|10|11} {color}]\n");
 	(void) fprintf(stderr,
 		"\t[-{wedges {int}}] [-{rings {int}}] [-[no]orient] [-[no]practice]\n");
 	(void) fprintf(stderr,
@@ -1091,6 +1117,10 @@ static XrmOptionDescRec options[] =
 	{(char *) "-wedge5", (char *) "*mball.wedgeColor5", XrmoptionSepArg, NULL},
 	{(char *) "-wedge6", (char *) "*mball.wedgeColor6", XrmoptionSepArg, NULL},
 	{(char *) "-wedge7", (char *) "*mball.wedgeColor7", XrmoptionSepArg, NULL},
+	{(char *) "-wedge8", (char *) "*mball.wedgeColor8", XrmoptionSepArg, NULL},
+	{(char *) "-wedge9", (char *) "*mball.wedgeColor9", XrmoptionSepArg, NULL},
+	{(char *) "-wedge10", (char *) "*mball.wedgeColor10", XrmoptionSepArg, NULL},
+	{(char *) "-wedge11", (char *) "*mball.wedgeColor11", XrmoptionSepArg, NULL},
 	{(char *) "-wedges", (char *) "*mball.wedges", XrmoptionSepArg, NULL},
 	{(char *) "-rings", (char *) "*mball.rings", XrmoptionSepArg, NULL},
 	{(char *) "-orient", (char *) "*mball.orient", XrmoptionNoArg, (char *) "TRUE"},
