@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -90,29 +90,42 @@ static void InitializeMlink(Widget request, Widget renew);
 static void ExposeMlink(Widget renew, XEvent * event, Region region);
 static void HideMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
 static void SelectMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
-static void ReleaseMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
-static void PracticeMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
-static void PracticeMlinkMaybe(MlinkWidget w, XEvent * event, char **args, int nArgs);
-static void PracticeMlink2(MlinkWidget w, XEvent * event, char **args, int nArgs);
-static void RandomizeMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
-static void RandomizeMlinkMaybe(MlinkWidget w, XEvent * event, char **args, int nArgs);
-static void RandomizeMlink2(MlinkWidget w, XEvent * event, char **args, int nArgs);
+static void MotionMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
+static void ReleaseMlink(MlinkWidget w, XEvent * event,
+	char **args, int nArgs);
+static void PracticeMlink(MlinkWidget w, XEvent * event,
+	char **args, int nArgs);
+static void PracticeMlinkMaybe(MlinkWidget w, XEvent * event,
+	char **args, int nArgs);
+static void PracticeMlink2(MlinkWidget w, XEvent * event,
+	char **args, int nArgs);
+static void RandomizeMlink(MlinkWidget w, XEvent * event,
+	char **args, int nArgs);
+static void RandomizeMlinkMaybe(MlinkWidget w, XEvent * event,
+	char **args, int nArgs);
+static void RandomizeMlink2(MlinkWidget w, XEvent * event,
+	char **args, int nArgs);
 static void GetMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
 static void WriteMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
 static void ClearMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
 static void UndoMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
 static void SolveMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
-static void OrientizeMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
+static void OrientizeMlink(MlinkWidget w, XEvent * event,
+	char **args, int nArgs);
 static void MiddleMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
 static void SpeedMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
 static void SlowMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
 static void SoundMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
 static void EnterMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
 static void LeaveMlink(MlinkWidget w, XEvent * event, char **args, int nArgs);
-static void MoveMlinkTop(MlinkWidget w, XEvent * event, char **args, int nArgs);
-static void MoveMlinkLeft(MlinkWidget w, XEvent * event, char **args, int nArgs);
-static void MoveMlinkRight(MlinkWidget w, XEvent * event, char **args, int nArgs);
-static void MoveMlinkBottom(MlinkWidget w, XEvent * event, char **args, int nArgs);
+static void MoveMlinkTop(MlinkWidget w, XEvent * event,
+	char **args, int nArgs);
+static void MoveMlinkBottom(MlinkWidget w, XEvent * event,
+	char **args, int nArgs);
+static void MoveMlinkLeft(MlinkWidget w, XEvent * event,
+	char **args, int nArgs);
+static void MoveMlinkRight(MlinkWidget w, XEvent * event,
+	char **args, int nArgs);
 
 static char defaultTranslationsMlink[] =
 "<KeyPress>q: Quit()\n\
@@ -143,6 +156,7 @@ static char defaultTranslationsMlink[] =
  <KeyPress>KP_2: MoveBottom()\n\
  <KeyPress>R14: MoveBottom()\n\
  <Btn1Down>: Select()\n\
+ <Btn1Motion>: Motion()\n\
  <Btn1Up>: Release()\n\
  <KeyPress>p: Practice()\n\
  <KeyPress>r: Randomize()\n\
@@ -161,7 +175,6 @@ static char defaultTranslationsMlink[] =
  <KeyPress>0x3E: Speed()\n\
  <KeyPress>0x3C: Slow()\n\
  <KeyPress>0x2C: Slow()\n\
- <KeyPress>2: Sound()\n\
  <KeyPress>@: Sound()\n\
  <EnterWindow>: Enter()\n\
  <LeaveWindow>: Leave()";
@@ -175,6 +188,7 @@ static XtActionsRec actionsListMlink[] =
 	{(char *) "MoveRight", (XtActionProc) MoveMlinkRight},
 	{(char *) "MoveBottom", (XtActionProc) MoveMlinkBottom},
 	{(char *) "Select", (XtActionProc) SelectMlink},
+	{(char *) "Motion", (XtActionProc) MotionMlink},
 	{(char *) "Release", (XtActionProc) ReleaseMlink},
 	{(char *) "Practice", (XtActionProc) PracticeMlink},
 	{(char *) "PracticeMaybe", (XtActionProc) PracticeMlinkMaybe},
@@ -498,7 +512,6 @@ initTimer(MlinkWidget w)
 #endif
 }
 
-
 static void
 useTimer(MlinkWidget w, int delay)
 {
@@ -615,12 +628,17 @@ Row(MlinkWidget w, int pos)
 	return (pos / w->mlink.tiles);
 }
 
-static void
-Cartesian(MlinkWidget w, int pos, int * x, int * y)
+static int
+CartesianX(MlinkWidget w, int pos)
 {
-	*x = Column(w, pos) * w->mlink.offset.x + w->mlink.delta.x +
+	return Column(w, pos) * w->mlink.offset.x + w->mlink.delta.x +
 		w->mlink.puzzleOffset.x;
-	*y = Row(w, pos) * (w->mlink.offset.y + 1) + w->mlink.delta.y +
+}
+
+static int
+CartesianY(MlinkWidget w, int pos)
+{
+	return Row(w, pos) * (w->mlink.offset.y + 1) + w->mlink.delta.y +
 		w->mlink.puzzleOffset.y;
 }
 
@@ -765,9 +783,9 @@ DrawLink(MlinkWidget w, Pixmap dr, GC gc, int pos, int offsetX, int offsetY)
 
 	sizex = w->mlink.offset.x * 3 / 2 - 6;
 	sizey = w->mlink.offset.y * 3 / 4 - 6;
-	Cartesian(w, pos, &dx, &dy);
-	dx += -sizex / 2 + offsetX + 2;
-	dy += w->mlink.tileSize.y / 2 - sizey / 2 - 1 + offsetY;
+	dx = CartesianX(w, pos) - sizex / 2 + offsetX + 2;
+	dy = CartesianY(w, pos) + w->mlink.tileSize.y / 2 - sizey / 2 -
+		1 + offsetY;
 	thick = MIN(sizey, sizex) / 3;
 	thick = MIN(thick, THICKNESS);
 	if (thick > 0) {
@@ -833,15 +851,17 @@ DrawLink(MlinkWidget w, Pixmap dr, GC gc, int pos, int offsetX, int offsetY)
 	for (i = 0; i < THICKNESS; i++) {
 		sizex = w->mlink.offset.x * 3 / 2 - i;
 		sizey = w->mlink.offset.y * 3 / 4 - i;
-		Cartesian(w, pos, &dx, &dy);
-		dx += -sizex / 2 + offsetX;
-		dy += w->mlink.tileSize.y / 2 - sizey / 2 + offsetY;
-		if (tile % w->mlink.tiles == 0 || tile == w->mlink.tileFaces - 1) }
+		dx = CartesianX(w, pos) - sizex / 2 + offsetX;
+		dy = CartesianY(w, pos) + w->mlink.tileSize.y / 2 - sizey / 2 +
+			offsetY;
+		if (tile % w->mlink.tiles == 0 ||
+				tile == w->mlink.tileFaces - 1) {
 			DRAWARC(w, dr, gc, 1, gc, dx, dy,
 				 sizex, sizey, 89 * MULT, -179 * MULT);
 		} else if (tile % w->mlink.tiles == 1) {
-			DRAWARC(w, dr, gc, 1, gc, dx + w->mlink.tileSize.x - 1, dy,
-				 sizex, sizey, 90 * MULT, 180 * MULT);
+			DRAWARC(w, dr, gc, 1, gc,
+				dx + w->mlink.tileSize.x - 1, dy,
+				sizex, sizey, 90 * MULT, 180 * MULT);
 		} else {
 			DRAWARC(w, dr, gc, 1, gc, dx, dy,
 				 sizex, sizey, 89 * MULT, -32 * MULT);
@@ -876,10 +896,10 @@ DrawTile(MlinkWidget w, int pos, Boolean blank, Boolean erase,
 		w->mlink.tileFaces;
 	Pixmap dr = 0;
 
-	Cartesian(w, pos, &dx, &dy);
-	dx += pressedOffset + offsetX;
-	dy += pressedOffset + offsetY;
-	Cartesian(w, tile, &sx, &sy);
+	dx = CartesianX(w, pos) + pressedOffset + offsetX;
+	dy = CartesianY(w, pos) + pressedOffset + offsetY;
+	sx = CartesianX(w, tile);
+	sy = CartesianY(w, tile);
 	if (blank) {
 		FILLRECTANGLE(w, dr,
 			(erase) ? w->mlink.inverseGC : w->mlink.tileGC,
@@ -935,9 +955,8 @@ DrawBufferedTile(MlinkWidget w, int pos, int pressedOffset)
 		}
 #endif
 	}
-	Cartesian(w, pos, &dx, &dy);
-	dx += pressedOffset;
-	dy += pressedOffset;
+	dx = CartesianX(w, pos) + pressedOffset;
+	dy = CartesianY(w, pos) + pressedOffset;
 	if (pressedOffset != 0) {
 		drawShadow(w, *dr, w->mlink.tileDarkerGC,
 			dx - pressedOffset, dy - pressedOffset,
@@ -995,7 +1014,7 @@ DrawBufferedTile(MlinkWidget w, int pos, int pressedOffset)
 		DrawLink(w, *dr, linkGC, pos, pressedOffset, pressedOffset);
 #if 0
 	DRAWRECTANGLE(w, *dr, borderGC, dx, dy,
-		w->mlink.tileSize.x + 1, w->mlink.tileSize.y - 1);
+		w->mlink.tileSize.x - 1, w->mlink.tileSize.y - 1);
 #endif
 }
 
@@ -1029,7 +1048,8 @@ AnimateSlide(MlinkWidget w, int numTiles, int dir, int fast, Boolean logMoves)
 	Pixmap dr = 0;
 
 	fillBeginPos = TileNFromSpace(w, numTiles, dir);
-	Cartesian(w, fillBeginPos, &fillBeginI, &dy);
+	fillBeginI = CartesianX(w, fillBeginPos);
+	dy = CartesianY(w, fillBeginPos);
 	gapI = w->mlink.tileSize.x * fast / w->mlink.numSlices;
 	moveI = w->mlink.tileSize.x + w->mlink.delta.x;
 	if (gapI == 0)
@@ -1047,7 +1067,8 @@ AnimateSlide(MlinkWidget w, int numTiles, int dir, int fast, Boolean logMoves)
 	      PutMove(dir, posNext, 0);
 	    }
 	    /* Calculate deltas */
-	    Cartesian(w, posNext, &dx, &dy);
+	    dx = CartesianX(w, posNext);
+	    dy = CartesianY(w, posNext);
 	    ix = ((dir == RIGHT) ? inc : -inc);
 	    iy = 0;
 	    DrawTile(w, posNext, False, False, FALSE, ix, iy);
@@ -1056,32 +1077,32 @@ AnimateSlide(MlinkWidget w, int numTiles, int dir, int fast, Boolean logMoves)
 	    iy += dy;
 	    if (aTile < numTiles - 1) {
 	      switch (dir) {
-	        case RIGHT:
-	          FILLRECTANGLE(w, dr,
-	            w->mlink.inverseGC,
-	            ix - gapI, iy, gapI, w->mlink.tileSize.y);
-	          break;
-	        case LEFT:
-	          FILLRECTANGLE(w, dr,
-	            w->mlink.inverseGC,
-	            ix + w->mlink.tileSize.x, iy,
-	            gapI, w->mlink.tileSize.y);
-		  break;
+	      case RIGHT:
+		FILLRECTANGLE(w, dr,
+		  w->mlink.inverseGC,
+		  ix - gapI, iy, gapI, w->mlink.tileSize.y);
+		break;
+	      case LEFT:
+		FILLRECTANGLE(w, dr,
+		  w->mlink.inverseGC,
+		  ix + w->mlink.tileSize.x, iy,
+		  gapI, w->mlink.tileSize.y);
+		break;
 	      }
 	    } else {
 	      switch (dir) {
-	        case RIGHT:
-	          FILLRECTANGLE(w, dr,
-	            w->mlink.inverseGC,
-	            fillBeginI, iy,
-	            ix - fillBeginI, w->mlink.tileSize.y);
-	          break;
-	        case LEFT:
-	          FILLRECTANGLE(w, dr,
-	            w->mlink.inverseGC,
-	            ix + w->mlink.tileSize.x, iy,
-	            fillBeginI - ix, w->mlink.tileSize.y);
-		 break;
+	      case RIGHT:
+		FILLRECTANGLE(w, dr,
+		  w->mlink.inverseGC,
+		  fillBeginI, iy,
+		  ix - fillBeginI, w->mlink.tileSize.y);
+		break;
+	      case LEFT:
+		FILLRECTANGLE(w, dr,
+		  w->mlink.inverseGC,
+		  ix + w->mlink.tileSize.x, iy,
+		  fillBeginI - ix, w->mlink.tileSize.y);
+		break;
 	      }
 	    }
 	  }
@@ -1089,10 +1110,10 @@ AnimateSlide(MlinkWidget w, int numTiles, int dir, int fast, Boolean logMoves)
 	}
 	pos = w->mlink.spacePosition;
 	for (aTile = 0; aTile < numTiles; aTile++) {
-	    posNext = TileNFromSpace(w, aTile + 1, dir);
-	    w->mlink.tileOfPosition[pos] =
-	      w->mlink.tileOfPosition[posNext];
-	    pos = posNext;
+	  posNext = TileNFromSpace(w, aTile + 1, dir);
+	  w->mlink.tileOfPosition[pos] =
+	    w->mlink.tileOfPosition[posNext];
+	  pos = posNext;
 	}
 	w->mlink.spacePosition = fillBeginPos;
 	w->mlink.tileOfPosition[fillBeginPos] = 0;
@@ -1139,7 +1160,7 @@ AnimateRotate(MlinkWidget w, int start, int finish, int direction, int fast)
 			w->mlink.puzzleSize.y);
 	SelectObject(memDC, hBit);
 	BitBlt(memDC, 0, 0,
-		size * moveI + 1,
+		size * moveI,
 		w->mlink.puzzleSize.y,
 		w->core.hDC,
 		start * moveI + w->mlink.puzzleOffset.x + 1,
@@ -1148,7 +1169,7 @@ AnimateRotate(MlinkWidget w, int start, int finish, int direction, int fast)
 #else
 	(void) XGetWindowAttributes(XtDisplay(w), XtWindow(w), &xgwa);
 	if ((bufferBox = XCreatePixmap(XtDisplay(w), XtWindow(w),
-			size * moveI + 1,
+			size * moveI,
 			w->mlink.puzzleSize.y,
 			xgwa.depth)) == None) {
 		DISPLAY_ERROR("Not enough memory, exiting.");
@@ -1157,7 +1178,7 @@ AnimateRotate(MlinkWidget w, int start, int finish, int direction, int fast)
 		w->mlink.frameGC,
 		start * moveI + w->mlink.puzzleOffset.x + 1,
 		w->mlink.puzzleOffset.y,
-		size * moveI + 1,
+		size * moveI,
 		w->mlink.puzzleSize.y,
 		0, 0);
 	XSetGraphicsExposures(XtDisplay(w), w->mlink.frameGC, False);
@@ -1175,7 +1196,7 @@ AnimateRotate(MlinkWidget w, int start, int finish, int direction, int fast)
 		BitBlt(w->core.hDC,
 			start * moveI + w->mlink.puzzleOffset.x + 1,
 			w->mlink.puzzleOffset.y + 1,
-			size * moveI + 1,
+			size * moveI,
 			w->mlink.puzzleSize.y - i,
 			memDC,
 			0, i,
@@ -1184,7 +1205,7 @@ AnimateRotate(MlinkWidget w, int start, int finish, int direction, int fast)
 			start * moveI + w->mlink.puzzleOffset.x + 1,
 			w->mlink.puzzleSize.y - i + w->mlink.puzzleOffset.y -
 			w->mlink.delta.y + 1,
-			size * moveI + 1,
+			size * moveI,
 			i - w->mlink.delta.y,
 			memDC,
 			0, 0,
@@ -1193,14 +1214,14 @@ AnimateRotate(MlinkWidget w, int start, int finish, int direction, int fast)
 		XCopyArea(XtDisplay(w), bufferBox, XtWindow(w),
 			w->mlink.frameGC,
 			0, i,
-			size * moveI + 1,
+			size * moveI,
 			w->mlink.puzzleSize.y - i,
 			start * moveI + w->mlink.puzzleOffset.x + 1,
 			w->mlink.puzzleOffset.y + 1);
 		XCopyArea(XtDisplay(w), bufferBox, XtWindow(w),
 			w->mlink.frameGC,
 			0, 0,
-			size * moveI + 1,
+			size * moveI,
 			i - w->mlink.delta.y,
 			start * moveI + w->mlink.puzzleOffset.x + 1,
 			w->mlink.puzzleSize.y - i + w->mlink.puzzleOffset.y -
@@ -1216,42 +1237,6 @@ AnimateRotate(MlinkWidget w, int start, int finish, int direction, int fast)
 #endif
 }
 
-static void
-ResetTiles(MlinkWidget w)
-{
-	int i;
-
-	w->mlink.tileFaces = w->mlink.tiles * w->mlink.faces;
-	if (w->mlink.tileOfPosition)
-		free(w->mlink.tileOfPosition);
-	if (!(w->mlink.tileOfPosition = (int *)
-			malloc(sizeof (int) * w->mlink.tileFaces))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-
-	if (startPosition)
-		free(startPosition);
-	if (!(startPosition = (int *)
-			malloc(sizeof (int) * w->mlink.tileFaces))) {
-		DISPLAY_ERROR("Not enough memory, exiting.");
-	}
-
-	w->mlink.spacePosition = w->mlink.tileFaces - 1;
-	w->mlink.tileOfPosition[w->mlink.tileFaces - 1] = 0;
-	for (i = 1; i < w->mlink.tileFaces; i++)
-		w->mlink.tileOfPosition[i - 1] = i;
-	FlushMoves(w);
-	w->mlink.currentRef = -w->mlink.tileFaces;
-	w->mlink.started = False;
-}
-
-static void
-EraseFrame(const MlinkWidget w, Pixmap dr)
-{
-	FILLRECTANGLE(w, dr, w->mlink.inverseGC,
-		0, 0, w->core.width, w->core.height);
-}
-
 static void
 DrawFrame(MlinkWidget w, Pixmap dr, Boolean focus)
 {
@@ -1287,6 +1272,13 @@ DrawFrame(MlinkWidget w, Pixmap dr, Boolean focus)
 	}
 }
 
+static void
+EraseFrame(const MlinkWidget w, Pixmap dr)
+{
+	FILLRECTANGLE(w, dr, w->mlink.inverseGC,
+		0, 0, w->core.width, w->core.height);
+}
+
 static void
 MoveNoTiles(MlinkWidget w)
 {
@@ -1378,7 +1370,7 @@ RotateTiles(MlinkWidget w, int start, int finish, int direction, int fast)
 
 		FILLRECTANGLE(w, dr, w->mlink.inverseGC,
 			start * moveI + w->mlink.puzzleOffset.x + 1, 0,
-			(finish - start + 1) * moveI + 1, w->core.height);
+			(finish - start + 1) * moveI, w->core.height);
 		DrawFrame(w, dr, w->mlink.focus);
 		DrawAllTilesForColumns(w, start, finish);
 	}
@@ -1390,7 +1382,7 @@ RotateTiles(MlinkWidget w, int start, int finish, int direction, int fast)
 	}
 #endif
 }
-
+ 
 static Boolean
 MoveTilesDir(MlinkWidget w, int direction, int tile, Boolean all, int fast)
 {
@@ -1459,6 +1451,13 @@ DiscreteMoves(MlinkWidget w, int from, int dir)
 	PutMove(dir, from, 0);
 }
 
+static void
+MoveShift(MlinkWidget w, int direction, int fast)
+{
+	(void) MoveTilesDir(w, direction, 0, True, fast);
+	SetMlink(w, MLINK_CONTROL);
+}
+
 static void
 ControlMlink(MlinkWidget w, int direction)
 {
@@ -1494,75 +1493,69 @@ ControlMlink(MlinkWidget w, int direction)
 	}
 }
 
-static void
-MoveShift(MlinkWidget w, int direction, int fast)
+Boolean
+MoveMlink(MlinkWidget w, const int direction, const int tile, const int shift,
+		const Boolean motion, const int fast)
 {
-	(void) MoveTilesDir(w, direction, 0, True, fast);
-	SetMlink(w, MLINK_CONTROL);
-}
-
-static void
-SlideMlink(MlinkWidget w, int direction, int pos)
-{
-	if (CheckSolved(w) && !w->mlink.practice) {
-		MoveNoTiles(w);
-		return;
-	}
-	if (!MoveMlink(w, direction, pos, FALSE, NORMAL)) {
-		SetMlink(w, MLINK_BLOCKED);
-		return;
-	}
-	if (CheckSolved(w)) {
-		SetMlink(w, MLINK_SOLVED);
-	}
-	return;
-}
-
-static void
-RotateMlink(MlinkWidget w, int direction, int tile)
-{
-	if (CheckSolved(w) && !w->mlink.practice) {
-		MoveNoTiles(w);
-		return;
-	}
-	(void) MoveMlink(w, direction, tile, FALSE, NORMAL);
-	if (CheckSolved(w)) {
-		SetMlink(w, MLINK_SOLVED);
-	}
-	return;
-}
-
-#ifndef WINVER
-static
-#endif
-void
-MoveMlinkInput(MlinkWidget w, int x, int direction, int shift, int control)
-{
-	int r;
-
-	if (control)
-		ControlMlink(w, direction);
-	else if (shift && (direction == TOP || direction == BOTTOM)) {
-		MoveShift(w, direction, NORMAL);
-		PutMove(direction, 0, 1);
-	} else if (CheckSolved(w) && !w->mlink.practice) {
-		MoveNoTiles(w);
-		return;
-	} else if (direction == LEFT || direction == RIGHT) {
-		SlideMlink(w, direction, w->mlink.spacePosition + direction - BOTTOM);
-		if (CheckSolved(w)) {
-			SetMlink(w, MLINK_SOLVED);
+	if (shift != 0 && (direction == TOP || direction == BOTTOM)) {
+		MoveShift(w, direction, fast);
+		if (!motion) {
+			PutMove(direction, tile, 1);
 		}
+		return True;
+	} else if (MoveTilesDir(w, direction, tile, False, fast)) {
+		if (!motion) {
+			SetMlink(w, MLINK_MOVED);
+			PutMove(direction, tile, 0);
+		}
+		return True;
+	}
+	return False;
+}
+
+static void
+DiffMove(MlinkWidget w, int diff, int j, int shift)
+{
+	int k;
+
+	if (diff > w->mlink.faces / 2 ||
+	    (diff == (w->mlink.faces + 1) / 2 && j > w->mlink.currentFace))
+		for (k = 0; k < w->mlink.faces - diff; k++)
+			(void) MoveMlink(w, BOTTOM, w->mlink.currentTile,
+				shift, True, NORMAL);
+	else
+		for (k = 0; k < diff; k++)
+			(void) MoveMlink(w, TOP, w->mlink.currentTile,
+				shift, True, NORMAL);
+}
+
+static void
+MoveRecord(MlinkWidget w, const int direction, const int tile, const int shift)
+{
+	if (shift != 0 && (direction == TOP || direction == BOTTOM)) {
+		PutMove(direction, tile, 1);
 	} else {
-		if (!PositionTile(w, x, &r))
-			return;
-		RotateMlink(w, direction, r);
-		if (CheckSolved(w)) {
-			SetMlink(w, MLINK_SOLVED);
-		}
+		SetMlink(w, MLINK_MOVED);
+		PutMove(direction, tile, 0);
 	}
 }
 
+static void
+DiffRecord(MlinkWidget w, int diff, int j, int shift)
+{
+	int k;
+
+	if (diff > w->mlink.faces / 2 ||
+	    (diff == (w->mlink.faces + 1) / 2 && j > w->mlink.currentFace))
+		for (k = 0; k < w->mlink.faces - diff; k++)
+			(void) MoveRecord(w, BOTTOM,
+				w->mlink.currentTile, shift);
+	else
+		for (k = 0; k < diff; k++)
+			(void) MoveRecord(w, TOP,
+				w->mlink.currentTile, shift);
+}
+
 void
 MoveMlinkDelay(MlinkWidget w,
 		const int direction, const int tile, const Boolean all)
@@ -1589,30 +1582,77 @@ MoveMlinkDelay(MlinkWidget w,
 	Sleep((unsigned int) w->mlink.delay);
 }
 
-Boolean
-MoveMlink(MlinkWidget w, const int direction, const int tile, const int shift,
-		const int fast)
+static void
+SlideMlink(MlinkWidget w, int direction, int pos)
 {
-	if (shift && (direction == TOP || direction == BOTTOM)) {
-		MoveShift(w, direction, fast);
-		PutMove(direction, tile, 1);
-		return True;
-	} else if (MoveTilesDir(w, direction, tile, False, fast)) {
-		SetMlink(w, MLINK_MOVED);
-		PutMove(direction, tile, 0);
-		return True;
+	if (CheckSolved(w) && !w->mlink.practice) {
+		MoveNoTiles(w);
+		return;
+	}
+	if (!MoveMlink(w, direction, pos, FALSE, False, NORMAL)) {
+		SetMlink(w, MLINK_BLOCKED);
+		return;
+	}
+	if (CheckSolved(w)) {
+		SetMlink(w, MLINK_SOLVED);
+	}
+	return;
+}
+
+static void
+RotateMlink(MlinkWidget w, int direction, int tile)
+{
+	if (CheckSolved(w) && !w->mlink.practice) {
+		MoveNoTiles(w);
+		return;
+	}
+	(void) MoveMlink(w, direction, tile, FALSE, False, NORMAL);
+	if (CheckSolved(w)) {
+		SetMlink(w, MLINK_SOLVED);
+	}
+	return;
+}
+
+#ifndef WINVER
+static
+#endif
+void
+MoveMlinkInput(MlinkWidget w, int x, int direction, int shift, int control)
+{
+	int r;
+
+	if (control != 0)
+		ControlMlink(w, direction);
+	else if (shift != 0 && (direction == TOP || direction == BOTTOM)) {
+		MoveShift(w, direction, NORMAL);
+		PutMove(direction, 0, 1);
+	} else if (CheckSolved(w) && !w->mlink.practice) {
+		MoveNoTiles(w);
+		return;
+	} else if (direction == LEFT || direction == RIGHT) {
+		SlideMlink(w, direction, w->mlink.spacePosition + direction - BOTTOM);
+		if (CheckSolved(w)) {
+			SetMlink(w, MLINK_SOLVED);
+		}
+	} else {
+		if (!PositionTile(w, x, &r))
+			return;
+		RotateMlink(w, direction, r);
+		if (CheckSolved(w)) {
+			SetMlink(w, MLINK_SOLVED);
+		}
 	}
-	return False;
 }
 
 static int
 SelectTiles(MlinkWidget w, int x, int y, int *i, int *j)
 {
+	int temp = w->mlink.faces * w->mlink.offset.y + w->mlink.delta.y - 1;
+
 	*i = (x - w->mlink.delta.x / 2 - w->mlink.puzzleOffset.x) /
 		w->mlink.offset.x;
-	*j = ((y - w->mlink.delta.y / 2 - w->mlink.puzzleOffset.y) %
-	      (w->mlink.faces * w->mlink.offset.y + w->mlink.delta.y - 1)) /
-		w->mlink.offset.y;
+	*j = ((y - w->mlink.delta.y / 2 - w->mlink.puzzleOffset.y + temp) %
+		temp) / w->mlink.offset.y;
 	if (*i >= 0 && *j >= 0 &&
 	    *i < w->mlink.tiles && *j < w->mlink.faces)
 		return (*i + w->mlink.tiles * *j -
@@ -1656,6 +1696,35 @@ SelectSlideTiles(MlinkWidget w, int pos)
 	}
 }
 
+static void
+ResetTiles(MlinkWidget w)
+{
+	int i;
+
+	w->mlink.tileFaces = w->mlink.tiles * w->mlink.faces;
+	if (w->mlink.tileOfPosition)
+		free(w->mlink.tileOfPosition);
+	if (!(w->mlink.tileOfPosition = (int *)
+			malloc(sizeof (int) * w->mlink.tileFaces))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
+
+	if (startPosition)
+		free(startPosition);
+	if (!(startPosition = (int *)
+			malloc(sizeof (int) * w->mlink.tileFaces))) {
+		DISPLAY_ERROR("Not enough memory, exiting.");
+	}
+
+	w->mlink.spacePosition = w->mlink.tileFaces - 1;
+	w->mlink.tileOfPosition[w->mlink.tileFaces - 1] = 0;
+	for (i = 1; i < w->mlink.tileFaces; i++)
+		w->mlink.tileOfPosition[i - 1] = i;
+	FlushMoves(w);
+	w->mlink.currentRef = -w->mlink.tileFaces;
+	w->mlink.started = False;
+}
+
 static void
 GetTiles(MlinkWidget w)
 {
@@ -1856,7 +1925,7 @@ UndoTiles(MlinkWidget w)
 
 		GetMove(&direction, &tile, &shift);
 		direction = (direction + COORD / 2) % COORD;
-		if (shift && (direction == TOP || direction == BOTTOM)) {
+		if (shift != 0 && (direction == TOP || direction == BOTTOM)) {
 			MoveShift(w, direction, DOUBLE);
 		} else {
 			if (direction == LEFT)
@@ -1907,7 +1976,7 @@ RandomizeTiles(MlinkWidget w)
 		if (count % 2 &&
 		    !ExchangeTiles(w, 0, 1) &&
 		    !ExchangeTiles(w, w->mlink.tileFaces - 2,
-		               w->mlink.tileFaces - 1)) {
+				w->mlink.tileFaces - 1)) {
 			DISPLAY_WARNING("RandomizeTiles: should not get here");
 		}
 		DrawAllTiles(w);
@@ -1961,7 +2030,9 @@ RandomizeTiles(MlinkWidget w)
 #endif
 			if ((randomDirection + COORD / 2) % COORD != lastDirection ||
 			    w->mlink.tiles == 1 || w->mlink.faces == 1) {
-				if (MoveMlink(w, randomDirection, NRAND(w->mlink.tiles), FALSE, INSTANT))
+				if (MoveMlink(w, randomDirection,
+				    NRAND(w->mlink.tiles), FALSE, False,
+				    INSTANT))
 					lastDirection = randomDirection;
 				else
 					big++;
@@ -2590,8 +2661,8 @@ ResizeMlink(MlinkWidget w)
 	w->mlink.delta.y = 1;
 	w->mlink.offset.x = MAX(((int) w->core.width - 2) /
 		w->mlink.tiles, 0);
-	w->mlink.offset.y = MAX(((int) w->core.height /
-		w->mlink.faces - 2), 0);
+	w->mlink.offset.y = MAX((int) w->core.height /
+		w->mlink.faces - 2, 0);
 	w->mlink.faceSize.x = w->mlink.offset.x * w->mlink.tiles +
 		w->mlink.delta.x + 2;
 	w->mlink.faceSize.y = w->mlink.offset.y + w->mlink.delta.y + 2;
@@ -2720,12 +2791,15 @@ SelectMlink(MlinkWidget w
 	int shift = (int) (event->xkey.state & (ShiftMask | LockMask));
 #endif
 
+	w->mlink.motion = False;
+	w->mlink.motionDiff = 0;
+	w->mlink.shiftDiff = 0;
 	pos = SelectTiles(w, x, y, &i, &j);
 	if (-w->mlink.tileFaces != pos) {
 		w->mlink.currentTile = i;
 		w->mlink.currentFace = j;
 		w->mlink.currentRef = pos;
-		if (shift || w->mlink.practice || !CheckSolved(w)) {
+		if (shift != 0 || w->mlink.practice || !CheckSolved(w)) {
 			pos = w->mlink.currentTile + w->mlink.currentFace * w->mlink.tiles;
 			DrawTile(w, pos, (w->mlink.tileOfPosition[i + j * w->mlink.tiles] <= 0),
 				 False, TRUE, 0, 0);
@@ -2734,6 +2808,79 @@ SelectMlink(MlinkWidget w
 		w->mlink.currentRef = -w->mlink.tileFaces;
 }
 
+#ifndef WINVER
+static
+#endif
+void
+MotionMlink(MlinkWidget w
+#ifdef WINVER
+, const int x, const int y, const int shift
+#else
+, XEvent * event, char **args, int nArgs
+#endif
+)
+{
+	int i, j, pos, diff;
+#ifndef WINVER
+	int x = event->xbutton.x, y = event->xbutton.y;
+	int shift = (int) (event->xkey.state & (ShiftMask | LockMask));
+#endif
+
+	if (w->mlink.currentRef == -w->mlink.tileFaces)
+		return;
+	if (shift == 0 && !w->mlink.practice && CheckSolved(w)) {
+		MoveNoTiles(w);
+		w->mlink.currentRef = -w->mlink.tileFaces;
+		return;
+	}
+	pos = SelectTiles(w, x, y, &i, &j);
+	if (w->mlink.currentTile != i) {
+		int k = w->mlink.currentTile +
+			w->mlink.currentFace * w->mlink.tiles;
+
+		DrawTile(w, k, True, True, TRUE, 0, 0);
+		DrawTile(w, k, (w->mlink.tileOfPosition[k] <= 0),
+			(w->mlink.tileOfPosition[k] <= 0), FALSE, 0, 0);
+		DiffRecord(w, w->mlink.motionDiff, j, FALSE);
+		DiffRecord(w, w->mlink.shiftDiff, j, TRUE);
+		if (shift == 0 && CheckSolved(w)) {
+			SetMlink(w, MLINK_SOLVED);
+		}
+		w->mlink.currentTile = i;
+		w->mlink.currentFace = j;
+		w->mlink.currentRef = pos;
+		w->mlink.motionDiff = 0;
+		w->mlink.shiftDiff = 0;
+	}
+	if (-w->mlink.tileFaces != pos) {
+		if (j != w->mlink.currentFace) {
+			diff = (w->mlink.currentFace - j + w->mlink.faces) %
+				w->mlink.faces;
+			DiffMove(w, diff, j, shift);
+			if (shift == 0 && CheckSolved(w)) {
+				SetMlink(w, MLINK_SOLVED);
+			}
+			w->mlink.motion = True;
+			if (shift == 0)
+				w->mlink.motionDiff = (diff +
+					w->mlink.motionDiff) % w->mlink.faces;
+			else
+				w->mlink.shiftDiff = (diff +
+					w->mlink.shiftDiff) % w->mlink.faces;
+		}
+		w->mlink.currentTile = i;
+		w->mlink.currentFace = j;
+		w->mlink.currentRef = pos;
+		if (shift != 0 || w->mlink.practice || !CheckSolved(w)) {
+			pos = w->mlink.currentTile +
+				w->mlink.currentFace * w->mlink.tiles;
+			DrawTile(w, pos, (w->mlink.tileOfPosition[i + j * w->mlink.tiles] <= 0),
+				 False, TRUE, 0, 0);
+		}
+	} else
+		w->mlink.currentRef = -w->mlink.tileFaces;
+}
+
 #ifndef WINVER
 static
 #endif
@@ -2759,37 +2906,42 @@ ReleaseMlink(MlinkWidget w
 	if (w->mlink.tileOfPosition[pos] > 0) {
 		DrawTile(w, pos, False, False, FALSE, 0, 0);
 	}
-	if (!shift && !w->mlink.practice && CheckSolved(w))
+	if (shift == 0 && !w->mlink.practice && CheckSolved(w)) {
 		MoveNoTiles(w);
-	else {
-		pos = SelectTiles(w, x, y, &i, &j);
-		if (-w->mlink.tileFaces != pos) {
-			if (j == w->mlink.currentFace) {
-				pos = w->mlink.currentRef;
-				if (pos / w->mlink.tiles == 0 &&
-				    j == Row(w, w->mlink.spacePosition) && pos != 0) {
-					if (shift && CheckSolved(w))
-						MoveNoTiles(w);
-					else {
-						SelectSlideTiles(w, pos);
-						w->mlink.currentTile = w->mlink.tiles;
-						if (CheckSolved(w)) {
-							SetMlink(w, MLINK_SOLVED);
-						}
+		w->mlink.currentRef = -w->mlink.tileFaces;
+		return;
+	}
+	pos = SelectTiles(w, x, y, &i, &j);
+	if (-w->mlink.tileFaces != pos) {
+		if (j == w->mlink.currentFace && !w->mlink.motion) {
+			pos = w->mlink.currentRef;
+			if (pos / w->mlink.tiles == 0 &&
+			    j == Row(w, w->mlink.spacePosition) && pos != 0) {
+				if (shift != 0 && CheckSolved(w))
+					MoveNoTiles(w);
+				else {
+					SelectSlideTiles(w, pos);
+					w->mlink.currentTile = w->mlink.tiles;
+					if (CheckSolved(w)) {
+						SetMlink(w, MLINK_SOLVED);
 					}
 				}
-			} else {
-				diff = (w->mlink.currentFace - j + w->mlink.faces) % w->mlink.faces;
-				if (diff > w->mlink.faces / 2 || (diff == (w->mlink.faces + 1) / 2 &&
-						j > w->mlink.currentFace))
-					for (i = 0; i < w->mlink.faces - diff; i++)
-						(void) MoveMlink(w, BOTTOM, w->mlink.currentTile, shift, NORMAL);
-				else
-					for (i = 0; i < diff; i++)
-						(void) MoveMlink(w, TOP, w->mlink.currentTile, shift, NORMAL);
-				if (!shift && CheckSolved(w)) {
-					SetMlink(w, MLINK_SOLVED);
-				}
+			}
+		} else {
+			diff = (w->mlink.currentFace - j + w->mlink.faces) %
+				w->mlink.faces;
+			DiffMove(w, diff, j, shift);
+			if (shift == 0)
+				w->mlink.motionDiff = (diff +
+					w->mlink.motionDiff) %
+					w->mlink.faces;
+			else
+				w->mlink.shiftDiff = (diff +
+					w->mlink.shiftDiff) % w->mlink.faces;
+			DiffRecord(w, w->mlink.motionDiff, j, FALSE);
+			DiffRecord(w, w->mlink.shiftDiff, j, TRUE);
+			if (shift == 0 && CheckSolved(w)) {
+				SetMlink(w, MLINK_SOLVED);
 			}
 		}
 	}
@@ -3045,11 +3197,25 @@ LeaveMlink(MlinkWidget w
 
 #ifndef WINVER
 static void
-MoveMlinkTop(MlinkWidget w, XEvent * event, char **args, int nArgs)
+MoveMlinkTop(MlinkWidget w , XEvent * event, char **args, int nArgs
+)
 {
-	MoveMlinkInput(w, event->xbutton.x, TOP,
-		(int) (event->xkey.state & (ShiftMask | LockMask)),
-		(int) (event->xkey.state & ControlMask));
+	int x = event->xbutton.x;
+	int shift = (int) (event->xkey.state & (ShiftMask | LockMask));
+	int control = (int) (event->xkey.state & ControlMask);
+
+	MoveMlinkInput(w, x, TOP, shift, control);
+}
+
+static void
+MoveMlinkBottom(MlinkWidget w , XEvent * event, char **args, int nArgs
+)
+{
+	int x = event->xbutton.x;
+	int shift = (int) (event->xkey.state & (ShiftMask | LockMask));
+	int control = (int) (event->xkey.state & ControlMask);
+
+	MoveMlinkInput(w, x, BOTTOM, shift, control);
 }
 
 static void
@@ -3067,12 +3233,4 @@ MoveMlinkRight(MlinkWidget w, XEvent * event, char **args, int nArgs)
 		(int) (event->xkey.state & (ShiftMask | LockMask)),
 		(int) (event->xkey.state & ControlMask));
 }
-
-static void
-MoveMlinkBottom(MlinkWidget w, XEvent * event, char **args, int nArgs)
-{
-	MoveMlinkInput(w, event->xbutton.x, BOTTOM,
-		(int) (event->xkey.state & (ShiftMask | LockMask)),
-		(int) (event->xkey.state & ControlMask));
-}
 #endif
