@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -95,7 +95,7 @@ static HWND Wnd;
 
 #ifdef HAVE_MOTIF
 static const char aboutHelp[] = {
-	"Version 7.1.1\n"
+	"Version 7.1.3\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
@@ -151,11 +151,13 @@ static const char featuresHelp[] = {
 	"\n"
 	"Press \"W\" or \"w\" keys to save a puzzle.\n"
 	"\n"
+	"Press \"C\" or \"c\" keys to clear a puzzle.\n"
+	"\n"
 	"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
 	"\n"
 	"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
 	"\n"
-	"Press \"@\" or \"2\" keys to toggle the sound.\n"
+	"Press \"@\" key to toggle the sound.\n"
 	"\n"
 	"Press \"Esc\" key to hide program.\n"
 	"\n"
@@ -854,6 +856,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 {
 	HBRUSH brush = (HBRUSH) NULL;
 	PAINTSTRUCT paint;
+	static Boolean mousePressed = False;
 
 	Wnd = widget.core.hWnd = hWnd;
 	if (GetFocus()) {
@@ -895,19 +898,69 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case WM_LBUTTONDOWN:
+			mousePressed = True;
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
 			SelectMlink(&widget, LOWORD(lParam), HIWORD(lParam),
 				((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)));
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
+		case WM_MOUSEMOVE:
+			if (!(wParam & MK_LBUTTON)) {
+				mousePressed = False;
+				widget.core.hDC = GetDC(hWnd);
+				(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
+				ReleaseMlink(&widget, LOWORD(lParam), HIWORD(lParam),
+					((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)));
+				(void) ReleaseDC(hWnd, widget.core.hDC);
+				break;
+			}
+			widget.core.hDC = GetDC(hWnd);
+			(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
+			MotionMlink(&widget, LOWORD(lParam), HIWORD(lParam),
+				((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)));
+			(void) ReleaseDC(hWnd, widget.core.hDC);
+			break;
 		case WM_LBUTTONUP:
+			mousePressed = False;
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
 			ReleaseMlink(&widget, LOWORD(lParam), HIWORD(lParam),
 				((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)));
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
+#if (_WIN32_WINNT >= 0x0400) || (_WIN32_WINDOWS > 0x0400)
+		case WM_MOUSEWHEEL:
+			widget.core.hDC = GetDC(hWnd);
+			(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
+			{
+				int zDelta = ((short) HIWORD(wParam));
+				POINT cursor, origin;
+
+				origin.x = 0, origin.y = 0;
+				ClientToScreen(hWnd, &origin);
+				(void) GetCursorPos(&cursor);
+				if (zDelta > (WHEEL_DELTA >> 1)) {
+					MoveMlinkInput(&widget, cursor.x - origin.x, TOP,
+				((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)),
+				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
+					if (GetKeyState(VK_CONTROL) >> 1) {
+						SizeMlink(&widget);
+						(void) InvalidateRect(hWnd, NULL, TRUE);
+					}
+				} else if (zDelta < -(WHEEL_DELTA >> 1)) {
+					MoveMlinkInput(&widget, cursor.x - origin.x, BOTTOM,
+				((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)),
+				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
+					if (GetKeyState(VK_CONTROL) >> 1) {
+						SizeMlink(&widget);
+						(void) InvalidateRect(hWnd, NULL, TRUE);
+					}
+				}
+			}
+			(void) ReleaseDC(hWnd, widget.core.hDC);
+			break;
+#endif
 		case WM_COMMAND:
 			switch (LOWORD(wParam)) {
 				case IDM_GET:
@@ -1032,7 +1085,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 
 int WINAPI
 WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
-	int numCmdShow)
+		int numCmdShow)
 {
 	HWND hWnd;
 	MSG msg;
