@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -695,16 +695,13 @@ Sqrt(int i)
 	return (j - 1);
 }
 
-static      RTT
-ToRTT(int position)
+static void
+ToRTT(int position, RTT * rtt)
 {
-	RTT         rtt;
-
-	rtt.row = Sqrt(position);
+	rtt->row = Sqrt(position);
 	/* Passing row so there is no sqrt calculation again */
-	rtt.trbl = (position - rtt.row * rtt.row) / 2;
-	rtt.tlbr = (rtt.row * rtt.row + 2 * rtt.row - position) / 2;
-	return rtt;
+	rtt->trbl = (position - rtt->row * rtt->row) / 2;
+	rtt->tlbr = (rtt->row * rtt->row + 2 * rtt->row - position) / 2;
 }
 
 static int
@@ -728,8 +725,8 @@ POLYGON(OctWidget w, GC color, GC lineColor, const POINT * poly, int n,
 		Boolean origin)
 {
 	/* CoordModePrevious -> CoordModeOrigin */
-	POINT      *temp = NULL;
-	int         pt;
+	POINT *temp = NULL;
+	int pt;
 
 	if (!origin) {
 		if (!(temp = (POINT *) malloc(sizeof (POINT) * n))) {
@@ -765,10 +762,10 @@ static void
 DrawOrientLine(OctWidget w, int orient, int face, int side, int dx, int dy,
 		GC borderGC)
 {
-	int         x_1 = 0, x_2 = 0, y_1 = 0, y_2 = 0;
-	int         temp1 = w->oct.facetLength + 1;
-	int         temp2 = w->oct.facetLength / 2 + 1;
-	int         temp3 = w->oct.orientLineLength / 3;
+	int x_1 = 0, x_2 = 0, y_1 = 0, y_2 = 0;
+	int temp1 = w->oct.facetLength + 1;
+	int temp2 = w->oct.facetLength / 2 + 1;
+	int temp3 = w->oct.orientLineLength / 3;
 
 	/* clock positions */
 	switch ((side == face) ? orient : (orient + MAXORIENT / 2) % MAXORIENT) {
@@ -856,14 +853,14 @@ DrawOrientLine(OctWidget w, int orient, int face, int side, int dx, int dy,
 static void
 DrawTriangle(OctWidget w, int face, int position, int offset)
 {
-	GC          faceGC, borderGC;
-	int         dx = 0, dy = 0;
-	int         side, row = Sqrt(position);
-	int         base = row * row;
-	int         g = position - base;
-	int         s = g % 2;
-	int         pos = row * (w->oct.facetLength + w->oct.delta);
-	int         orient, view, faceOnView;
+	GC faceGC, borderGC;
+	int dx = 0, dy = 0;
+	int side, row = Sqrt(position);
+	int base = row * row;
+	int g = position - base;
+	int s = g % 2;
+	int pos = row * (w->oct.facetLength + w->oct.delta);
+	int orient, view, faceOnView;
 
 	view = (face / MAXSIDES == UP) ? DOWN : UP;
 	faceOnView = face - MAXSIDES * (!view);
@@ -948,8 +945,8 @@ DrawTriangle(OctWidget w, int face, int position, int offset)
 	}
 	POLYGON(w, faceGC, borderGC, triangleList[side], 3, False);
 	if (w->oct.mono) {
-		int         letterX, letterY;
-		char        buf[2];
+		int letterX, letterY;
+		char buf[2];
 
 		buf[0] =
 #ifdef WINVER
@@ -971,13 +968,13 @@ DrawTriangle(OctWidget w, int face, int position, int offset)
 	}
 	if (w->oct.orient)
 		DrawOrientLine(w, w->oct.facetLoc[face][position].rotation, faceOnView,
-			       side, dx, dy, borderGC);
+			side, dx, dy, borderGC);
 }
 
 void
 DrawAllPieces(OctWidget w)
 {
-	int         position, face;
+	int position, face;
 
 	for (face = 0; face < MAXFACES; face++)
 		for (position = 0; position < w->oct.sizeSize; position++)
@@ -995,7 +992,7 @@ EraseFrame(const OctWidget w)
 static void
 DrawFrame(OctWidget w, Boolean focus)
 {
-	int         startx, starty, lengthx, lengthy, longlength;
+	int startx, starty, lengthx, lengthy, longlength;
 
 	GC gc = (focus) ? w->oct.frameGC : w->oct.borderGC;
 	startx = 1 + w->oct.puzzleOffset.x;
@@ -1052,17 +1049,19 @@ MoveNoPieces(OctWidget w)
 static void
 RotateFace(OctWidget w, int view, int side, int direction)
 {
-	int         g, square, s;
-	int         i = 0, j = 0, k, i_1, j_1, k_1, position;
+	int g, square, s;
+	int i = 0, j = 0, k, i_1, j_1, k_1, position;
 
 	/* Read Face */
 	k = -1;
 	square = 0;
 	for (g = 0; g < w->oct.sizeSize; g++) {
-		/* This is the old algorithm, its now more efficient
-		   k = Sqrt(g);
-		   j = (g - k * k) / 2;
-		   i = ((k + 1) * (k + 1) - g - 1) / 2; */
+#if 0
+		/* This is the old algorithm, its now more efficient */
+		k = Sqrt(g);
+		j = (g - k * k) / 2;
+		i = ((k + 1) * (k + 1) - g - 1) / 2;
+#endif
 		if (square <= g) {
 			k++;
 			square = (k + 1) * (k + 1);
@@ -1105,8 +1104,8 @@ RotateFace(OctWidget w, int view, int side, int direction)
 static void
 ReadRTT(OctWidget w, int view, int side, int dir, int h, int len, int orient)
 {
-	int         f, g, s;
-	int         base = h * h;
+	int f, g, s;
+	int base = h * h;
 
 	if (!(dir % 2) || dir > COORD)
 		for (g = 0; g < len; g++)
@@ -1137,7 +1136,7 @@ ReadRTT(OctWidget w, int view, int side, int dir, int h, int len, int orient)
 static void
 RotateRTT(OctWidget w, int rotate, int len, int orient)
 {
-	int         g;
+	int g;
 
 	for (g = 0; g < len; g++)
 		w->oct.rowLoc[orient][g].rotation =
@@ -1147,8 +1146,8 @@ RotateRTT(OctWidget w, int rotate, int len, int orient)
 static void
 ReverseRTT(OctWidget w, int len, int orient)
 {
-	int         g;
-	OctLoc      temp;
+	int g;
+	OctLoc temp;
 
 	for (g = 0; g < (len - 1) / 2; g++) {
 		temp = w->oct.rowLoc[orient][len - 1 - g];
@@ -1160,8 +1159,8 @@ ReverseRTT(OctWidget w, int len, int orient)
 static void
 WriteRTT(OctWidget w, int view, int side, int dir, int h, int len, int orient)
 {
-	int         f, g, s;
-	int         base = h * h;
+	int f, g, s;
+	int base = h * h;
 
 	if (!(dir % 2) || dir > COORD) {	/* CW || CCW */
 		for (g = 0; g < len; g++) {
@@ -1197,8 +1196,8 @@ WriteRTT(OctWidget w, int view, int side, int dir, int h, int len, int orient)
 static void
 MovePieces(OctWidget w, int face, RTT rtt, int direction, int style)
 {
-	int         view, side, orient, newView, rotate, g, h, len;
-	int         newSide, oldSide, newDirection, bound, l = 0;
+	int view, side, orient, newView, rotate, g, h, len;
+	int newSide, oldSide, newDirection, bound, l = 0;
 
 	view = face / MAXSIDES;
 	side = face % MAXSIDES;
@@ -1210,17 +1209,21 @@ MovePieces(OctWidget w, int face, RTT rtt, int direction, int style)
 			rtt.row = rtt.trbl = rtt.tlbr = 0;
 		}
 		if ((!rtt.row && !(direction % 2)) ||
-		    (!rtt.trbl && (direction % 2) && !((side + direction / 2) % 2)) ||
-		    (!rtt.tlbr && (direction % 2) && ((side + direction / 2) % 2)))
+				(!rtt.trbl && (direction % 2) &&
+				!((side + direction / 2) % 2)) ||
+				(!rtt.tlbr && (direction % 2) &&
+				((side + direction / 2) % 2)))
 			RotateFace(w, view, rowToRotate[side][direction].face,
-				   rowToRotate[side][direction].rotation);
+				rowToRotate[side][direction].rotation);
 		if ((rtt.row == w->oct.size - 1 && !(direction % 2)) ||
-		    (rtt.trbl == w->oct.size - 1 && (direction % 2) &&
-		     !((side + direction / 2) % 2)) ||
-		    (rtt.tlbr == w->oct.size - 1 && (direction % 2) &&
-		     (side + direction / 2) % 2))
+				(rtt.trbl == w->oct.size - 1 &&
+				(direction % 2) &&
+				!((side + direction / 2) % 2)) ||
+				(rtt.tlbr == w->oct.size - 1 &&
+				(direction % 2) &&
+				(side + direction / 2) % 2))
 			RotateFace(w, !view, rowToRotate[MAXSIDES + side][direction].face,
-			   rowToRotate[MAXSIDES + side][direction].rotation);
+				rowToRotate[MAXSIDES + side][direction].rotation);
 		if (!(direction % 2))
 			h = rtt.row;
 		else if ((direction / 2 + side) % 2)
@@ -1277,8 +1280,8 @@ MovePieces(OctWidget w, int face, RTT rtt, int direction, int style)
 			h = rtt.trbl;
 
 		if (w->oct.sticky &&
-		    !((direction > TL && h == w->oct.size - 1) ||
-		      (direction <= TL && !h))) {
+				!((direction > TL && h == w->oct.size - 1) ||
+				(direction <= TL && !h))) {
 			l = 0;
 			h = (direction <= TL);
 			bound = TRUE;
@@ -1304,10 +1307,10 @@ MovePieces(OctWidget w, int face, RTT rtt, int direction, int style)
 							((direction + 6) % MAXFACES) : ((direction + 2) % MAXFACES);
 						if (side % 2)
 							rotate = (((newDirection - direction) / 2 + MAXSIDES) %
-								  MAXSIDES == 1) ? 4 : MAXORIENT - 4;
+								MAXSIDES == 1) ? 4 : MAXORIENT - 4;
 						else
 							rotate = (((newDirection - direction) / 2 + MAXSIDES) %
-								  MAXSIDES == 1) ? 2 : MAXORIENT - 2;
+								MAXSIDES == 1) ? 2 : MAXORIENT - 2;
 					} else {	/* Next is on same view */
 						newView = view;
 						newSide = MAXSIDES - side - 1;
@@ -1335,22 +1338,22 @@ MovePieces(OctWidget w, int face, RTT rtt, int direction, int style)
 			}
 			l++;
 			if (w->oct.sticky &&
-			    !((direction > TL && h == w->oct.size - 1) ||
-			      (direction <= TL && !h)))
+					!((direction > TL && h == w->oct.size - 1) ||
+					(direction <= TL && !h)))
 				h++;
 			else
 				g++;
 		} while ((bound && l < w->oct.size - 1) ||
-			 (((direction > TL && h == w->oct.size - 1) ||
-			   (direction <= TL && !h)) && g < 2 && !bound));
+				(((direction > TL && h == w->oct.size - 1) ||
+				(direction <= TL && !h)) && g < 2 && !bound));
 	}
 }
 
 static void
 MoveControlCb(OctWidget w, int face, int direction, int style)
 {
-	int         i, j;
-	RTT         rtt;
+	int i, j;
+	RTT rtt;
 
 	if (w->oct.sticky) {
 		if (style == PERIOD3)
@@ -1381,7 +1384,7 @@ MoveControlCb(OctWidget w, int face, int direction, int style)
 						rtt.tlbr = j;
 						MovePieces(w,
 								(!(face / MAXSIDES)) * MAXSIDES + ((face % 2) ?
-												   (face + MAXSIDES / 2) % MAXSIDES : face % MAXSIDES), rtt,
+												(face + MAXSIDES / 2) % MAXSIDES : face % MAXSIDES), rtt,
 								(direction == CW) ? CCW : CW, style);
 					} else {
 						j = i + 1;
@@ -1390,7 +1393,7 @@ MoveControlCb(OctWidget w, int face, int direction, int style)
 						rtt.tlbr = j;
 						MovePieces(w,
 								(!(face / MAXSIDES)) * MAXSIDES + ((face % 2) ?
-												   (face + MAXSIDES / 2) % MAXSIDES : face % MAXSIDES), rtt,
+												(face + MAXSIDES / 2) % MAXSIDES : face % MAXSIDES), rtt,
 								((direction / 2) % 2) ? (direction + 2) % MAXFACES :
 								(direction + 6) % MAXFACES, style);
 					}
@@ -1420,7 +1423,7 @@ MoveControlCb(OctWidget w, int face, int direction, int style)
 						rtt.tlbr = j;
 						MovePieces(w,
 								(!(face / MAXSIDES)) * MAXSIDES + ((face % 2) ?
-												   (face + MAXSIDES / 2) % MAXSIDES : face % MAXSIDES), rtt,
+												(face + MAXSIDES / 2) % MAXSIDES : face % MAXSIDES), rtt,
 								(direction == CW) ? CCW : CW, style);
 					} else {
 						j = i - w->oct.size + 1;
@@ -1429,7 +1432,7 @@ MoveControlCb(OctWidget w, int face, int direction, int style)
 						rtt.tlbr = j;
 						MovePieces(w,
 								(!(face / MAXSIDES)) * MAXSIDES + ((face % 2) ?
-												   (face + MAXSIDES / 2) % MAXSIDES : face % MAXSIDES), rtt,
+												(face + MAXSIDES / 2) % MAXSIDES : face % MAXSIDES), rtt,
 								((direction / 2) % 2) ? (direction + 2) % MAXFACES :
 								(direction + 6) % MAXFACES, style);
 					}
@@ -1445,16 +1448,19 @@ MoveOct(OctWidget w, int face, int position, int direction, int style, int contr
 	if (control)
 		MoveControlCb(w, face, direction, style);
 	else {
-		MovePieces(w, face, ToRTT(position), direction, style);
+		RTT rtt;
+
+		ToRTT(position, &rtt);
+		MovePieces(w, face, rtt, direction, style);
 		SetOct(w, OCT_MOVED);
 	}
 	PutMove(face, position, direction, style, control);
 }
 
-static      Boolean
+static Boolean
 SelectPieces(OctWidget w, int x, int y, int *face, RTT * rtt)
 {
-	int         view;
+	int view;
 
 	x -= w->oct.puzzleOffset.x;
 	y -= w->oct.puzzleOffset.y;
@@ -1467,8 +1473,8 @@ SelectPieces(OctWidget w, int x, int y, int *face, RTT * rtt)
 	} else
 		view = UP;
 	if (x <= 0 || y <= 0 ||
-	    x >= w->oct.faceLength + w->oct.delta ||
-	    y >= w->oct.faceLength + w->oct.delta)
+			x >= w->oct.faceLength + w->oct.delta ||
+			y >= w->oct.faceLength + w->oct.delta)
 		return False;
 	else if (x + y > w->oct.faceLength) {
 		if (x > y)
@@ -1487,26 +1493,26 @@ SelectPieces(OctWidget w, int x, int y, int *face, RTT * rtt)
 	}
 	rtt->row = 0;
 	while ((x <= (w->oct.size - (rtt->row + 1)) *
-		(w->oct.facetLength + w->oct.delta) ||
-		x >= w->oct.viewMiddle + (rtt->row + 1) *
-		(w->oct.facetLength + w->oct.delta) + 1 ||
-		y <= (w->oct.size - (rtt->row + 1)) *
-		(w->oct.facetLength + w->oct.delta) ||
-		y >= w->oct.viewMiddle + (rtt->row + 1) *
-		(w->oct.facetLength + w->oct.delta) + 1) &&
-	       rtt->row < w->oct.size)
+			(w->oct.facetLength + w->oct.delta) ||
+			x >= w->oct.viewMiddle + (rtt->row + 1) *
+			(w->oct.facetLength + w->oct.delta) + 1 ||
+			y <= (w->oct.size - (rtt->row + 1)) *
+			(w->oct.facetLength + w->oct.delta) ||
+			y >= w->oct.viewMiddle + (rtt->row + 1) *
+			(w->oct.facetLength + w->oct.delta) + 1) &&
+			rtt->row < w->oct.size)
 		rtt->row++;
 	rtt->trbl = 0;
 	while ((x + y) / 2 <= (w->oct.size - (rtt->trbl + 1)) *
-	       (w->oct.facetLength + w->oct.delta) + 2 * w->oct.delta ||
-	       (x + y) / 2 >= w->oct.viewMiddle + (rtt->trbl + 1) *
-	       (w->oct.facetLength + w->oct.delta))
+			(w->oct.facetLength + w->oct.delta) + 2 * w->oct.delta ||
+			(x + y) / 2 >= w->oct.viewMiddle + (rtt->trbl + 1) *
+			(w->oct.facetLength + w->oct.delta))
 		rtt->trbl++;
 	rtt->tlbr = 0;
 	while (x <= y - 2 * (rtt->tlbr + 1) *
-	       (w->oct.facetLength + w->oct.delta) - 2 ||
-	       y <= x - 2 * (rtt->tlbr + 1) *
-	       (w->oct.facetLength + w->oct.delta) - 2)
+			(w->oct.facetLength + w->oct.delta) - 2 ||
+			y <= x - 2 * (rtt->tlbr + 1) *
+			(w->oct.facetLength + w->oct.delta) - 2)
 		rtt->tlbr++;
 	if (!w->oct.vertical && view == DOWN)
 		*face = (*face + MAXSIDES / 2) % MAXSIDES;
@@ -1522,8 +1528,8 @@ SelectPieces(OctWidget w, int x, int y, int *face, RTT * rtt)
 static int
 CheckMoveDir(OctWidget w, RTT rtt1, RTT rtt2, int face, int *direction)
 {
-	int         which = -1, count = 0;
-	int         i, *p1, *p2;
+	int which = -1, count = 0;
+	int i, *p1, *p2;
 
 	p1 = &(rtt1.row);
 	p2 = &(rtt2.row);
@@ -1558,10 +1564,10 @@ CheckMoveDir(OctWidget w, RTT rtt1, RTT rtt2, int face, int *direction)
 	return count;
 }
 
-static      Boolean
+static Boolean
 NarrowSelection(int style, int *face, int *direction)
 {
-	int         side;
+	int side;
 
 	side = *face % MAXSIDES;
 	if (!(*direction % 2) && !((*direction / 2 + side) % 2))
@@ -1573,14 +1579,19 @@ NarrowSelection(int style, int *face, int *direction)
 			else	/* *direction == (2 * side + 6) % MAXFACES */
 				*direction = CCW;
 		}
-/* if (*direction > TL) h = rtt->row; else if (!((*direction / 2) % 2)) h =
-		   rtt->trbl; else *//* (*direction / 2) % 2 == 1 *//*
-		   h = rtt->tlbr; */
+#if 0
+	if (*direction > TL)
+		h = rtt->row;
+	else if (!((*direction / 2) % 2)) h =
+		rtt->trbl;
+	else /* (*direction / 2) % 2 == 1*/
+		h = rtt->tlbr;
+#endif
 	}
 	return True;
 }
 
-static      Boolean
+static Boolean
 PositionPieces(OctWidget w, int x, int y, int style, int *face, RTT * rtt, int *direction)
 {
 	if (!SelectPieces(w, x, y, face, rtt))
@@ -1597,8 +1608,8 @@ static
 void
 MoveOctInput(OctWidget w, int x, int y, int direction, int shift, int control)
 {
-	int         style, face;
-	RTT         rtt;
+	int style, face;
+	RTT rtt;
 
 	if (w->oct.mode != BOTH) {
 		if (control && shift)
@@ -1623,20 +1634,20 @@ MoveOctInput(OctWidget w, int x, int y, int direction, int shift, int control)
 static void
 ResetPieces(OctWidget w)
 {
-	int         face, position, orient;
+	int face, position, orient;
 
 	w->oct.sizeSize = w->oct.size * w->oct.size;
 	for (face = 0; face < MAXFACES; face++) {
 		if (w->oct.facetLoc[face])
 			(void) free((void *) w->oct.facetLoc[face]);
 		if (!(w->oct.facetLoc[face] = (OctLoc *)
-		      malloc(sizeof (OctLoc) * w->oct.sizeSize))) {
+				malloc(sizeof (OctLoc) * w->oct.sizeSize))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 		if (startLoc[face])
 			(void) free((void *) startLoc[face]);
 		if (!(startLoc[face] = (OctLoc *)
-		      malloc(sizeof (OctLoc) * w->oct.sizeSize))) {
+				malloc(sizeof (OctLoc) * w->oct.sizeSize))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
@@ -1644,14 +1655,14 @@ ResetPieces(OctWidget w)
 		if (w->oct.rowLoc[orient])
 			(void) free((void *) w->oct.rowLoc[orient]);
 		if (!(w->oct.rowLoc[orient] = (OctLoc *)
-		      malloc(sizeof (OctLoc) * (2 * w->oct.size - 1)))) {
+				malloc(sizeof (OctLoc) * (2 * w->oct.size - 1)))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
 	if (w->oct.faceLoc)
 		(void) free((void *) w->oct.faceLoc);
 	if (!(w->oct.faceLoc = (OctLoc *)
-	      malloc(sizeof (OctLoc) * w->oct.sizeSize))) {
+			malloc(sizeof (OctLoc) * w->oct.sizeSize))) {
 		DISPLAY_ERROR("Not enough memory, exiting.");
 	}
 	for (face = 0; face < MAXFACES; face++)
@@ -1667,7 +1678,7 @@ ResetPieces(OctWidget w)
 static void
 ResizePieces(OctWidget w)
 {
-	int         i, j;
+	int i, j;
 
 	w->oct.facetLength = w->oct.faceLength / (2 * w->oct.size) -
 		w->oct.delta - 1;
@@ -1696,8 +1707,8 @@ ResizePieces(OctWidget w)
 static void
 GetPieces(OctWidget w)
 {
-	FILE       *fp;
-	int         c, i, size, mode, sticky, orient, practice, moves;
+	FILE *fp;
+	int c, i, size, mode, sticky, orient, practice, moves;
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname, *name;
 
@@ -1812,7 +1823,7 @@ GetPieces(OctWidget w)
 	ScanMoves(fp, w, moves);
 	(void) fclose(fp);
 	(void) printf("%s: size %d, mode %d, sticky %d, orient %d",
-		      name, size, mode, sticky, orient);
+		name, size, mode, sticky, orient);
 	(void) printf(", practice %d, moves %d.\n", practice, moves);
 	free(lname);
 	free(fname);
@@ -1822,7 +1833,7 @@ GetPieces(OctWidget w)
 static void
 WritePieces(OctWidget w)
 {
-	FILE       *fp;
+	FILE *fp;
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname, *name;
 
@@ -1890,7 +1901,7 @@ static void
 UndoPieces(OctWidget w)
 {
 	if (MadeMoves() && w->oct.currentFace < 0) {
-		int         face, position, direction, style, control;
+		int face, position, direction, style, control;
 
 		GetMove(&face, &position, &direction, &style, &control);
 		direction = (direction < COORD) ?
@@ -1898,7 +1909,10 @@ UndoPieces(OctWidget w)
 		if (control)
 			MoveControlCb(w, face, direction, style);
 		else {
-			MovePieces(w, face, ToRTT(position), direction, style);
+			RTT rtt;
+
+			ToRTT(position, &rtt);
+			MovePieces(w, face, rtt, direction, style);
 			SetOct(w, OCT_UNDO);
 		}
 	}
@@ -1913,8 +1927,8 @@ PracticePieces(OctWidget w)
 static void
 RandomizePieces(OctWidget w)
 {
-	int         randomDirection, face, position, style;
-	int         big = w->oct.sizeSize * 3 + NRAND(2);
+	int randomDirection, face, position, style;
+	int big = w->oct.sizeSize * 3 + NRAND(2);
 
 	if (w->oct.currentFace >= 0)
 		return;
@@ -2042,10 +2056,10 @@ static void
 SetValuesOct(OctWidget w)
 {
 	struct tagColor {
-		int         red, green, blue;
+		int red, green, blue;
 	} color;
-	char        szBuf[80], buf[20], charbuf[2];
-	int         face;
+	char szBuf[80], buf[20], charbuf[2];
+	int face;
 
 	w->oct.size = GetPrivateProfileInt(SECTION, "size",
 		DEFAULTFACETS, INIFILE);
@@ -2113,9 +2127,9 @@ DestroyOct(HBRUSH brush)
 static void
 GetColor(OctWidget w, int face)
 {
-	XGCValues   values;
-	XtGCMask    valueMask;
-	XColor      colorCell, rgb;
+	XGCValues values;
+	XtGCMask valueMask;
+	XColor colorCell, rgb;
 
 	valueMask = GCForeground | GCBackground;
 	if (w->oct.reverse) {
@@ -2125,8 +2139,8 @@ GetColor(OctWidget w, int face)
 	}
 	if (!w->oct.mono) {
 		if (XAllocNamedColor(XtDisplay(w),
-				  DefaultColormapOfScreen(XtScreen(w)),
-				  w->oct.faceName[face], &colorCell, &rgb)) {
+				DefaultColormapOfScreen(XtScreen(w)),
+				w->oct.faceName[face], &colorCell, &rgb)) {
 			values.foreground = w->oct.faceColor[face] = colorCell.pixel;
 			if (w->oct.faceGC[face])
 				XtReleaseGC((Widget) w, w->oct.faceGC[face]);
@@ -2160,9 +2174,9 @@ GetColor(OctWidget w, int face)
 static void
 SetAllColors(OctWidget w)
 {
-	XGCValues   values;
-	XtGCMask    valueMask;
-	int         face;
+	XGCValues values;
+	XtGCMask valueMask;
+	int face;
 
 	valueMask = GCForeground | GCBackground;
 
@@ -2213,12 +2227,12 @@ SetAllColors(OctWidget w)
 			w->oct.fontInfo->fid);
 }
 
-static      Boolean
+static Boolean
 SetValuesOct(Widget current, Widget request, Widget renew)
 {
-	OctWidget   c = (OctWidget) current, w = (OctWidget) renew;
-	Boolean     redraw = False, setColors = False;
-	int         face;
+	OctWidget c = (OctWidget) current, w = (OctWidget) renew;
+	Boolean redraw = False, setColors = False;
+	int face;
 
 	CheckPieces(w);
 	for (face = 0; face < MAXFACES; face++) {
@@ -2235,8 +2249,8 @@ SetValuesOct(Widget current, Widget request, Widget renew)
 		SetAllColors(w);
 		redraw = True;
 	} else if (w->oct.background != c->oct.background ||
-	    w->oct.foreground != c->oct.foreground ||
-	    setColors) {
+			w->oct.foreground != c->oct.foreground ||
+			setColors) {
 		SetAllColors(w);
 		redraw = True;
 	}
@@ -2248,8 +2262,8 @@ SetValuesOct(Widget current, Widget request, Widget renew)
 		redraw = True;
 	}
 	if (w->oct.size != c->oct.size ||
-	    w->oct.mode != c->oct.mode ||
-	    w->oct.sticky != c->oct.sticky) {
+			w->oct.mode != c->oct.mode ||
+			w->oct.sticky != c->oct.sticky) {
 		SizeOct(w);
 		redraw = True;
 	}
@@ -2327,8 +2341,8 @@ QuitOct(OctWidget w, XEvent * event, char **args, int nArgs)
 static void
 DestroyOct(Widget old)
 {
-	OctWidget   w = (OctWidget) old;
-	int         face;
+	OctWidget w = (OctWidget) old;
+	int face;
 
 	for (face = 0; face < MAXFACES; face++)
 		XtReleaseGC(old, w->oct.faceGC[face]);
@@ -2345,9 +2359,9 @@ static
 void
 ResizeOct(OctWidget w)
 {
-	int         tempLength;
+	int tempLength;
 #ifdef WINVER
-	RECT        rect;
+	RECT rect;
 
 	/* Determine size of client area */
 	(void) GetClientRect(w->core.hWnd, &rect);
@@ -2399,11 +2413,11 @@ Widget request, Widget renew
 #endif
 )
 {
-	int         face, orient;
+	int face, orient;
 #ifdef WINVER
-        SetValuesOct(w);
+	SetValuesOct(w);
 #else
-	OctWidget   w = (OctWidget) renew;
+	OctWidget w = (OctWidget) renew;
 
 	w->oct.mono = (DefaultDepthOfScreen(XtScreen(w)) < 2 ||
 		w->oct.mono);
@@ -2448,7 +2462,7 @@ Widget renew, XEvent * event, Region region
 )
 {
 #ifndef WINVER
-	OctWidget   w = (OctWidget) renew;
+	OctWidget w = (OctWidget) renew;
 
 	if (!w->core.visible)
 		return;
@@ -2483,9 +2497,9 @@ SelectOct(OctWidget w
 #endif
 )
 {
-	RTT         rtt;
+	RTT rtt;
 #ifndef WINVER
-	int  x = event->xbutton.x, y = event->xbutton.y;
+	int x = event->xbutton.x, y = event->xbutton.y;
 	int control = (int) (event->xkey.state & ControlMask);
 #endif
 
@@ -2510,10 +2524,10 @@ ReleaseOct(OctWidget w
 #endif
 )
 {
-	int         style, face, count = -1, direction = 0;
-	RTT         rtt;
+	int style, face, count = -1, direction = 0;
+	RTT rtt;
 #ifndef WINVER
-	int  x = event->xbutton.x, y = event->xbutton.y;
+	int x = event->xbutton.x, y = event->xbutton.y;
 	int shift = (int) (event->xbutton.state & (ShiftMask | LockMask));
 	int control = (int) (event->xkey.state & ControlMask);
 #endif
@@ -2531,9 +2545,12 @@ ReleaseOct(OctWidget w
 				style = (w->oct.mode == PERIOD3) ? PERIOD3 : PERIOD4;
 		} else
 			style = (shift) ? PERIOD4 : PERIOD3;
-		if (face == w->oct.currentFace)
-			count = CheckMoveDir(w, ToRTT(w->oct.currentPosition), rtt, face,
-					     &direction);
+		if (face == w->oct.currentFace) {
+			RTT rtt1;
+
+			ToRTT(w->oct.currentPosition, &rtt1);
+			count = CheckMoveDir(w, rtt1, rtt, face, &direction);
+		}
 		if (count == 1 && NarrowSelection(style, &face, &direction)) {
 			MoveOct(w, face, w->oct.currentPosition,
 				direction, style, (control) ? 1 : 0);
@@ -2818,79 +2835,79 @@ static void
 MoveOctCcw(OctWidget w, XEvent * event, char **args, int nArgs)
 {
 	MoveOctInput(w, event->xbutton.x, event->xbutton.y, CCW,
-		     (int) (event->xbutton.state & (ShiftMask | LockMask)),
-		     (int) (event->xbutton.state & ControlMask));
+		(int) (event->xbutton.state & (ShiftMask | LockMask)),
+		(int) (event->xbutton.state & ControlMask));
 }
 
 static void
 MoveOctTl(OctWidget w, XEvent * event, char **args, int nArgs)
 {
 	MoveOctInput(w, event->xbutton.x, event->xbutton.y, TL,
-		     (int) (event->xbutton.state & (ShiftMask | LockMask)),
-		     (int) (event->xkey.state & ControlMask));
+		(int) (event->xbutton.state & (ShiftMask | LockMask)),
+		(int) (event->xkey.state & ControlMask));
 }
 
 static void
 MoveOctTop(OctWidget w, XEvent * event, char **args, int nArgs)
 {
 	MoveOctInput(w, event->xbutton.x, event->xbutton.y, TOP,
-		     (int) (event->xbutton.state & (ShiftMask | LockMask)),
-		     (int) (event->xkey.state & ControlMask));
+		(int) (event->xbutton.state & (ShiftMask | LockMask)),
+		(int) (event->xkey.state & ControlMask));
 }
 
 static void
 MoveOctTr(OctWidget w, XEvent * event, char **args, int nArgs)
 {
 	MoveOctInput(w, event->xbutton.x, event->xbutton.y, TR,
-		     (int) (event->xbutton.state & (ShiftMask | LockMask)),
-		     (int) (event->xkey.state & ControlMask));
+		(int) (event->xbutton.state & (ShiftMask | LockMask)),
+		(int) (event->xkey.state & ControlMask));
 }
 
 static void
 MoveOctLeft(OctWidget w, XEvent * event, char **args, int nArgs)
 {
 	MoveOctInput(w, event->xbutton.x, event->xbutton.y, LEFT,
-		     (int) (event->xbutton.state & (ShiftMask | LockMask)),
-		     (int) (event->xkey.state & ControlMask));
+		(int) (event->xbutton.state & (ShiftMask | LockMask)),
+		(int) (event->xkey.state & ControlMask));
 }
 
 static void
 MoveOctCw(OctWidget w, XEvent * event, char **args, int nArgs)
 {
 	MoveOctInput(w, event->xbutton.x, event->xbutton.y, CW,
-		     (int) (event->xbutton.state & (ShiftMask | LockMask)),
-		     (int) (event->xkey.state & ControlMask));
+		(int) (event->xbutton.state & (ShiftMask | LockMask)),
+		(int) (event->xkey.state & ControlMask));
 }
 
 static void
 MoveOctRight(OctWidget w, XEvent * event, char **args, int nArgs)
 {
 	MoveOctInput(w, event->xbutton.x, event->xbutton.y, RIGHT,
-		     (int) (event->xbutton.state & (ShiftMask | LockMask)),
-		     (int) (event->xkey.state & ControlMask));
+		(int) (event->xbutton.state & (ShiftMask | LockMask)),
+		(int) (event->xkey.state & ControlMask));
 }
 
 static void
 MoveOctBl(OctWidget w, XEvent * event, char **args, int nArgs)
 {
 	MoveOctInput(w, event->xbutton.x, event->xbutton.y, BL,
-		     (int) (event->xbutton.state & (ShiftMask | LockMask)),
-		     (int) (event->xkey.state & ControlMask));
+		(int) (event->xbutton.state & (ShiftMask | LockMask)),
+		(int) (event->xkey.state & ControlMask));
 }
 
 static void
 MoveOctBottom(OctWidget w, XEvent * event, char **args, int nArgs)
 {
 	MoveOctInput(w, event->xbutton.x, event->xbutton.y, BOTTOM,
-		     (int) (event->xbutton.state & (ShiftMask | LockMask)),
-		     (int) (event->xkey.state & ControlMask));
+		(int) (event->xbutton.state & (ShiftMask | LockMask)),
+		(int) (event->xkey.state & ControlMask));
 }
 
 static void
 MoveOctBr(OctWidget w, XEvent * event, char **args, int nArgs)
 {
 	MoveOctInput(w, event->xbutton.x, event->xbutton.y, BR,
-		     (int) (event->xbutton.state & (ShiftMask | LockMask)),
-		     (int) (event->xkey.state & ControlMask));
+		(int) (event->xbutton.state & (ShiftMask | LockMask)),
+		(int) (event->xkey.state & ControlMask));
 }
 #endif
