@@ -16,7 +16,7 @@
 #  Dubrovsky.
 #  Break ability taken from the X puzzle by Don Bennett, HP Labs
 #
-#  Copyright (c) 1996 - 2003	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1996 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -129,7 +129,7 @@ MoveATile(PanexWidget w, int fromStack, int toStack)
 	if (SolvingFlag && AbortSolvingFlag)
 		longjmp(solve_env, 1);
 #endif
-	if ((fromPosition = TopOfStack(w, fromStack)) < 0 ||
+	if ((fromPosition = TopOfStack(w, fromStack, 0)) < 0 ||
 	    MovePanex(w, fromStack, fromPosition, toStack) < 0) {
 		(void) printf("move from %d to %d can not be made.",
 			      fromStack, toStack);
@@ -168,8 +168,8 @@ SolveHanoiMode(PanexWidget w)
 			} else {
 				temp1Stack = (triangleStack + 1) % MAXSTACKS;
 				temp2Stack = (triangleStack + 2) % MAXSTACKS;
-				temp1Loc = TopOfStack(w, temp1Stack);
-				temp2Loc = TopOfStack(w, temp2Stack);
+				temp1Loc = TopOfStack(w, temp1Stack, 0);
+				temp2Loc = TopOfStack(w, temp2Stack, 0);
 				if (temp1Loc < 0 && temp2Loc < 0)
 					return;
 				else if (temp1Loc < 0) {
