@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1996 - 2003	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1996 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -33,6 +33,9 @@
 #define IDM_UNDO	201
 #define IDM_SOLVE	202
 #define IDM_MODE	203
+#define IDM_SPEED       204
+#define IDM_SLOW        205
+#define IDM_SOUND       206
 #define IDM_DEC		400
 #define IDM_INC		401
 #define IDM_ABOUT	500
