@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1996 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1996 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -95,7 +95,7 @@ static HWND Wnd;
 
 #ifdef HAVE_MOTIF
 static const char aboutHelp[] = {
-	"Version 7.1.1\n"
+	"Version 7.1.3\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
@@ -131,8 +131,10 @@ static const char featuresHelp[] = {
 	"of a column.  Release \"mouse-left\" button on\n"
 	"another column to move the tile to that column.  It will "
 	"not move if blocked.\n"
+	"\n"
 	"Click \"mouse-right\" button, or press \"C\", \"c\", \"R\","
 	"or \"r\" keys, to clear/reset the puzzle.\n"
+	"\n"
 	"Press \"M\" or \"m\" keys to toggle between hanoi "
 	"(one pyramid column) and panex (two pyramid columns) modes\n"
 	"(they each have different rules).\n"
@@ -141,15 +143,30 @@ static const char featuresHelp[] = {
 	"the left peg to the rightmost peg.\n"
 	"In Panex, a tile can not go lower that its initial starting "
 	"point.  Here the goal is to exchange the 2 piles.\n"
+	"\n"
 	"Press \"I\" or \"i\" keys to increase the number of tiles.\n"
+	"\n"
 	"Press \"D\" or \"d\" keys to decrease the number of tiles.\n"
+	"\n"
 	"Press \"S\" or \"s\" keys to auto-solve.  Unfortunately, its "
 	"only implemented from the starting position.\n"
+	"\n"
 	"Press \"U\" or \"u\" keys to undo a move.\n"
+	"\n"
 	"Press \"G\" or \"g\" keys to get a saved puzzle.\n"
+	"\n"
 	"Press \"W\" or \"w\" keys to save a puzzle.\n"
+	"\n"
+	"Press \">\" or \".\" keys to speed up the movement of tiles.\n"
+	"\n"
+	"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
+	"\n"
+	"Press \"@\" key to toggle the sound.\n"
+	"\n"
 	"Press \"Esc\" key to hide program.\n"
+	"\n"
 	"Press \"Q\", \"q\", or \"CTRL-C\" keys to kill program.\n"
+	"\n"
 	"Unlike other puzzles in the collection there is no way to "
 	"move pieces without drag and drop.\n"
 };
@@ -196,7 +213,6 @@ static char recordDsp[MESSAGELEN] = "NOT RECORDED";
 #ifdef HAVE_MOTIF
 #define MINSPEED 1
 #define MAXSPEED 50
-#define MULTSPEED 20
 static Widget moves, record, message, modes[MAXMODES], tile, speed;
 static char buff[21];
 static const char *modeString[] =
@@ -460,19 +476,21 @@ Initialize(
 	mode = w->panex.mode;
 	username = w->panex.username;
 #else
-	int delay;
-
 	XtVaGetValues(w,
 		XtNuserName, &username,
 		XtNtiles, &tiles,
-		XtNmode, &mode,
-		XtNdelay, &delay, NULL);
+		XtNmode, &mode, NULL);
 #ifdef HAVE_MOTIF
-	if (tiles > MAXTILES)
-		XtVaSetValues(tile, XmNmaximum, tiles, NULL);
-	XmScaleSetValue(tile, tiles);
-	XmToggleButtonSetState(modes[mode - HANOI], True, False);
-	XmScaleSetValue(speed, MAXSPEED + MINSPEED - delay / MULTSPEED - 1);
+	{
+		int delay;
+
+		if (tiles > MAXTILES)
+			XtVaSetValues(tile, XmNmaximum, tiles, NULL);
+		XmScaleSetValue(tile, tiles);
+		XmToggleButtonSetState(modes[mode - HANOI], True, False);
+		XtVaGetValues(panex, XtNdelay, &delay, NULL);
+		XmScaleSetValue(speed, MAXSPEED + MINSPEED - delay - 1);
+	}
 #endif
 #endif
 	/* SET_STARTED(w, False); */
@@ -643,6 +661,26 @@ CallbackPanex(Widget w, caddr_t clientData, panexCallbackStruct * callData)
 			movesDsp--;
 			SET_STARTED(w, True);
 			break;
+#ifdef HAVE_MOTIF
+		case PANEX_SPEED:
+			{
+				int oldDelay, delay;
+
+				XtVaGetValues(panex, XtNdelay, &delay, NULL);
+				oldDelay = delay;
+				if (delay > MAXSPEED - MINSPEED)
+					delay = MAXSPEED - MINSPEED;
+				if (delay < 0)
+					delay = 0;
+				if (delay != oldDelay) {
+					XtSetArg(arg[0], XtNdelay, delay);
+					XtSetValues(w, arg, 1);
+				}
+				XmScaleSetValue(speed,
+					MAXSPEED + MINSPEED - delay - 1);
+			}
+			return;
+#endif
 	}
 #ifdef HAVE_MOTIF
 	PrintState(message, messageDsp);
@@ -678,6 +716,7 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 {
 	HBRUSH brush = (HBRUSH) NULL;
 	PAINTSTRUCT paint;
+	static Boolean mousePress = False;
 
 	Wnd = widget.core.hWnd = hWnd;
 	if (GetFocus()) {
@@ -719,13 +758,24 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case WM_LBUTTONDOWN:
+			mousePress = True;
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
 			SelectPanex(&widget, LOWORD(lParam));
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
+		case WM_MOUSEMOVE:
+			if (!mousePress)
+				break;
+			widget.core.hDC = GetDC(hWnd);
+			(void) SelectObject(widget.core.hDC,
+				GetStockObject(NULL_PEN));
+			MotionPanex(&widget, LOWORD(lParam));
+			(void) ReleaseDC(hWnd, widget.core.hDC);
+			break;
 		case WM_LBUTTONUP:
+			mousePress = False;
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC,
 				GetStockObject(NULL_PEN));
@@ -778,6 +828,15 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 					SizePanex(&widget);
 					(void) InvalidateRect(hWnd, NULL, TRUE);
 					break;
+				case IDM_SPEED:
+					SpeedPanex(&widget);
+					break;
+				case IDM_SLOW:
+					SlowPanex(&widget);
+					break;
+				case IDM_SOUND:
+					SoundPanex(&widget);
+					break;
 				case IDM_ABOUT:
 					(void) DialogBox(widget.core.hInstance,
 						"About", hWnd, (DLGPROC) About);
@@ -803,10 +862,8 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 }
 
 int WINAPI
-WinMain(HINSTANCE hInstance,
-	HINSTANCE hPrevInstance,
-	LPSTR lpCmdLine,
-	int numCmdShow)
+WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine,
+		int numCmdShow)
 {
 	HWND hWnd;
 	MSG msg;
@@ -869,7 +926,9 @@ Usage(char * programName)
 	(void) fprintf(stderr,
 		"\t[-tiles {int}] [-{mode {int}|hanoi|panex}] [-delay msecs]\n");
 	(void) fprintf(stderr,
-		"\t[-{font|fn} {fontname}] [-username {string}]\n");
+		"\t[-movesound {filename}] [-{font|fn} {fontname}]\n");
+	(void) fprintf(stderr, 
+		"\t[-username {string}]\n");
 	exit(1);
 }
 
@@ -895,6 +954,9 @@ static XrmOptionDescRec options[] =
 	{(char *) "-hanoi", (char *) "*panex.mode", XrmoptionNoArg, (char *) "0"},
 	{(char *) "-panex", (char *) "*panex.mode", XrmoptionNoArg, (char *) "1"},
 	{(char *) "-delay", (char *) "*panex.delay", XrmoptionSepArg, NULL},
+	{(char *) "-sound", (char *) "*panex.sound", XrmoptionNoArg, (char *) "TRUE"},
+	{(char *) "-nosound", (char *) "*panex.sound", XrmoptionNoArg, (char *) "FALSE"},
+	{(char *) "-movesound", (char *) "*panex.moveSound", XrmoptionSepArg, NULL},
 	{(char *) "-fn", (char *) "*panex.font", XrmoptionSepArg, NULL},
 	{(char *) "-font", (char *) "*panex.font", XrmoptionSepArg, NULL},
 	{(char *) "-username", (char *) "*userName", XrmoptionSepArg, NULL}
@@ -953,8 +1015,7 @@ ModeToggle(Widget w, int mode, XmToggleButtonCallbackStruct * cbs)
 static void
 SpeedSlider(Widget w, XtPointer clientData, XmScaleCallbackStruct * cbs)
 {
-	int delay = MULTSPEED * (MAXSPEED + MINSPEED - cbs->value - 1);
-	int oldDelay;
+	int delay = MAXSPEED + MINSPEED - cbs->value - 1, oldDelay;
 
 	XtVaGetValues(panex,
 		XtNdelay, &oldDelay, NULL);
@@ -1079,6 +1140,7 @@ main(int argc, char **argv)
 	XmString getString, writeString, quitString;
 	XmString clearString, undoString, solveString;
 	XmString incrementString, decrementString, mode;
+	XmString speedString, slowString, soundString;
 	unsigned int i;
 #endif
 
@@ -1149,6 +1211,9 @@ main(int argc, char **argv)
 	incrementString = XmStringCreateSimple((char *) "Increment");
 	decrementString = XmStringCreateSimple((char *) "Decrement");
 	mode = XmStringCreateSimple((char *) "Mode");
+	speedString = XmStringCreateSimple((char *) ">Speed");
+	slowString = XmStringCreateSimple((char *) "<Slow");
+	soundString = XmStringCreateSimple((char *) "@Sound");
 	XmVaCreateSimplePulldownMenu(menuBar, (char *) "play_menu", 1, playCB,
 		XmVaPUSHBUTTON, clearString, 'C', NULL, NULL,
 		XmVaPUSHBUTTON, undoString, 'U', NULL, NULL,
@@ -1156,6 +1221,9 @@ main(int argc, char **argv)
 		XmVaPUSHBUTTON, incrementString, 'I', NULL, NULL,
 		XmVaPUSHBUTTON, decrementString, 'D', NULL, NULL,
 		XmVaPUSHBUTTON, mode, 'M', NULL, NULL,
+		XmVaPUSHBUTTON, speedString, '>', NULL, NULL,
+		XmVaPUSHBUTTON, slowString, '<', NULL, NULL,
+		XmVaPUSHBUTTON, soundString, '@', NULL, NULL,
 		NULL);
 	XmStringFree(clearString);
 	XmStringFree(undoString);
@@ -1163,6 +1231,9 @@ main(int argc, char **argv)
 	XmStringFree(incrementString);
 	XmStringFree(decrementString);
 	XmStringFree(mode);
+	XmStringFree(speedString);
+	XmStringFree(slowString);
+	XmStringFree(soundString);
 	pullDownMenu = XmCreatePulldownMenu(menuBar,
 		(char *) "helpPullDown", NULL, 0);
 	widget = XtVaCreateManagedWidget("Help",
@@ -1301,7 +1372,7 @@ main(int argc, char **argv)
 		XtVaTypedArg, XmNtitleString, XmRString, "Animation Speed", 8,
 		XmNminimum, MINSPEED,
 		XmNmaximum, MAXSPEED,
-		XmNvalue, MAXSPEED + MINSPEED - DEFAULTDELAY / MULTSPEED - 1,
+		XmNvalue, MAXSPEED - DEFAULTDELAY,
 		XmNshowValue, True,
 		XmNorientation, XmHORIZONTAL, NULL);
 	XtAddCallback(speed, XmNvalueChangedCallback,
