@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -192,7 +192,7 @@ static XtActionsRec actionsListPyraminx[] =
 	{(char *) "Both", (XtActionProc) BothModePyraminx},
 	{(char *) "Sticky", (XtActionProc) StickyModePyraminx},
 	{(char *) "Enter", (XtActionProc) EnterPyraminx},
-        {(char *) "Leave", (XtActionProc) LeavePyraminx}
+	{(char *) "Leave", (XtActionProc) LeavePyraminx}
 };
 
 static XtResource resourcesPyraminx[] =
@@ -316,7 +316,7 @@ PyraminxClassRec pyraminxClassRec =
 WidgetClass pyraminxWidgetClass = (WidgetClass) & pyraminxClassRec;
 
 #ifndef HAVE_USLEEP
-#if !defined( VMS ) || defined( XVMSUTILS ) ||  ( __VMS_VER >= 70000000 )
+#if !defined( VMS ) || defined( XVMSUTILS ) || ( __VMS_VER >= 70000000 )
 #ifdef USE_XVMSUTILS
 #include <X11/unix_time.h>
 #endif
@@ -360,7 +360,7 @@ usleep(unsigned int usec)
 #endif
 #else
 #ifdef VMS
-	long        timadr[2];
+	long timadr[2];
 
 	if (usec != 0) {
 		timadr[0] = -usec * 10;
@@ -374,7 +374,7 @@ usleep(unsigned int usec)
 
 #if 0
 	/* (!defined(AIXV3) && !defined(__hpux)) */
-	extern int  select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
+	extern int select(int, fd_set *, fd_set *, fd_set *, struct timeval *);
 
 #endif
 
@@ -443,11 +443,11 @@ loadFont(PyraminxWidget w)
 #define NOTDIR(x) ((x==CW)?CCW:CW)
 
 typedef struct _CRD {
-	int         column, row, diagonal;
+	int column, row, diagonal;
 } CRD;
 
 typedef struct _RowNextP3 {
-	int         viewChanged, face, direction, reverse;
+	int viewChanged, face, direction, reverse;
 } RowNextP3;
 static PyraminxLoc slideNextRowP2[MAXSIDES][3] =
 {
@@ -479,7 +479,7 @@ static RowNextP3 slideNextRowP3[MAXSIDES][MAXORIENT] =
 		{FALSE, DOWN, TOP, TRUE}
 	}
 };
-static int  rotOrientRowP3[3][MAXORIENT] =
+static int rotOrientRowP3[3][MAXORIENT] =
 /* current orient, rotation */
 {
 	{1, 5, 1, 5, 4, 2},
@@ -565,7 +565,7 @@ CheckPieces(PyraminxWidget w)
 Boolean
 CheckSolved(PyraminxWidget w)
 {
-	int         face, position;
+	int face, position;
 	PyraminxLoc test;
 
 	for (face = 0; face < MAXFACES; face++)
@@ -574,9 +574,9 @@ CheckSolved(PyraminxWidget w)
 				test.face = w->pyraminx.facetLoc[face][position].face;
 				test.rotation = w->pyraminx.facetLoc[face][position].rotation;
 			} else if (test.face !=		/* MAXSIDES * view + face */
-				 w->pyraminx.facetLoc[face][position].face ||
-				   (w->pyraminx.orient && test.rotation !=
-			      w->pyraminx.facetLoc[face][position].rotation))
+					 w->pyraminx.facetLoc[face][position].face ||
+					(w->pyraminx.orient && test.rotation !=
+					w->pyraminx.facetLoc[face][position].rotation))
 				return False;
 		}
 	return True;
@@ -587,14 +587,14 @@ CheckSolved(PyraminxWidget w)
 static void
 PrintFacet(PyraminxWidget w)
 {
-	int         face, position, square;
+	int face, position, square;
 
 	for (face = 0; face < MAXSIDES; face++) {
 		square = 1;
 		for (position = 0; position < w->pyraminx.sizeSize; position++) {
 			(void) printf("%d %d  ",
-				   w->pyraminx.facetLoc[face][position].face,
-			      w->pyraminx.facetLoc[face][position].rotation);
+				w->pyraminx.facetLoc[face][position].face,
+				w->pyraminx.facetLoc[face][position].rotation);
 			if (position == square * square - 1) {
 				(void) printf("\n");
 				++square;
@@ -608,26 +608,26 @@ PrintFacet(PyraminxWidget w)
 static void
 PrintFace(PyraminxWidget w)
 {
-	int         g, h, side;
+	int g, h, side;
 
 	for (g = 0; g < w->pyraminx.size; g++) {
 		for (h = 0; h < w->pyraminx.size - g; h++)
 			for (side = 0; side < MAXSIDES; side++)
 				if (!side || h < w->pyraminx.size - g - 1)
 					(void) printf("%d %d  ", w->pyraminx.faceLoc[side][h +
-						  g * w->pyraminx.size].face,
-						      w->pyraminx.faceLoc[side][h + g * w->pyraminx.size].rotation);
+						g * w->pyraminx.size].face,
+						w->pyraminx.faceLoc[side][h + g * w->pyraminx.size].rotation);
 		(void) printf("\n");
 	}
 	(void) printf("\n");
 
 #if 0
-	int         position;
-	int         square = 1;
+	int position;
+	int square = 1;
 
 	for (position = 0; position < w->pyraminx.sizeSize; position++) {
 		(void) printf("%d %d  ", w->pyraminx.faceLoc[position].face,
-			      w->pyraminx.faceLoc[position].rotation);
+			w->pyraminx.faceLoc[position].rotation);
 		if (position == square * square - 1) {
 			(void) printf("\n");
 			++square;
@@ -640,20 +640,20 @@ PrintFace(PyraminxWidget w)
 static void
 PrintRow2(PyraminxWidget w, int orient)
 {
-	int         g, side;
+	int g, side;
 
 	(void) printf("Row %d:\n", orient);
 	for (g = 0; g < w->pyraminx.size; g++)
 		for (side = 0; side < MAXSIDES; side++)
 			(void) printf("%d %d  ", w->pyraminx.rowLoc[orient][side][g].face,
-			       w->pyraminx.rowLoc[orient][side][g].rotation);
+				w->pyraminx.rowLoc[orient][side][g].rotation);
 	(void) printf("\n");
 }
 
 static void
 PrintRow3(PyraminxWidget w, int len, int orient)
 {
-	int         g, side;
+	int g, side;
 
 	(void) printf("Row %d:\n", orient);
 	for (g = 0; g <= len; g++)
@@ -670,16 +670,16 @@ PrintRow3(PyraminxWidget w, int len, int orient)
 static int
 Sqrt(int i)
 {
-	int         j = 0;
+	int j = 0;
 
 	while (j * j <= i)
 		j++;
 	return (j - 1);
 }
-static      void
+static void
 ToCRD(PyraminxWidget w, int face, int position, CRD * crd)
 {
-	int         diag, diag2;
+	int diag, diag2;
 
 	diag = Sqrt(position);
 	diag2 = diag * diag;
@@ -698,7 +698,7 @@ ToCRD(PyraminxWidget w, int face, int position, CRD * crd)
 static int
 ToPosition(PyraminxWidget w, CRD crd)
 {
-	int         diag;
+	int diag;
 
 	if (crd.diagonal < w->pyraminx.size)
 		return (crd.diagonal * crd.diagonal + crd.diagonal + crd.column - crd.row);
@@ -732,8 +732,8 @@ POLYGON(PyraminxWidget w, GC color, GC lineColor, const POINT * poly, int n,
 		Boolean origin)
 {
 	/* CoordModePrevious -> CoordModeOrigin */
-	POINT      *temp = NULL;
-	int         pt;
+	POINT *temp = NULL;
+	int pt;
 
 	if (!origin) {
 		if (!(temp = (POINT *) malloc(sizeof (POINT) * n))) {
@@ -771,10 +771,10 @@ static void
 DrawOrientLine(PyraminxWidget w, int orient, int dx, int dy, int side,
 		GC borderGC)
 {
-	int         x_1 = 0, x_2 = 0, y_1 = 0, y_2 = 0;
-	int         temp1 = w->pyraminx.facetLength / 2 + 1;
-	int         temp2 = w->pyraminx.facetLength + 1;
-	int         fix = (w->pyraminx.size == 1) ? 1 : 0;
+	int x_1 = 0, x_2 = 0, y_1 = 0, y_2 = 0;
+	int temp1 = w->pyraminx.facetLength / 2 + 1;
+	int temp2 = w->pyraminx.facetLength + 1;
+	int fix = (w->pyraminx.size == 1) ? 1 : 0;
 
 	switch (orient) {
 		case TOP:
@@ -825,9 +825,9 @@ DrawOrientLine(PyraminxWidget w, int orient, int dx, int dy, int side,
 static void
 DrawTriangle(PyraminxWidget w, int face, int position, int offset)
 {
-	GC          faceGC, borderGC;
-	int         dx, dy, faceOnView, orient, side, view;
-	CRD         crd;
+	GC faceGC, borderGC;
+	int dx, dy, faceOnView, orient, side, view;
+	CRD crd;
 
 	ToCRD(w, face, position, &crd);
 	view = (face / MAXSIDES == UP) ? DOWN : UP;
@@ -839,9 +839,9 @@ DrawTriangle(PyraminxWidget w, int face, int position, int offset)
 		dy = (w->pyraminx.size - crd.row - 1) *
 			(w->pyraminx.facetLength + w->pyraminx.delta);
 		orient = (w->pyraminx.facetLoc[face][position].rotation +
-			  MAXORIENT / 2) % MAXORIENT;
+			MAXORIENT / 2) % MAXORIENT;
 		if (2 * w->pyraminx.size - crd.column - crd.row - 2 +
-		    faceOnView >= w->pyraminx.size) {
+				faceOnView >= w->pyraminx.size) {
 			dx += w->pyraminx.sideOffset;
 			dy += w->pyraminx.sideOffset;
 		}
@@ -881,8 +881,8 @@ DrawTriangle(PyraminxWidget w, int face, int position, int offset)
 	dx += -faceOnView;
 	dy += -faceOnView;
 	if (w->pyraminx.mono) {
-		int         letterX, letterY;
-		char        buf[2];
+		int letterX, letterY;
+		char buf[2];
 
 		buf[0] =
 #ifdef WINVER
@@ -909,7 +909,7 @@ DrawTriangle(PyraminxWidget w, int face, int position, int offset)
 void
 DrawAllPieces(PyraminxWidget w)
 {
-	int         face, position;
+	int face, position;
 
 	for (face = 0; face < MAXFACES; face++)
 		for (position = 0; position < w->pyraminx.sizeSize; position++)
@@ -926,7 +926,7 @@ EraseFrame(const PyraminxWidget w)
 static void
 DrawFrame(PyraminxWidget w, Boolean focus)
 {
-	int         startx, starty, lengthx, lengthy, longlength;
+	int startx, starty, lengthx, lengthy, longlength;
 	GC gc = (focus) ? w->pyraminx.frameGC : w->pyraminx.borderGC;
 
 	startx = 1 + w->pyraminx.puzzleOffset.x;
@@ -980,8 +980,8 @@ MoveNoPieces(PyraminxWidget w)
 static void
 RotateFace(PyraminxWidget w, int view, int faceOnView, int direction)
 {
-	int         g, h, side, face, position;
-	CRD         crd;
+	int g, h, side, face, position;
+	CRD crd;
 
 	/* Read Face */
 	for (g = 0; g < w->pyraminx.size; g++)
@@ -1024,7 +1024,7 @@ RotateFace(PyraminxWidget w, int view, int faceOnView, int direction)
 						else	/* direction == CW */
 							w->pyraminx.facetLoc[face][position] =
 								w->pyraminx.faceLoc[side][g +
-											  (w->pyraminx.size - 1 - g - h - side) * w->pyraminx.size];
+											(w->pyraminx.size - 1 - g - h - side) * w->pyraminx.size];
 						w->pyraminx.facetLoc[face][position].rotation =
 							(direction == CW) ?
 							(w->pyraminx.facetLoc[face][position].rotation + 2) %
@@ -1046,11 +1046,11 @@ RotateFace(PyraminxWidget w, int view, int faceOnView, int direction)
 						if (direction == CCW)
 							w->pyraminx.facetLoc[face][position] =
 								w->pyraminx.faceLoc[!side][g + h - w->pyraminx.size + 1 - !side
-											   + (w->pyraminx.size - 1 - h) * w->pyraminx.size];
+											+ (w->pyraminx.size - 1 - h) * w->pyraminx.size];
 						else	/* (direction == CW) */
 							w->pyraminx.facetLoc[face][position] =
 								w->pyraminx.faceLoc[!side][w->pyraminx.size - 1 - g +
-											   (g + h - w->pyraminx.size + 1 - !side) * w->pyraminx.size];
+											(g + h - w->pyraminx.size + 1 - !side) * w->pyraminx.size];
 						w->pyraminx.facetLoc[face][position].rotation =
 							(direction == CW) ?
 							(w->pyraminx.facetLoc[face][position].rotation + 2) %
@@ -1065,8 +1065,8 @@ RotateFace(PyraminxWidget w, int view, int faceOnView, int direction)
 static void
 ReadCRD2(PyraminxWidget w, int view, int dir, int h, int orient)
 {
-	int         g, i, j, side, faceOnView, s, face, position;
-	CRD         crd;
+	int g, i, j, side, faceOnView, s, face, position;
+	CRD crd;
 
 	if (dir == TOP || dir == BOTTOM)
 		for (g = 0; g < w->pyraminx.size; g++)
@@ -1095,8 +1095,8 @@ ReadCRD2(PyraminxWidget w, int view, int dir, int h, int orient)
 		for (g = 0; g < w->pyraminx.size; g++) {
 			for (side = 0; side < MAXSIDES; side++) {
 				s = (((side == UP) && (faceOnView == UP)) ||
-				     ((side == DOWN) && (faceOnView == DOWN)))
-				  ? DOWN : UP;
+					((side == DOWN) && (faceOnView == DOWN)))
+					? DOWN : UP;
 				crd.column = i;
 				crd.row = j;
 				crd.diagonal = i + j + s;
@@ -1124,8 +1124,8 @@ ReadCRD2(PyraminxWidget w, int view, int dir, int h, int orient)
 static void
 ReadCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, int orient)
 {
-	int         g, i, j, side, s, face, position;
-	CRD         crd;
+	int g, i, j, side, s, face, position;
+	CRD crd;
 
 	if (dir == TOP || dir == BOTTOM) {
 		for (g = 0; g <= len; g++)
@@ -1134,8 +1134,8 @@ ReadCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, in
 					crd.column = h;
 					crd.row = (faceOnView == UP) ? w->pyraminx.size - 1 - g : g;
 					crd.diagonal = h + crd.row + ((((side == UP) && (faceOnView == DOWN)) ||
-					  ((side == DOWN) && (faceOnView == UP)))
-					  ? UP : DOWN);
+						((side == DOWN) && (faceOnView == UP)))
+						? UP : DOWN);
 					face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 					position = ToPosition(w, crd);
 					w->pyraminx.rowLoc[orient][side][g] =
@@ -1148,9 +1148,9 @@ ReadCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, in
 					crd.column = (faceOnView == UP) ? w->pyraminx.size - 1 - g : g;
 					crd.row = h;
 					crd.diagonal = h + crd.column +
-					  ((((side == UP) && (faceOnView == DOWN)) ||
-					  ((side == DOWN) && (faceOnView == UP)))
-					  ? UP : DOWN);
+						((((side == UP) && (faceOnView == DOWN)) ||
+						((side == DOWN) && (faceOnView == UP)))
+						? UP : DOWN);
 					face = view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN);
 					position = ToPosition(w, crd);
 					w->pyraminx.rowLoc[orient][side][g] =
@@ -1164,8 +1164,8 @@ ReadCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, in
 			for (side = 0; side < MAXSIDES; side++) {
 				if (side == DOWN || g < len) {
 					s = (((side == UP) && (faceOnView == UP)) ||
-					  ((side == DOWN) && (faceOnView == DOWN)))
-					  ? DOWN : UP;
+						((side == DOWN) && (faceOnView == DOWN)))
+						? DOWN : UP;
 					crd.column = i;
 					crd.row = j;
 					crd.diagonal = i + j + s;
@@ -1185,7 +1185,7 @@ ReadCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, in
 static void
 RotateCRD2(PyraminxWidget w, int rotate, int orient)
 {
-	int         g, side;
+	int g, side;
 
 	for (g = 0; g < w->pyraminx.size; g++)
 		for (side = 0; side < MAXSIDES; side++)
@@ -1196,7 +1196,7 @@ RotateCRD2(PyraminxWidget w, int rotate, int orient)
 static void
 RotateCRD3(PyraminxWidget w, int faceOnView, int dir, int len, int orient)
 {
-	int         g, side, direction, facetOrient;
+	int g, side, direction, facetOrient;
 
 	for (g = 0; g <= len; g++)
 		for (side = 0; side < MAXSIDES; side++)
@@ -1214,7 +1214,7 @@ static void
 ReverseCRD2(PyraminxWidget w, int orient)
 {
 	PyraminxLoc temp;
-	int         g;
+	int g;
 
 	for (g = 0; g < w->pyraminx.size; g++) {
 		temp = w->pyraminx.rowLoc[orient][g % 2][g / 2];
@@ -1229,7 +1229,7 @@ static void
 ReverseCRD3(PyraminxWidget w, int len, int orient)
 {
 	PyraminxLoc temp;
-	int         g;
+	int g;
 
 	for (g = 0; g < len; g++) {
 		temp = w->pyraminx.rowLoc[orient][g % 2][len - ((g + 1) / 2)];
@@ -1242,8 +1242,8 @@ ReverseCRD3(PyraminxWidget w, int len, int orient)
 static void
 WriteCRD2(PyraminxWidget w, int view, int dir, int h, int orient)
 {
-	int         g, side, i, j, s, faceOnView, face, position;
-	CRD         crd;
+	int g, side, i, j, s, faceOnView, face, position;
+	CRD crd;
 
 	if (dir == TOP || dir == BOTTOM) {
 		for (g = 0; g < w->pyraminx.size; g++)
@@ -1256,8 +1256,8 @@ WriteCRD2(PyraminxWidget w, int view, int dir, int h, int orient)
 				w->pyraminx.facetLoc[face][position] =
 					w->pyraminx.rowLoc[orient][side][g];
 				DrawTriangle(w,
-					     view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN),
-					     ToPosition(w, crd), FALSE);
+					view * MAXSIDES + ((crd.diagonal >= w->pyraminx.size) ? UP : DOWN),
+					ToPosition(w, crd), FALSE);
 			}
 	} else if (dir == RIGHT || dir == LEFT) {
 		for (g = 0; g < w->pyraminx.size; g++)
@@ -1278,8 +1278,8 @@ WriteCRD2(PyraminxWidget w, int view, int dir, int h, int orient)
 		for (g = 0; g < w->pyraminx.size; g++) {
 			for (side = 0; side < MAXSIDES; side++) {
 				s = (((side == UP) && (faceOnView == UP)) ||
-				  ((side == DOWN) && (faceOnView == DOWN)))
-				  ? DOWN : UP;
+					((side == DOWN) && (faceOnView == DOWN)))
+					? DOWN : UP;
 				crd.column = i;
 				crd.row = j;
 				crd.diagonal = i + j + s;
@@ -1315,8 +1315,8 @@ WriteCRD2(PyraminxWidget w, int view, int dir, int h, int orient)
 static void
 WriteCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, int orient)
 {
-	int         g, side, i, j, k, s, face, position;
-	CRD         crd;
+	int g, side, i, j, k, s, face, position;
+	CRD crd;
 
 	if (dir == TOP || dir == BOTTOM) {
 		for (k = 0; k <= len; k++)
@@ -1324,8 +1324,8 @@ WriteCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, i
 				if ((side == DOWN) || k < len) {
 					g = (faceOnView == UP) ? w->pyraminx.size - 1 - k : k;
 					s = (((side == UP) && (faceOnView == DOWN)) ||
-					  ((side == DOWN) && (faceOnView == UP)))
-					  ? UP : DOWN;
+						((side == DOWN) && (faceOnView == UP)))
+						? UP : DOWN;
 					crd.column = h;
 					crd.row = g;
 					crd.diagonal = h + g + s;
@@ -1341,8 +1341,8 @@ WriteCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, i
 				if ((side == DOWN) || k < len) {
 					g = (faceOnView == UP) ? w->pyraminx.size - 1 - k : k;
 					s = (((side == UP) && (faceOnView == DOWN)) ||
-					  ((side == DOWN) && (faceOnView == UP)))
-					  ? UP : DOWN;
+						((side == DOWN) && (faceOnView == UP)))
+						? UP : DOWN;
 					crd.column = g;
 					crd.row = h;
 					crd.diagonal = h + g + s;
@@ -1360,8 +1360,8 @@ WriteCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, i
 			for (side = 0; side < MAXSIDES; side++)
 				if ((side == DOWN) || k < len) {
 					s = (((side == UP) && (faceOnView == UP)) ||
-					  ((side == DOWN) && (faceOnView == DOWN)))
-					  ? DOWN : UP;
+						((side == DOWN) && (faceOnView == DOWN)))
+						? DOWN : UP;
 					crd.column = i;
 					crd.row = j;
 					crd.diagonal = i + j + s;
@@ -1397,10 +1397,9 @@ WriteCRD3(PyraminxWidget w, int view, int faceOnView, int dir, int h, int len, i
 static void
 MovePieces(PyraminxWidget w, int face, CRD crd, int direction, int style)
 {
-	int         view, side;
-	int         newSide, newView, rotate, reverse, h, k, newH, faceOnView,
-	            len;
-	int         newFace, newDirection, bound, l = 0;
+	int view, side;
+	int newSide, newView, rotate, reverse, h, k, newH, faceOnView, len;
+	int newFace, newDirection, bound, l = 0;
 
 	view = face / MAXSIDES;
 	side = crd.diagonal - crd.column - crd.row;
@@ -1459,17 +1458,17 @@ MovePieces(PyraminxWidget w, int face, CRD crd, int direction, int style)
 			else if (w->pyraminx.sticky)
 				bound = TRUE;
 		} else if (!crd.column && faceOnView == DOWN &&
-			   (direction == TOP || direction == BOTTOM))
+				(direction == TOP || direction == BOTTOM))
 			RotateFace(w, !view, DOWN,
 			 (direction == TOP || direction == LEFT) ? CCW : CW);
 		else if (crd.column == w->pyraminx.size - 1 && faceOnView &&
 			 (direction == TOP || direction == BOTTOM))
 			RotateFace(w, !view, UP,
-				   (direction == BOTTOM || direction == RIGHT) ? CCW : CW);
+				(direction == BOTTOM || direction == RIGHT) ? CCW : CW);
 		else if (!crd.row && faceOnView == DOWN &&
 			 (direction == RIGHT || direction == LEFT))
 			RotateFace(w, !view, UP,
-				   (direction == BOTTOM || direction == RIGHT) ? CCW : CW);
+				(direction == BOTTOM || direction == RIGHT) ? CCW : CW);
 		else if (crd.row == w->pyraminx.size - 1 && faceOnView == UP &&
 			 (direction == RIGHT || direction == LEFT))
 			RotateFace(w, !view, DOWN,
@@ -1527,8 +1526,8 @@ MovePieces(PyraminxWidget w, int face, CRD crd, int direction, int style)
 static void
 MoveControlCb(PyraminxWidget w, int face, int direction, int style)
 {
-	int         i, faceOnView;
-	CRD         crd;
+	int i, faceOnView;
+	CRD crd;
 
 	faceOnView = face % MAXSIDES;
 	if (w->pyraminx.sticky) {
@@ -1610,10 +1609,10 @@ MovePyraminxDelay(PyraminxWidget w, int face, int position, int direction,
 	Sleep((unsigned int) w->pyraminx.delay);
 }
 
-static      Boolean
+static Boolean
 SelectPieces(PyraminxWidget w, int x, int y, int *face, CRD * crd)
 {
-	int         offset, modI, modJ, side, view;
+	int offset, modI, modJ, side, view;
 
 	x -= w->pyraminx.puzzleOffset.x;
 	y -= w->pyraminx.puzzleOffset.y;
@@ -1626,8 +1625,8 @@ SelectPieces(PyraminxWidget w, int x, int y, int *face, CRD * crd)
 	} else
 		view = UP;
 	if (x <= 0 || y <= 0 ||
-	    x >= w->pyraminx.faceLength + w->pyraminx.delta ||
-	    y >= w->pyraminx.faceLength + w->pyraminx.delta)
+			x >= w->pyraminx.faceLength + w->pyraminx.delta ||
+			y >= w->pyraminx.faceLength + w->pyraminx.delta)
 		return False;
 	else if (x + y > w->pyraminx.faceLength)
 		offset = 2 * w->pyraminx.delta + 1;
@@ -1652,8 +1651,8 @@ SelectPieces(PyraminxWidget w, int x, int y, int *face, CRD * crd)
 static int
 CheckMoveDir(PyraminxWidget w, CRD crd1, CRD crd2, int face, int *direction)
 {
-	int         which = -1, count = 0;
-	int         i, *p1, *p2;
+	int which = -1, count = 0;
+	int i, *p1, *p2;
 
 	p1 = &(crd1.column);
 	p2 = &(crd2.column);
@@ -1694,7 +1693,7 @@ NarrowSelection(PyraminxWidget w, int style, int *face, CRD * crd, int *directio
 			crd->diagonal = w->pyraminx.size -
 				((crd->diagonal < w->pyraminx.size) ? UP : DOWN);
 			*direction = ((*direction == CW && crd->diagonal == w->pyraminx.size) ||
-				      (*direction == CCW && crd->diagonal != w->pyraminx.size))
+				(*direction == CCW && crd->diagonal != w->pyraminx.size))
 				? TR : BL;
 			*face = !(*face % 2) + 2 * (*face / 2);
 			crd->row = w->pyraminx.size - 1;
@@ -1703,7 +1702,7 @@ NarrowSelection(PyraminxWidget w, int style, int *face, CRD * crd, int *directio
 	}
 }
 
-static      Boolean
+static Boolean
 PositionPieces(PyraminxWidget w, int x, int y, int style, int *face, CRD * crd, int *direction)
 {
 	if (!SelectPieces(w, x, y, face, crd))
@@ -1719,8 +1718,8 @@ void
 MovePyraminxInput(PyraminxWidget w, int x, int y, int direction, int shift,
 		int control)
 {
-	int         style, face;
-	CRD         crd;
+	int style, face;
+	CRD crd;
 
 	if (w->pyraminx.mode != BOTH) {
 		if (control && shift)
@@ -1745,20 +1744,20 @@ MovePyraminxInput(PyraminxWidget w, int x, int y, int direction, int shift,
 static void
 ResetPieces(PyraminxWidget w)
 {
-	int         face, position, orient, side;
+	int face, position, orient, side;
 
 	w->pyraminx.sizeSize = w->pyraminx.size * w->pyraminx.size;
 	for (face = 0; face < MAXFACES; face++) {
 		if (w->pyraminx.facetLoc[face])
 			(void) free((void *) w->pyraminx.facetLoc[face]);
 		if (!(w->pyraminx.facetLoc[face] = (PyraminxLoc *)
-		      malloc(sizeof (PyraminxLoc) * w->pyraminx.sizeSize))) {
+				malloc(sizeof (PyraminxLoc) * w->pyraminx.sizeSize))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 		if (startLoc[face])
 			(void) free((void *) startLoc[face]);
 		if (!(startLoc[face] = (PyraminxLoc *)
-		      malloc(sizeof (PyraminxLoc) * w->pyraminx.sizeSize))) {
+				malloc(sizeof (PyraminxLoc) * w->pyraminx.sizeSize))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
@@ -1767,7 +1766,7 @@ ResetPieces(PyraminxWidget w)
 			if (w->pyraminx.rowLoc[orient][side])
 				(void) free((void *) w->pyraminx.rowLoc[orient][side]);
 			if (!(w->pyraminx.rowLoc[orient][side] = (PyraminxLoc *)
-			    malloc(sizeof (PyraminxLoc) * w->pyraminx.size))) {
+					malloc(sizeof (PyraminxLoc) * w->pyraminx.size))) {
 				DISPLAY_ERROR("Not enough memory, exiting.");
 			}
 		}
@@ -1775,7 +1774,7 @@ ResetPieces(PyraminxWidget w)
 		if (w->pyraminx.faceLoc)
 			(void) free((void *) w->pyraminx.faceLoc[side]);
 		if (!(w->pyraminx.faceLoc[side] = (PyraminxLoc *)
-		      malloc(sizeof (PyraminxLoc) * w->pyraminx.sizeSize))) {
+				malloc(sizeof (PyraminxLoc) * w->pyraminx.sizeSize))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
 	}
@@ -1792,7 +1791,7 @@ ResetPieces(PyraminxWidget w)
 static void
 ResizePieces(PyraminxWidget w)
 {
-	int         i, j;
+	int i, j;
 
 	w->pyraminx.facetLength = w->pyraminx.faceLength / w->pyraminx.size -
 		w->pyraminx.delta - 1;
@@ -1823,8 +1822,8 @@ ResizePieces(PyraminxWidget w)
 static void
 GetPieces(PyraminxWidget w)
 {
-	FILE       *fp;
-	int         c, i, size, mode, sticky, orient, practice, moves;
+	FILE *fp;
+	int c, i, size, mode, sticky, orient, practice, moves;
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname, *name;
 
@@ -1939,7 +1938,7 @@ GetPieces(PyraminxWidget w)
 	ScanMoves(fp, w, moves);
 	(void) fclose(fp);
 	(void) printf("%s: size %d, mode %d, sticky %d, orient %d",
-		      name, size, mode, sticky, orient);
+		name, size, mode, sticky, orient);
 	(void) printf(", practice %d, moves %d.\n", practice, moves);
 	free(lname);
 	free(fname);
@@ -1949,7 +1948,7 @@ GetPieces(PyraminxWidget w)
 static void
 WritePieces(PyraminxWidget w)
 {
-	FILE       *fp;
+	FILE *fp;
 	char *buf1 = NULL, *buf2 = NULL;
 	char *fname, *lname, *name;
 
@@ -2010,16 +2009,16 @@ ClearPieces(PyraminxWidget w)
 {
 	if (w->pyraminx.currentFace >= 0)
 		return;
-        ResetPieces(w);
-        DrawAllPieces(w);
-        SetPyraminx(w, PYRAMINX_RESET);
+	ResetPieces(w);
+	DrawAllPieces(w);
+	SetPyraminx(w, PYRAMINX_RESET);
 }
 
 static void
 UndoPieces(PyraminxWidget w)
 {
 	if (MadeMoves() && w->pyraminx.currentFace < 0) {
-		int         face, position, direction, style, control;
+		int face, position, direction, style, control;
 
 		GetMove(&face, &position, &direction, &style, &control);
 		direction = (direction < MAXORIENT) ? (direction + MAXORIENT / 2) %
@@ -2045,8 +2044,8 @@ PracticePieces(PyraminxWidget w)
 static void
 RandomizePieces(PyraminxWidget w)
 {
-	int         randomDirection, face, position, style;
-	int         big = w->pyraminx.sizeSize * 3 + NRAND(2);
+	int randomDirection, face, position, style;
+	int big = w->pyraminx.sizeSize * 3 + NRAND(2);
 
 	if (w->pyraminx.currentFace >= 0)
 		return;
@@ -2148,10 +2147,10 @@ static void
 SetValuesPyraminx(PyraminxWidget w)
 {
 	struct tagColor {
-		int         red, green, blue;
+		int red, green, blue;
 	} color;
-	char        szBuf[80], buf[20], charbuf[2];
-	int         face;
+	char szBuf[80], buf[20], charbuf[2];
+	int face;
 
 	w->pyraminx.size = GetPrivateProfileInt(SECTION, "size",
 		DEFAULTFACETS, INIFILE);
@@ -2219,9 +2218,9 @@ DestroyPyraminx(HBRUSH brush)
 static void
 GetColor(PyraminxWidget w, int face)
 {
-	XGCValues   values;
-	XtGCMask    valueMask;
-	XColor      colorCell, rgb;
+	XGCValues values;
+	XtGCMask valueMask;
+	XColor colorCell, rgb;
 
 	valueMask = GCForeground | GCBackground;
 	if (w->pyraminx.reverse) {
@@ -2231,8 +2230,8 @@ GetColor(PyraminxWidget w, int face)
 	}
 	if (!w->pyraminx.mono) {
 		if (XAllocNamedColor(XtDisplay(w),
-				  DefaultColormapOfScreen(XtScreen(w)),
-			     w->pyraminx.faceName[face], &colorCell, &rgb)) {
+				DefaultColormapOfScreen(XtScreen(w)),
+				w->pyraminx.faceName[face], &colorCell, &rgb)) {
 			values.foreground = w->pyraminx.faceColor[face] = colorCell.pixel;
 			if (w->pyraminx.faceGC[face])
 				XtReleaseGC((Widget) w,
@@ -2267,9 +2266,9 @@ GetColor(PyraminxWidget w, int face)
 static void
 SetAllColors(PyraminxWidget w)
 {
-	XGCValues   values;
-	XtGCMask    valueMask;
-	int         face;
+	XGCValues values;
+	XtGCMask valueMask;
+	int face;
 
 	valueMask = GCForeground | GCBackground;
 
@@ -2320,12 +2319,12 @@ SetAllColors(PyraminxWidget w)
 			w->pyraminx.fontInfo->fid);
 }
 
-static      Boolean
+static Boolean
 SetValuesPyraminx(Widget current, Widget request, Widget renew)
 {
 	PyraminxWidget c = (PyraminxWidget) current, w = (PyraminxWidget) renew;
-	Boolean     redraw = False, setColors = False;
-	int         face;
+	Boolean redraw = False, setColors = False;
+	int face;
 
 	CheckPieces(w);
 	for (face = 0; face < MAXFACES; face++) {
@@ -2342,8 +2341,8 @@ SetValuesPyraminx(Widget current, Widget request, Widget renew)
 		SetAllColors(w);
 		redraw = True;
 	} else if (w->pyraminx.background != c->pyraminx.background ||
-	    w->pyraminx.foreground != c->pyraminx.foreground ||
-	    setColors) {
+			w->pyraminx.foreground != c->pyraminx.foreground ||
+			setColors) {
 		SetAllColors(w);
 		redraw = True;
 	}
@@ -2355,8 +2354,8 @@ SetValuesPyraminx(Widget current, Widget request, Widget renew)
 		redraw = True;
 	}
 	if (w->pyraminx.size != c->pyraminx.size ||
-	    w->pyraminx.mode != c->pyraminx.mode ||
-	    w->pyraminx.sticky != c->pyraminx.sticky) {
+			w->pyraminx.mode != c->pyraminx.mode ||
+			w->pyraminx.sticky != c->pyraminx.sticky) {
 		SizePyraminx(w);
 		redraw = True;
 	}
@@ -2435,7 +2434,7 @@ static void
 DestroyPyraminx(Widget old)
 {
 	PyraminxWidget w = (PyraminxWidget) old;
-	int         face;
+	int face;
 
 	for (face = 0; face < MAXFACES; face++)
 		XtReleaseGC(old, w->pyraminx.faceGC[face]);
@@ -2452,9 +2451,9 @@ static
 void
 ResizePyraminx(PyraminxWidget w)
 {
-	int         tempLength;
+	int tempLength;
 #ifdef WINVER
-	RECT        rect;
+	RECT rect;
 
 	/* Determine size of client area */
 	(void) GetClientRect(w->core.hWnd, &rect);
@@ -2469,7 +2468,7 @@ ResizePyraminx(PyraminxWidget w)
 	else
 		tempLength = MIN(w->core.height, w->core.width / 2);
 	w->pyraminx.facetLength = MAX((tempLength - w->pyraminx.delta + 1) /
-				      w->pyraminx.size, 0);
+		w->pyraminx.size, 0);
 	w->pyraminx.faceLength = w->pyraminx.size * w->pyraminx.facetLength;
 	w->pyraminx.viewLength = w->pyraminx.faceLength + w->pyraminx.delta + 3;
 	if (w->pyraminx.vertical) {
@@ -2482,9 +2481,9 @@ ResizePyraminx(PyraminxWidget w)
 		w->pyraminx.puzzleSize.y = w->pyraminx.viewLength - 1;
 	}
 	w->pyraminx.puzzleOffset.x = ((int) w->core.width -
-				      w->pyraminx.puzzleSize.x) / 2;
+		w->pyraminx.puzzleSize.x) / 2;
 	w->pyraminx.puzzleOffset.y = ((int) w->core.height -
-				      w->pyraminx.puzzleSize.y) / 2;
+		w->pyraminx.puzzleSize.y) / 2;
 	ResizePieces(w);
 }
 
@@ -2510,7 +2509,7 @@ Widget request, Widget renew
 #endif
 )
 {
-	int         face, orient, side;
+	int face, orient, side;
 #ifdef WINVER
 	SetValuesPyraminx(w);
 #else
@@ -2596,9 +2595,9 @@ SelectPyraminx(PyraminxWidget w
 #endif
 )
 {
-	CRD         crd;
+	CRD crd;
 #ifndef WINVER
-	int  x = event->xbutton.x, y = event->xbutton.y;
+	int x = event->xbutton.x, y = event->xbutton.y;
 	int control = (int) (event->xkey.state & ControlMask);
 #endif
 
@@ -2606,7 +2605,7 @@ SelectPyraminx(PyraminxWidget w
 		w->pyraminx.currentPosition = ToPosition(w, crd);
 		if (control || w->pyraminx.practice || !CheckSolved(w))
 			DrawTriangle(w, w->pyraminx.currentFace, w->pyraminx.currentPosition,
-				     TRUE);
+				TRUE);
 	} else
 		w->pyraminx.currentFace = -1;
 }
@@ -2623,10 +2622,10 @@ ReleasePyraminx(PyraminxWidget w
 #endif
 )
 {
-	int         style, face, count = -1, direction = 0;
-	CRD         crd;
+	int style, face, count = -1, direction = 0;
+	CRD crd;
 #ifndef WINVER
-	int  x = event->xbutton.x, y = event->xbutton.y;
+	int x = event->xbutton.x, y = event->xbutton.y;
 	int shift = (int) (event->xbutton.state & (ShiftMask | LockMask));
 	int control = (int) (event->xkey.state & ControlMask);
 #endif
@@ -2635,7 +2634,7 @@ ReleasePyraminx(PyraminxWidget w
 	if (w->pyraminx.currentFace < 0)
 		return;
 	DrawTriangle(w, w->pyraminx.currentFace, w->pyraminx.currentPosition,
-		     FALSE);
+		FALSE);
 	if (!control && !w->pyraminx.practice && CheckSolved(w))
 		MoveNoPieces(w);
 	else if (SelectPieces(w, x, y, &face, &crd)) {
@@ -2647,7 +2646,7 @@ ReleasePyraminx(PyraminxWidget w
 		} else
 			style = (shift) ? PERIOD3 : PERIOD2;
 		if (face == w->pyraminx.currentFace) {
-			CRD         crd0;
+			CRD crd0;
 
 			ToCRD(w, face, w->pyraminx.currentPosition, &crd0);
 			count = CheckMoveDir(w, crd0, crd, face, &direction);
@@ -2938,63 +2937,63 @@ static void
 MovePyraminxCcw(PyraminxWidget w, XEvent * event, char **args, int nArgs)
 {
 	MovePyraminxInput(w, event->xbutton.x, event->xbutton.y, CCW,
-		       (int) (event->xbutton.state & (ShiftMask | LockMask)),
-			  (int) (event->xbutton.state & ControlMask));
+		(int) (event->xbutton.state & (ShiftMask | LockMask)),
+		(int) (event->xbutton.state & ControlMask));
 }
 
 static void
 MovePyraminxTop(PyraminxWidget w, XEvent * event, char **args, int nArgs)
 {
 	MovePyraminxInput(w, event->xbutton.x, event->xbutton.y, TOP,
-			  (int) (event->xkey.state & (ShiftMask | LockMask)),
-			  (int) (event->xkey.state & ControlMask));
+		(int) (event->xkey.state & (ShiftMask | LockMask)),
+		(int) (event->xkey.state & ControlMask));
 }
 
 static void
 MovePyraminxTr(PyraminxWidget w, XEvent * event, char **args, int nArgs)
 {
 	MovePyraminxInput(w, event->xbutton.x, event->xbutton.y, TR,
-			  (int) (event->xkey.state & (ShiftMask | LockMask)),
-			  (int) (event->xkey.state & ControlMask));
+		(int) (event->xkey.state & (ShiftMask | LockMask)),
+		(int) (event->xkey.state & ControlMask));
 }
 
 static void
 MovePyraminxLeft(PyraminxWidget w, XEvent * event, char **args, int nArgs)
 {
 	MovePyraminxInput(w, event->xbutton.x, event->xbutton.y, LEFT,
-			  (int) (event->xkey.state & (ShiftMask | LockMask)),
-			  (int) (event->xkey.state & ControlMask));
+		(int) (event->xkey.state & (ShiftMask | LockMask)),
+		(int) (event->xkey.state & ControlMask));
 }
 
 static void
 MovePyraminxCw(PyraminxWidget w, XEvent * event, char **args, int nArgs)
 {
 	MovePyraminxInput(w, event->xbutton.x, event->xbutton.y, CW,
-			  (int) (event->xkey.state & (ShiftMask | LockMask)),
-			  (int) (event->xkey.state & ControlMask));
+		(int) (event->xkey.state & (ShiftMask | LockMask)),
+		(int) (event->xkey.state & ControlMask));
 }
 
 static void
 MovePyraminxRight(PyraminxWidget w, XEvent * event, char **args, int nArgs)
 {
 	MovePyraminxInput(w, event->xbutton.x, event->xbutton.y, RIGHT,
-			  (int) (event->xkey.state & (ShiftMask | LockMask)),
-			  (int) (event->xkey.state & ControlMask));
+		(int) (event->xkey.state & (ShiftMask | LockMask)),
+		(int) (event->xkey.state & ControlMask));
 }
 
 static void
 MovePyraminxBl(PyraminxWidget w, XEvent * event, char **args, int nArgs)
 {
 	MovePyraminxInput(w, event->xbutton.x, event->xbutton.y, BL,
-			  (int) (event->xkey.state & (ShiftMask | LockMask)),
-			  (int) (event->xkey.state & ControlMask));
+		(int) (event->xkey.state & (ShiftMask | LockMask)),
+		(int) (event->xkey.state & ControlMask));
 }
 
 static void
 MovePyraminxBottom(PyraminxWidget w, XEvent * event, char **args, int nArgs)
 {
 	MovePyraminxInput(w, event->xbutton.x, event->xbutton.y, BOTTOM,
-			  (int) (event->xkey.state & (ShiftMask | LockMask)),
-			  (int) (event->xkey.state & ControlMask));
+		(int) (event->xkey.state & (ShiftMask | LockMask)),
+		(int) (event->xkey.state & ControlMask));
 }
 #endif
