@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -99,7 +99,7 @@ static HWND Wnd;
 
 #ifdef HAVE_MOTIF
 static const char aboutHelp[] = {
-	"Version 7.1\n"
+	"Version 7.1.3\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
@@ -121,7 +121,7 @@ static const char descriptionHelp[] = {
 	"and has period 3 turning (i.e. the face or points turn\n"
 	"in 120 degree intervals).  The puzzle was designed by Uwe "
 	"Meffert and called the Pyraminx.  This has 2^5*3^8*6!/2\n"
-	"or 75,582,720 different comibinations.\n"
+	"or 75,582,720 different combinations.\n"
 	"Another puzzle Senior Pyraminx 3x3x3 exists only on "
 	"paper, it has period 2 turning (i.e.  edges turn with\n"
 	"180 degree intervals) but the corners would fall off "
@@ -935,6 +935,34 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
+#if (_WIN32_WINNT >= 0x0400) || (_WIN32_WINDOWS > 0x0400)
+		case WM_MOUSEWHEEL:
+			widget.core.hDC = GetDC(hWnd);
+			(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
+			{
+				int zDelta = ((short) HIWORD(wParam));
+				POINT cursor, origin;
+
+				origin.x = 0, origin.y = 0;
+				ClientToScreen(hWnd, &origin);
+				(void) GetCursorPos(&cursor);
+				if (zDelta > (WHEEL_DELTA >> 1)) {
+					MovePyraminxInput(&widget,
+						cursor.x - origin.x, cursor.y - origin.y,
+						TOP,
+				((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)),
+				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
+				} else if (zDelta < -(WHEEL_DELTA >> 1)) {
+					MovePyraminxInput(&widget,
+						cursor.x - origin.x, cursor.y - origin.y,
+						BOTTOM,
+				((GetKeyState(VK_SHIFT) >> 1) || (GetKeyState(VK_CAPITAL) & 1)),
+				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
+				}
+			}
+			(void) ReleaseDC(hWnd, widget.core.hDC);
+			break;
+#endif
 		case WM_COMMAND:
 			switch (LOWORD(wParam)) {
 				case IDM_GET:
