@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -103,7 +103,7 @@ static HWND Wnd;
 
 #ifdef HAVE_MOTIF
 static const char aboutHelp[] = {
-	"Version 7.1\n"
+	"Version 7.1.3\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
@@ -1149,7 +1149,7 @@ CallbackRubik(Widget w, caddr_t clientData, rubikCallbackStruct * callData)
 	PrintState(XtParent(w), dim, sizex, sizey, sizez,
 		movesDsp, messageDsp);
 	PrintState(XtParent(otherw1), otherdim1, sizex, sizey, sizez,
-		ovesDsp, messageDsp);
+		movesDsp, messageDsp);
 #ifdef HAVE_OPENGL
 	PrintState(XtParent(otherw2), otherdim2, sizex, sizey, sizez,
 		movesDsp, messageDsp);
@@ -1267,6 +1267,32 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
+#if (_WIN32_WINNT >= 0x0400) || (_WIN32_WINDOWS > 0x0400)
+		case WM_MOUSEWHEEL:
+			widget.core.hDC = GetDC(hWnd);
+			(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
+			{
+				int zDelta = ((short) HIWORD(wParam));
+				POINT cursor, origin;
+
+				origin.x = 0, origin.y = 0;
+				ClientToScreen(hWnd, &origin);
+				(void) GetCursorPos(&cursor);
+				if (zDelta > (WHEEL_DELTA >> 1)) {
+					MoveRubikInput(&widget,
+						cursor.x - origin.x, cursor.y - origin.y,
+						TOP,
+				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
+				} else if (zDelta < -(WHEEL_DELTA >> 1)) {
+					MoveRubikInput(&widget,
+						cursor.x - origin.x, cursor.y - origin.y,
+						BOTTOM,
+				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0);
+				}
+			}
+			(void) ReleaseDC(hWnd, widget.core.hDC);
+			break;
+#endif
 		case WM_COMMAND:
 			switch (LOWORD(wParam)) {
 				case IDM_GET:
