@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -102,7 +102,7 @@ static HWND Wnd;
 
 #ifdef HAVE_MOTIF
 static const char aboutHelp[] = {
-	"Version 7.1\n"
+	"Version 7.1.3\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
@@ -1029,16 +1029,46 @@ WindowProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
 			SelectSkewb(&widget, LOWORD(lParam), HIWORD(lParam),
-				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0, FALSE);
+				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0,
+				(GetKeyState(VK_TAB) >> 1) ? 1 : 0);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
 		case WM_LBUTTONUP:
 			widget.core.hDC = GetDC(hWnd);
 			(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
 			ReleaseSkewb(&widget, LOWORD(lParam), HIWORD(lParam),
-				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0, FALSE);
+				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0,
+				(GetKeyState(VK_TAB) >> 1) ? 1 : 0);
 			(void) ReleaseDC(hWnd, widget.core.hDC);
 			break;
+#if (_WIN32_WINNT >= 0x0400) || (_WIN32_WINDOWS > 0x0400)
+		case WM_MOUSEWHEEL:
+			widget.core.hDC = GetDC(hWnd);
+			(void) SelectObject(widget.core.hDC, GetStockObject(NULL_PEN));
+			{
+				int zDelta = ((short) HIWORD(wParam));
+				POINT cursor, origin;
+
+				origin.x = 0, origin.y = 0;
+				ClientToScreen(hWnd, &origin);
+				(void) GetCursorPos(&cursor);
+				if (zDelta > (WHEEL_DELTA >> 1)) {
+					MoveSkewbInput(&widget,
+						cursor.x - origin.x, cursor.y - origin.y,
+						TOP,
+				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0,
+				(GetKeyState(VK_TAB) >> 1) ? 1 : 0);
+				} else if (zDelta < -(WHEEL_DELTA >> 1)) {
+					MoveSkewbInput(&widget,
+						cursor.x - origin.x, cursor.y - origin.y,
+						BOTTOM,
+				(GetKeyState(VK_CONTROL) >> 1) ? 1 : 0,
+				(GetKeyState(VK_TAB) >> 1) ? 1 : 0);
+				}
+			}
+			(void) ReleaseDC(hWnd, widget.core.hDC);
+			break;
+#endif
 		case WM_COMMAND:
 			switch (LOWORD(wParam)) {
 				case IDM_GET:
