@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1994 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1994 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -145,7 +145,6 @@ static char defaultTranslationsTriangles[] =
  <KeyPress>0x3E: Speed()\n\
  <KeyPress>0x3C: Slow()\n\
  <KeyPress>0x2C: Slow()\n\
- <KeyPress>2: Sound()\n\
  <KeyPress>@: Sound()\n\
  <EnterWindow>: Enter()\n\
  <LeaveWindow>: Leave()";
@@ -550,7 +549,7 @@ ToPosition(int row, int trbl, int tlbr)
 static int
 ToOrient(int row, int trbl, int tlbr)
 {
-	return (trbl + tlbr == row);
+	return ((trbl + tlbr == row) ? UP : DOWN);
 }
 
 int
@@ -572,18 +571,22 @@ TlBr(const int pos, int const posRow)
 	return ((posRow * posRow + 2 * posRow - pos) / 2);
 }
 
-static void
-Cartesian(TrianglesWidget w, int pos, int orient, int * x, int * y)
+static int
+CartesianX(TrianglesWidget w, int pos, int row)
 {
-	int k = Row(pos);
-
-	*y = (orient == UP) ? 0 : w->triangles.tileSize.y;
-	*y += k * w->triangles.offset.y + w->triangles.delta.y + 2 +
-		w->triangles.puzzleOffset.y;
-	*x = (pos - k * k - k + w->triangles.size) * w->triangles.offset.x / 2 +
+	return (pos - row * row - row + w->triangles.size) *
+		w->triangles.offset.x / 2 +
 		w->triangles.delta.x / 2 + w->triangles.puzzleOffset.x;
 }
 
+static int
+CartesianY(TrianglesWidget w, int row, int orient)
+{
+	return ((orient == UP) ? 0 : w->triangles.tileSize.y) +
+		row * w->triangles.offset.y + w->triangles.delta.y + 2 +
+		w->triangles.puzzleOffset.y;
+}
+
 static int
 TileNFromSpace(TrianglesWidget w, int n, int rowType, int orient, int direction)
 {
@@ -629,12 +632,12 @@ CheckSolved(const TrianglesWidget w)
 }
 
 static Boolean
-bresenhamLine(int x0, int y0, int x1, int y1,
+bresenhamLine(int startX, int startY, int endX, int endY,
 		int * pixX, int * pixY, int * pixNo)
 {
 	int pix = 0;
-	int ex = x1 - x0;
-	int ey = y1 - y0;
+	int ex = endX - startX;
+	int ey = endY - startY;
 	int dx, dy, error;
 
 	(*pixNo)++;
@@ -654,8 +657,8 @@ bresenhamLine(int x0, int y0, int x1, int y1,
 	} else {
 		dy = 0;
 	}
-	*pixX = x0;
-	*pixY = y0;
+	*pixX = startX;
+	*pixY = startY;
 	if (ex > ey) {
 		error = 2 * ey - ex;
 		while (pix != *pixNo) {
@@ -666,12 +669,12 @@ bresenhamLine(int x0, int y0, int x1, int y1,
 			error += 2 * ey;
 			*pixX += dx;
 			pix++;
-			if (*pixX == x1)
+			if (*pixX == endX)
 				return True;
 		}
 		return False;
 	} else {
-		error = 2 * ex -ey;
+		error = 2 * ex - ey;
 		while (pix != *pixNo) {
 			if (error >= 0) {
 				error -= 2 * ey;
@@ -680,7 +683,7 @@ bresenhamLine(int x0, int y0, int x1, int y1,
 			error += 2 * ex;
 			*pixY += dy;
 			pix++;
-			if (*pixY == y1)
+			if (*pixY == endY)
 				return True;
 		}
 		return False;
@@ -893,7 +896,7 @@ DrawTile(TrianglesWidget w, int pos, int orient, Boolean blank, Boolean erase,
 {
 	Pixmap *dr;
 	Pixmap adr = 0;
-	int dx, dy;
+	int dx, dy, row;
 	GC tileGC, borderGC;
 
 	/*dr = &(w->triangles.bufferTiles[pressedOffset]);*/
@@ -905,9 +908,9 @@ DrawTile(TrianglesWidget w, int pos, int orient, Boolean blank, Boolean erase,
 		tileGC = w->triangles.tileGC;
 		borderGC = w->triangles.borderGC;
 	}
-	Cartesian(w, pos, orient, &dx, &dy);
-	dx += offsetX + pressedOffset;
-	dy += offsetY + pressedOffset;
+	row = Row(pos);
+	dx = CartesianX(w, pos, row) + offsetX + pressedOffset;
+	dy = CartesianY(w, row, orient) + offsetY + pressedOffset;
 	triangleList[orient][0].x = dx;
 	triangleList[orient][0].y = dy;
 	if (blank) {
@@ -978,7 +981,7 @@ DrawAllTiles(const TrianglesWidget w)
 			step += 2;
 			fin += step;
 		} else
-			side = !side;
+			side = (side == UP) ? DOWN : UP;
 	}
 }
 
@@ -1043,74 +1046,96 @@ RhombusType(TrianglesWidget w)
 
 #ifdef ANIMATE
 static int
-CountTiles(TrianglesWidget w, int *dir, int *rowType)
+CountTiles(TrianglesWidget w, int dir, int rowType)
 {
-	int count = 0;
-	char *buf;
+	switch (rowType) {
+	case TLBR:
+		return w->triangles.spaceRow[dir][TRBL] -
+			w->triangles.currentRow[TRBL] +
+			w->triangles.spaceRow[(dir == UP) ? DOWN : UP][ROW] -
+			w->triangles.currentRow[ROW];
+	case TRBL:
+		return w->triangles.spaceRow[dir][TLBR] -
+			w->triangles.currentRow[TLBR] +
+			w->triangles.spaceRow[(dir == UP) ? DOWN : UP][ROW] -
+			w->triangles.currentRow[ROW];
+	case ROW:
+		return w->triangles.spaceRow[dir][TRBL] -
+			w->triangles.currentRow[TRBL] +
+			w->triangles.currentRow[TLBR] -
+			w->triangles.spaceRow[(dir == UP) ? DOWN : UP][TLBR];
+	default:
+		{
+			char *buf;
 
-	*rowType = MovableTile(w);
-	if (*rowType < 0) {
-		intCat(&buf, "CountTiles: rowType ", *rowType);
-		DISPLAY_WARNING(buf);
-		free(buf);
-		return 0;
+			intCat(&buf, "CountTiles: rowType ", rowType);
+			DISPLAY_WARNING(buf);
+			free(buf);
+		}
 	}
-	switch (*rowType) {
-		case TLBR:
-			count = w->triangles.spaceRow[*dir][TRBL] -
-			  w->triangles.currentRow[TRBL] +
-			  w->triangles.spaceRow[!*dir][ROW] -
-			  w->triangles.currentRow[ROW];
-			*dir = (*dir == DOWN) ? BR : TL;
-			break;
-		case TRBL:
-			count = w->triangles.spaceRow[*dir][TLBR] -
-			  w->triangles.currentRow[TLBR] +
-			  w->triangles.spaceRow[!*dir][ROW] -
-			  w->triangles.currentRow[ROW];
-			*dir = (*dir == DOWN) ? BL: TR;
-			break;
-		case ROW:
-			count = w->triangles.spaceRow[*dir][TRBL] -
-			  w->triangles.currentRow[TRBL] +
-			  w->triangles.currentRow[TLBR] -
-			  w->triangles.spaceRow[!*dir][TLBR];
-			*dir = (*dir == DOWN) ? RIGHT: LEFT;
-			break;
-		default:
-			{
-				intCat(&buf, "CountTiles: rowType ",
-					*rowType);
-				DISPLAY_WARNING(buf);
-				free(buf);
-			}
+	return 0;
+}
+
+static int
+DirTiles(TrianglesWidget w, int dir, int rowType)
+{
+	switch (rowType) {
+	case TLBR:
+		return (dir == UP) ? TL : BR;
+	case TRBL:
+		return (dir == UP) ? TR : BL;
+	case ROW:
+		return (dir == UP) ? LEFT : RIGHT;
+	default:
+		{
+			char *buf;
+
+			intCat(&buf, "DirTiles: rowType ", rowType);
+			DISPLAY_WARNING(buf);
+			free(buf);
+		}
 	}
-	return count;
+	return dir;
 }
 
 static void
 AnimateSlide(TrianglesWidget w, int dir, int fast, Boolean logMoves)
 {
 	int aTile, numTiles, direction = dir, rowType;
-	int fillBeginPos, fillBeginPos2, fillBeginOrient, fillBeginRow;
+	int fillBeginPos, fillBeginPos2, fillBeginRow;
+	int fillBeginOrient, fillBeginOrientOp;
 	int pos, pos2, posNext, orient, orientNext;
 
-	numTiles = CountTiles(w, &direction, &rowType);
+	rowType = MovableTile(w);
+	if (rowType < 0) {
+		char *buf;
+
+		intCat(&buf, "AnimateSlide: rowType ", rowType);
+		DISPLAY_WARNING(buf);
+		free(buf);
+		numTiles = 0;
+	} else {
+		numTiles = CountTiles(w, dir, rowType);
+		direction = DirTiles(w, dir, rowType);
+	}
 	if (numTiles < 0)
 		numTiles = -numTiles;
-	if (dir == DOWN)
-		orient = (w->triangles.spacePosition[UP] + (rowType == TRBL) <
+	if (dir == UP)
+		orient = (w->triangles.spacePosition[UP] +
+			((rowType == TRBL) ? 2 : 0) >
 			w->triangles.spacePosition[DOWN]) ? UP : DOWN;
 	else
 		orient = (w->triangles.spacePosition[UP] +
-			2 * (rowType == TRBL) >
+			((rowType == TRBL) ? 1 : 0) <
 			w->triangles.spacePosition[DOWN]) ? UP : DOWN;
-	fillBeginPos = TileNFromSpace(w, numTiles, rowType, orient, !dir);
+	fillBeginPos = TileNFromSpace(w, numTiles, rowType, orient,
+		(dir == UP) ? DOWN : UP);
 	fillBeginRow = Row(fillBeginPos);
 	fillBeginOrient = ToOrient(fillBeginRow,
 		TrBl(fillBeginPos, fillBeginRow),
 		TlBr(fillBeginPos, fillBeginRow));
-	fillBeginPos2 = w->triangles.spacePosition[!fillBeginOrient];
+	fillBeginOrientOp = (fillBeginOrient == UP) ? DOWN : UP;
+	fillBeginPos2 = w->triangles.spacePosition[fillBeginOrientOp];
 #ifdef RHOMBUS
 	{
 		int inc = 0;
@@ -1143,36 +1168,39 @@ AnimateSlide(TrianglesWidget w, int dir, int fast, Boolean logMoves)
 #else
 	{
 		int pixNo = 0;
-		int pixX = 0;
-		int pixY = 0;
-		int fromdx = 0;
-		int fromdy = 0;
-		int todx = 0;
-		int tody = 0;
-		int dx, dy;
-		int firstRow;
+		int pixX = 0, pixY = 0;
+		int fromdx = 0, fromdy = 0;
+		int todx = 0, tody = 0;
+		int dx, dy, row;
+		int firstRow, firstOrient;
 		int *rowPos;
 		int i, k;
 		Boolean slideDone = False;
-		int firstOrient;
 
 		if (!(rowPos = (int *)
 				malloc(sizeof (int) * (numTiles + 2)))) {
 			DISPLAY_ERROR("Not enough memory, exiting.");
 		}
-		rowPos[2] = TileNFromSpace(w, 1, rowType, orient, !dir);
+		rowPos[2] = TileNFromSpace(w, 1, rowType, orient,
+			(dir == UP) ? DOWN : UP);
 		firstRow = Row(rowPos[2]);
 		firstOrient = ToOrient(firstRow,
 			TrBl(rowPos[2], firstRow),
 			TlBr(rowPos[2], firstRow));
 		rowPos[0] = w->triangles.spacePosition[firstOrient];
-		rowPos[1] = w->triangles.spacePosition[!firstOrient];
+		rowPos[1] = w->triangles.spacePosition[(firstOrient == UP) ?
+			DOWN : UP];
 		for (i = 1; i < numTiles; i++) {
 			rowPos[i + 2] = TileNFromSpace(w,
-				i + 1, rowType, orient, !dir);
+				i + 1, rowType, orient,
+				(dir == UP) ? DOWN : UP);
 		}
-		Cartesian(w, rowPos[2], firstOrient, &fromdx, &fromdy);
-		Cartesian(w, rowPos[0], firstOrient, &todx, &tody);
+		row = Row(rowPos[2]);
+		fromdx = CartesianX(w, rowPos[2], row);
+		fromdy = CartesianY(w, row, firstOrient);
+		row = Row(rowPos[0]);
+		todx = CartesianX(w, rowPos[0], row);
+		tody = CartesianY(w, row, firstOrient);
 		dx = todx - fromdx;
 		dy = tody - fromdy;
 		i = 0;
@@ -1203,26 +1231,29 @@ AnimateSlide(TrianglesWidget w, int dir, int fast, Boolean logMoves)
 			SetTriangles(w, TRIANGLES_MOVED);
 			PutMove(direction);
 		}
-		posNext = TileNFromSpace(w, aTile + 1, rowType, orient, !dir);
-		orientNext = (aTile & 1) ? orient : !orient;
-		if (orientNext == !fillBeginOrient)
+		posNext = TileNFromSpace(w, aTile + 1, rowType, orient,
+			(dir == UP) ? DOWN : UP);
+		orientNext = ((aTile & 1) != 0) ? orient :
+			(orient == UP) ? DOWN : UP;
+		if (orientNext == fillBeginOrientOp)
 			fillBeginPos2 = posNext;
 	}
 	pos2 = w->triangles.spacePosition[orient];
-	pos = w->triangles.spacePosition[!orient];
+	pos = w->triangles.spacePosition[(orient == UP) ? DOWN : UP];
 	for (aTile = 0; aTile < numTiles; aTile++) {
-		posNext = TileNFromSpace(w, aTile + 1, rowType, orient, !dir);
+		posNext = TileNFromSpace(w, aTile + 1, rowType, orient,
+			(dir == UP) ? DOWN : UP);
 		w->triangles.tileOfPosition[pos] =
-		w->triangles.tileOfPosition[posNext];
+			w->triangles.tileOfPosition[posNext];
 		pos = pos2;
 		pos2 = posNext;
 	}
 	w->triangles.tileOfPosition[fillBeginPos] =
 		w->triangles.spacePosition[fillBeginOrient];
 	w->triangles.tileOfPosition[fillBeginPos2] =
-		w->triangles.spacePosition[!fillBeginOrient];
+		w->triangles.spacePosition[fillBeginOrientOp];
 	w->triangles.spacePosition[fillBeginOrient] = fillBeginPos;
-	w->triangles.spacePosition[!fillBeginOrient] = fillBeginPos2;
+	w->triangles.spacePosition[fillBeginOrientOp] = fillBeginPos2;
 	if (fillBeginOrient == UP) {
 		w->triangles.tileOfPosition[fillBeginPos] = 0;
 		w->triangles.tileOfPosition[fillBeginPos2] = -1;
@@ -1235,11 +1266,11 @@ AnimateSlide(TrianglesWidget w, int dir, int fast, Boolean logMoves)
 		w->triangles.spaceRow[fillBeginOrient][ROW]);
 	w->triangles.spaceRow[fillBeginOrient][TLBR] = TlBr(fillBeginPos,
 		w->triangles.spaceRow[fillBeginOrient][ROW]);
-	w->triangles.spaceRow[!fillBeginOrient][ROW] = Row(fillBeginPos2);
-	w->triangles.spaceRow[!fillBeginOrient][TRBL] = TrBl(fillBeginPos2,
-		w->triangles.spaceRow[!fillBeginOrient][ROW]);
-	w->triangles.spaceRow[!fillBeginOrient][TLBR] = TlBr(fillBeginPos2,
-		w->triangles.spaceRow[!fillBeginOrient][ROW]);
+	w->triangles.spaceRow[fillBeginOrientOp][ROW] = Row(fillBeginPos2);
+	w->triangles.spaceRow[fillBeginOrientOp][TRBL] = TrBl(fillBeginPos2,
+		w->triangles.spaceRow[fillBeginOrientOp][ROW]);
+	w->triangles.spaceRow[fillBeginOrientOp][TLBR] = TlBr(fillBeginPos2,
+		w->triangles.spaceRow[fillBeginOrientOp][ROW]);
 #ifdef RHOMBUS
 	DrawRhombus(w, w->triangles.spacePosition[UP], RhombusType(w), 1, 1);
 #endif
@@ -1266,14 +1297,14 @@ ResetTiles(TrianglesWidget w)
 	}
 
 	w->triangles.spacePosition[UP] = w->triangles.sizeSize - 1;
-	w->triangles.spaceRow[UP][TRBL] = w->triangles.size - 1;	/*i */
-	w->triangles.spaceRow[UP][TLBR] = 0;	/*j */
-	w->triangles.spaceRow[UP][ROW] = w->triangles.size - 1;		/*k */
+	w->triangles.spaceRow[UP][TRBL] = w->triangles.size - 1; /* i */
+	w->triangles.spaceRow[UP][TLBR] = 0; /* j */
+	w->triangles.spaceRow[UP][ROW] = w->triangles.size - 1; /* k */
 	if (w->triangles.size > 1) {
 		w->triangles.spacePosition[DOWN] = w->triangles.sizeSize - 2;
-		w->triangles.spaceRow[DOWN][TRBL] = w->triangles.size - 2;	/*i */
-		w->triangles.spaceRow[DOWN][TLBR] = 0;	/*j */
-		w->triangles.spaceRow[DOWN][ROW] = w->triangles.size - 1;	/*k */
+		w->triangles.spaceRow[DOWN][TRBL] = w->triangles.size - 2; /* i */
+		w->triangles.spaceRow[DOWN][TLBR] = 0; /* j */
+		w->triangles.spaceRow[DOWN][ROW] = w->triangles.size - 1; /* k */
 		w->triangles.tileOfPosition[w->triangles.sizeSize - 2] = -1;
 	}
 	w->triangles.tileOfPosition[w->triangles.sizeSize - 1] = 0;
@@ -1372,7 +1403,6 @@ MoveTiles(TrianglesWidget w, int from, int orient, int fast)
 		w->triangles.currentPositionOrient = ToOrient(w->triangles.currentRow[ROW],
 			w->triangles.currentRow[TRBL],
 			w->triangles.currentRow[TLBR]);
-
 		if (w->triangles.currentPosition <
 			w->triangles.spacePosition[w->triangles.currentPositionOrient]) {
 			AnimateSlide(w, DOWN, fast, False);
@@ -1385,9 +1415,8 @@ MoveTiles(TrianglesWidget w, int from, int orient, int fast)
 	} else
 #endif
 	{
-		int tempTile;
+		int tempTile = w->triangles.tileOfPosition[from];
 
-		tempTile = w->triangles.tileOfPosition[from];
 		w->triangles.tileOfPosition[from] =
 			w->triangles.tileOfPosition[w->triangles.spacePosition[orient]];
 		w->triangles.tileOfPosition[w->triangles.spacePosition[orient]] =
@@ -1549,59 +1578,60 @@ DiscreteMoves(TrianglesWidget w, int dir, int fast)
 		DISPLAY_WARNING(buf);
 	}
 	if (dir == DOWN) {
-		orient = (w->triangles.spacePosition[UP] + (rowType == TRBL) <
+		orient = (w->triangles.spacePosition[UP] +
+			((rowType == TRBL) ? 1 : 0) <
 			w->triangles.spacePosition[DOWN]) ? UP : DOWN;
 		next = TileNFromSpace(w, 1, rowType, orient, UP);
-		orient = !orient;
+		orient = (orient == UP) ? DOWN : UP;
 		MoveTiles(w, next, orient, fast);
 		SetTriangles(w, TRIANGLES_MOVED);
 		switch (rowType) {
-			case TLBR:
-				PutMove(BR);
-				break;
-			case TRBL:
-				PutMove(BL);
-				break;
-			case ROW:
-				PutMove(RIGHT);
-				break;
-			default:
-				{
-					intCat(&buf,
-						"DiscreteMoves: rowType ",
-						rowType);
-					DISPLAY_WARNING(buf);
-					free(buf);
-					return;
-				}
+		case TLBR:
+			PutMove(BR);
+			return;
+		case TRBL:
+			PutMove(BL);
+			return;
+		case ROW:
+			PutMove(RIGHT);
+			return;
+		default:
+			{
+				intCat(&buf,
+					"DiscreteMoves: rowType ",
+					rowType);
+				DISPLAY_WARNING(buf);
+				free(buf);
+				return;
+			}
 		}
 	} else {
 		orient = (w->triangles.spacePosition[UP] +
-			2 * (rowType == TRBL) >
+			((rowType == TRBL) ? 2 : 0) >
 			w->triangles.spacePosition[DOWN]) ? UP : DOWN;
 		next = TileNFromSpace(w, 1, rowType, orient, DOWN);
-		orient = !orient;
+		orient = (orient == UP) ? DOWN : UP;
 		MoveTiles(w, next, orient, fast);
 		SetTriangles(w, TRIANGLES_MOVED);
 		switch (rowType) {
-			case TLBR:
-				PutMove(TL);
-				break;
-			case TRBL:
-				PutMove(TR);
-				break;
-			case ROW:
-				PutMove(LEFT);
-				break;
-			default:
-				{
-					intCat(&buf,
-						"DiscreteMoves: rowType ",
-						rowType);
-					DISPLAY_WARNING(buf);
-					free(buf);
-					return;
-				}
+		case TLBR:
+			PutMove(TL);
+			return;
+		case TRBL:
+			PutMove(TR);
+			return;
+		case ROW:
+			PutMove(LEFT);
+			return;
+		default:
+			{
+				intCat(&buf,
+					"DiscreteMoves: rowType ",
+					rowType);
+				DISPLAY_WARNING(buf);
+				free(buf);
+				return;
+			}
 		}
 	}
 }
@@ -2312,9 +2342,9 @@ DestroyTriangles(Widget old)
 	TrianglesWidget w = (TrianglesWidget) old;
 
 	XtReleaseGC(old, w->triangles.tileGC);
+	XtReleaseGC(old, w->triangles.borderGC);
 	XtReleaseGC(old, w->triangles.tileBrighterGC);
 	XtReleaseGC(old, w->triangles.tileDarkerGC);
-	XtReleaseGC(old, w->triangles.borderGC);
 	XtReleaseGC(old, w->triangles.frameGC);
 	XtReleaseGC(old, w->triangles.inverseGC);
 	XtRemoveCallbacks(old, XtNselectCallback, w->triangles.select);
@@ -2457,11 +2487,11 @@ ResizeTriangles(TrianglesWidget w)
 		w->triangles.delta.x) / w->triangles.size, 0);
 	w->triangles.offset.y = MAX(((int) w->core.height -
 		2 * w->triangles.delta.y) / w->triangles.size, 0);
-	tempSize.y = (int) ((double) w->triangles.offset.x * sqrt_3 / 2.0);
 	tempSize.x = (int) ((double) w->triangles.offset.y * 2.0 / sqrt_3);
+	tempSize.y = (int) ((double) w->triangles.offset.x * sqrt_3 / 2.0);
 	if (tempSize.y < w->triangles.offset.y)
 		w->triangles.offset.y = tempSize.y;
-	else	/* tempSize.x <= w->triangles.wid */
+	else /* tempSize.x <= w->triangles.offset.x */
 		w->triangles.offset.x = tempSize.x;
 	w->triangles.puzzleSize.x = w->triangles.offset.x * w->triangles.size +
 		w->triangles.delta.x + 2;
@@ -2516,9 +2546,9 @@ Widget request, Widget renew
 	w->triangles.oldColormap = None;
 	w->triangles.fontInfo = NULL;
 	w->triangles.tileGC = NULL;
+	w->triangles.borderGC = NULL;
 	w->triangles.tileBrighterGC = NULL;
 	w->triangles.tileDarkerGC = NULL;
-	w->triangles.borderGC = NULL;
 	w->triangles.frameGC = NULL;
 	w->triangles.inverseGC = NULL;
 #endif
