@@ -5,7 +5,7 @@
 #
 ###
 #
-#  Copyright (c) 1993 - 2004	David Albert Bagley, bagleyd@tux.org
+#  Copyright (c) 1993 - 2005	David Albert Bagley, bagleyd@tux.org
 #
 #                   All Rights Reserved
 #
@@ -97,7 +97,7 @@ static HWND Wnd;
 
 #ifdef HAVE_MOTIF
 static const char aboutHelp[] = {
-	"Version 7.1.1\n"
+	"Version 7.1.3\n"
 	"Send bugs (reports or fixes) to the author: "
 	"David Bagley <bagleyd@tux.org>\n"
 	"The latest version is at: "
@@ -150,7 +150,7 @@ static const char featuresHelp[] = {
 	"\n"
 	"Press \"<\" or \",\" keys to slow down the movement of tiles.\n"
 	"\n"
-	"Press \"@\" or \"2\" keys to toggle the sound.\n"
+	"Press \"@\" key to toggle the sound.\n"
 	"\n"
 	"Press \"Esc\" key to hide program.\n"
 	"\n"
